/*

@Name  : Bootstrap Theme
@author: NaveenDA
@github: github.com/NaveenDA

*/

/*!
 * Bootstrap v3.3.7 (http://getbootstrap.com)
 * Copyright 2011-2016 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */

/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */

html {
  font-family: sans-serif;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%;
}

body {
  margin: 0;
}

article, aside, details, figcaption, figure, footer, header, hgroup, main, menu, nav, section, summary {
  display: block;
}

audio, canvas, progress, video {
  display: inline-block;
  vertical-align: baseline;
}

audio:not([controls]) {
  display: none;
  height: 0;
}

[hidden], template {
  display: none;
}

a {
  background-color: transparent;
  &:active, &:hover {
    outline: 0;
  }
}

abbr[title] {
  border-bottom: 1px dotted;
}

b, strong {
  font-weight: bold;
}

dfn {
  font-style: italic;
}

h1 {
  font-size: 2em;
  margin: 0.67em 0;
}

mark {
  background: #ff0;
  color: #000;
}

small {
  font-size: 80%;
}

sub {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
}

sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline;
  top: -0.5em;
}

sub {
  bottom: -0.25em;
}

img {
  border: 0;
}

svg:not(:root) {
  overflow: hidden;
}

figure {
  margin: 1em 40px;
}

hr {
  -webkit-box-sizing: content-box;
  box-sizing: content-box;
  height: 0;
}

pre {
  overflow: auto;
}

code, kbd, pre, samp {
  font-family: monospace, monospace;
  font-size: 1em;
}

button, input, optgroup, select, textarea {
  color: inherit;
  font: inherit;
  margin: 0;
}

button {
  overflow: visible;
  text-transform: none;
}

select {
  text-transform: none;
}

button, html input[type="button"] {
  -webkit-appearance: button;
  cursor: pointer;
}

input {
  &[type="reset"], &[type="submit"] {
    -webkit-appearance: button;
    cursor: pointer;
  }
}

button[disabled], html input[disabled] {
  cursor: default;
}

button::-moz-focus-inner {
  border: 0;
  padding: 0;
}

input {
  &::-moz-focus-inner {
    border: 0;
    padding: 0;
  }
  line-height: normal;
  &[type="checkbox"], &[type="radio"] {
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    padding: 0;
  }
  &[type="number"] {
    &::-webkit-inner-spin-button, &::-webkit-outer-spin-button {
      height: auto;
    }
  }
  &[type="search"] {
    -webkit-appearance: textfield;
    -webkit-box-sizing: content-box;
    box-sizing: content-box;
    &::-webkit-search-cancel-button, &::-webkit-search-decoration {
      -webkit-appearance: none;
    }
  }
}

fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em;
}

legend {
  border: 0;
  padding: 0;
}

textarea {
  overflow: auto;
}

optgroup {
  font-weight: bold;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

td, th {
  padding: 0;
}

* {
  -webkit-box-sizing: border-box;
  box-sizing: border-box;
  &:before, &:after {
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
  }
}

html {
  font-size: 10px;
  -webkit-tap-highlight-color: transparent;
}

body {
  font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
  font-size: 14px;
  line-height: 1.42857;
  color: #333;
  background-color: #fff;
}

input, button, select, textarea {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}

a {
  color: #337ab7;
  text-decoration: none;
  &:hover {
    color: #23527c;
    text-decoration: underline;
  }
  &:focus {
    color: #23527c;
    text-decoration: underline;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

figure {
  margin: 0;
}

img {
  vertical-align: middle;
}

.img-responsive {
  display: block;
  max-width: 100%;
  height: auto;
}

.img-rounded {
  border-radius: 6px;
}

.img-thumbnail {
  padding: 4px;
  line-height: 1.42857;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 4px;
  -webkit-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
  display: inline-block;
  max-width: 100%;
  height: auto;
}

.img-circle {
  border-radius: 50%;
}

hr {
  margin-top: 20px;
  margin-bottom: 20px;
  border: 0;
  border-top: 1px solid #eee;
}

.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0;
}

.sr-only-focusable {
  &:active, &:focus {
    position: static;
    width: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    clip: auto;
  }
}

[role="button"] {
  cursor: pointer;
}

h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
  font-family: inherit;
  font-weight: 500;
  line-height: 1.1;
  color: inherit;
}

h1 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

h2 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

h3 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

h4 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

h5 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

h6 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

.h1 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

.h2 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

.h3 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

.h4 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

.h5 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

.h6 {
  small, .small {
    font-weight: normal;
    line-height: 1;
    color: #777;
  }
}

h1, .h1, h2, .h2, h3, .h3 {
  margin-top: 20px;
  margin-bottom: 10px;
}

h1 {
  small, .small {
    font-size: 65%;
  }
}

.h1 {
  small, .small {
    font-size: 65%;
  }
}

h2 {
  small, .small {
    font-size: 65%;
  }
}

.h2 {
  small, .small {
    font-size: 65%;
  }
}

h3 {
  small, .small {
    font-size: 65%;
  }
}

.h3 {
  small, .small {
    font-size: 65%;
  }
}

h4, .h4, h5, .h5, h6, .h6 {
  margin-top: 10px;
  margin-bottom: 10px;
}

h4 {
  small, .small {
    font-size: 75%;
  }
}

.h4 {
  small, .small {
    font-size: 75%;
  }
}

h5 {
  small, .small {
    font-size: 75%;
  }
}

.h5 {
  small, .small {
    font-size: 75%;
  }
}

h6 {
  small, .small {
    font-size: 75%;
  }
}

.h6 {
  small, .small {
    font-size: 75%;
  }
}

h1, .h1 {
  font-size: 36px;
}

h2, .h2 {
  font-size: 30px;
}

h3, .h3 {
  font-size: 24px;
}

h4, .h4 {
  font-size: 18px;
}

h5, .h5 {
  font-size: 14px;
}

h6, .h6 {
  font-size: 12px;
}

p {
  margin: 0 0 10px;
}

.lead {
  margin-bottom: 20px;
  font-size: 16px;
  font-weight: 300;
  line-height: 1.4;
}

@media (min-width: 768px) {
  .lead {
    font-size: 21px;
  }
}

small, .small {
  font-size: 85%;
}

mark, .mark {
  background-color: #fcf8e3;
  padding: .2em;
}

.text-left {
  text-align: left;
}

.text-right {
  text-align: right;
}

.text-center, #leftNav h1 {
  text-align: center;
}

.text-justify {
  text-align: justify;
}

.text-nowrap {
  white-space: nowrap;
}

.text-lowercase {
  text-transform: lowercase;
}

.text-uppercase, .initialism {
  text-transform: uppercase;
}

.text-capitalize {
  text-transform: capitalize;
}

.text-muted {
  color: #777;
}

.text-primary {
  color: #337ab7;
}

a.text-primary {
  &:hover, &:focus {
    color: #286090;
  }
}

.text-success {
  color: #3c763d;
}

a.text-success {
  &:hover, &:focus {
    color: #2b542c;
  }
}

.text-info {
  color: #31708f;
}

a.text-info {
  &:hover, &:focus {
    color: #245269;
  }
}

.text-warning {
  color: #8a6d3b;
}

a.text-warning {
  &:hover, &:focus {
    color: #66512c;
  }
}

.text-danger {
  color: #a94442;
}

a.text-danger {
  &:hover, &:focus {
    color: #843534;
  }
}

.bg-primary {
  color: #fff;
  background-color: #337ab7;
}

a.bg-primary {
  &:hover, &:focus {
    background-color: #286090;
  }
}

.bg-success {
  background-color: #dff0d8;
}

a.bg-success {
  &:hover, &:focus {
    background-color: #c1e2b3;
  }
}

.bg-info {
  background-color: #d9edf7;
}

a.bg-info {
  &:hover, &:focus {
    background-color: #afd9ee;
  }
}

.bg-warning {
  background-color: #fcf8e3;
}

a.bg-warning {
  &:hover, &:focus {
    background-color: #f7ecb5;
  }
}

.bg-danger {
  background-color: #f2dede;
}

a.bg-danger {
  &:hover, &:focus {
    background-color: #e4b9b9;
  }
}

.page-header, #loginBox h1 {
  padding-bottom: 9px;
  margin: 40px 0 20px;
  border-bottom: 1px solid #eee;
}

ul, ol {
  margin-top: 0;
  margin-bottom: 10px;
}

ul {
  ul, ol {
    margin-bottom: 0;
  }
}

ol {
  ul, ol {
    margin-bottom: 0;
  }
}

.list-unstyled {
  padding-left: 0;
  list-style: none;
}

.list-inline {
  padding-left: 0;
  list-style: none;
  margin-left: -5px;
  > li {
    display: inline-block;
    padding-left: 5px;
    padding-right: 5px;
  }
}

dl {
  margin-top: 0;
  margin-bottom: 20px;
}

dt, dd {
  line-height: 1.42857;
}

dt {
  font-weight: bold;
}

dd {
  margin-left: 0;
}

.dl-horizontal dd {
  &:before {
    content: " ";
    display: table;
  }
  &:after {
    content: " ";
    display: table;
    clear: both;
  }
}

@media (min-width: 768px) {
  .dl-horizontal {
    dt {
      float: left;
      width: 160px;
      clear: left;
      text-align: right;
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap;
    }
    dd {
      margin-left: 180px;
    }
  }
}

abbr {
  &[title], &[data-original-title] {
    cursor: help;
    border-bottom: 1px dotted #777;
  }
}

.initialism {
  font-size: 90%;
}

blockquote {
  padding: 10px 20px;
  margin: 0 0 20px;
  font-size: 17.5px;
  border-left: 5px solid #eee;
  p:last-child, ul:last-child, ol:last-child {
    margin-bottom: 0;
  }
  footer, small, .small {
    display: block;
    font-size: 80%;
    line-height: 1.42857;
    color: #777;
  }
  footer:before, small:before, .small:before {
    content: '\2014 \00A0';
  }
}

.blockquote-reverse, blockquote.pull-right {
  padding-right: 15px;
  padding-left: 0;
  border-right: 5px solid #eee;
  border-left: 0;
  text-align: right;
}

.blockquote-reverse {
  footer:before, small:before, .small:before {
    content: '';
  }
}

blockquote.pull-right {
  footer:before, small:before, .small:before {
    content: '';
  }
}

.blockquote-reverse {
  footer:after, small:after, .small:after {
    content: '\00A0 \2014';
  }
}

blockquote.pull-right {
  footer:after, small:after, .small:after {
    content: '\00A0 \2014';
  }
}

address {
  margin-bottom: 20px;
  font-style: normal;
  line-height: 1.42857;
}

code, kbd, pre, samp {
  font-family: Menlo,Monaco,Consolas,"Courier New",monospace;
}

code {
  padding: 2px 4px;
  font-size: 90%;
  color: #c7254e;
  background-color: #f9f2f4;
  border-radius: 4px;
}

kbd {
  padding: 2px 4px;
  font-size: 90%;
  color: #fff;
  background-color: #333;
  border-radius: 3px;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
  box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
  kbd {
    padding: 0;
    font-size: 100%;
    font-weight: bold;
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 1.42857;
  word-break: break-all;
  word-wrap: break-word;
  color: #333;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border-radius: 4px;
  code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    white-space: pre-wrap;
    background-color: transparent;
    border-radius: 0;
  }
}

.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll;
}

.container, .container-fluid {
  margin-right: auto;
  margin-left: auto;
  padding-left: 15px;
  padding-right: 15px;
  &:before {
    content: " ";
    display: table;
  }
  &:after {
    content: " ";
    display: table;
    clear: both;
  }
}

@media (min-width: 768px) {
  .container {
    width: 750px;
  }
}

@media (min-width: 992px) {
  .container {
    width: 970px;
  }
}

@media (min-width: 1200px) {
  .container {
    width: 1170px;
  }
}

.row, div.confirm + fieldset {
  margin-left: -15px;
  margin-right: -15px;
}

.row:before, div.confirm + fieldset:before, .row:after, div.confirm + fieldset:after {
  content: " ";
  display: table;
}

.row:after, div.confirm + fieldset:after {
  clear: both;
}

.col-xs-1, .col-sm-1, .col-md-1, .col-lg-1, .col-xs-2, .col-sm-2, .col-md-2, .col-lg-2, .col-xs-3, .col-sm-3, .col-md-3, .col-lg-3, .col-xs-4, .col-sm-4, .col-md-4, .col-lg-4, .col-xs-5, .col-sm-5, .col-md-5, div.confirm + fieldset form, .col-lg-5, .col-xs-6, .col-sm-6, .col-md-6, .col-lg-6, .col-xs-7, .col-sm-7, .col-md-7, .col-lg-7, .col-xs-8, .col-sm-8, .col-md-8, .col-lg-8, .col-xs-9, .col-sm-9, .col-md-9, .col-lg-9, .col-xs-10, .col-sm-10, .col-md-10, .col-lg-10, .col-xs-11, .col-sm-11, .col-md-11, .col-lg-11, .col-xs-12, .col-sm-12, .col-md-12, .col-lg-12 {
  position: relative;
  min-height: 1px;
  padding-left: 15px;
  padding-right: 15px;
}

.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12 {
  float: left;
}

.col-xs-1 {
  width: 8.33333%;
}

.col-xs-2 {
  width: 16.66667%;
}

.col-xs-3 {
  width: 25%;
}

.col-xs-4 {
  width: 33.33333%;
}

.col-xs-5 {
  width: 41.66667%;
}

.col-xs-6 {
  width: 50%;
}

.col-xs-7 {
  width: 58.33333%;
}

.col-xs-8 {
  width: 66.66667%;
}

.col-xs-9 {
  width: 75%;
}

.col-xs-10 {
  width: 83.33333%;
}

.col-xs-11 {
  width: 91.66667%;
}

.col-xs-12 {
  width: 100%;
}

.col-xs-pull-0 {
  right: auto;
}

.col-xs-pull-1 {
  right: 8.33333%;
}

.col-xs-pull-2 {
  right: 16.66667%;
}

.col-xs-pull-3 {
  right: 25%;
}

.col-xs-pull-4 {
  right: 33.33333%;
}

.col-xs-pull-5 {
  right: 41.66667%;
}

.col-xs-pull-6 {
  right: 50%;
}

.col-xs-pull-7 {
  right: 58.33333%;
}

.col-xs-pull-8 {
  right: 66.66667%;
}

.col-xs-pull-9 {
  right: 75%;
}

.col-xs-pull-10 {
  right: 83.33333%;
}

.col-xs-pull-11 {
  right: 91.66667%;
}

.col-xs-pull-12 {
  right: 100%;
}

.col-xs-push-0 {
  left: auto;
}

.col-xs-push-1 {
  left: 8.33333%;
}

.col-xs-push-2 {
  left: 16.66667%;
}

.col-xs-push-3 {
  left: 25%;
}

.col-xs-push-4 {
  left: 33.33333%;
}

.col-xs-push-5 {
  left: 41.66667%;
}

.col-xs-push-6 {
  left: 50%;
}

.col-xs-push-7 {
  left: 58.33333%;
}

.col-xs-push-8 {
  left: 66.66667%;
}

.col-xs-push-9 {
  left: 75%;
}

.col-xs-push-10 {
  left: 83.33333%;
}

.col-xs-push-11 {
  left: 91.66667%;
}

.col-xs-push-12 {
  left: 100%;
}

.col-xs-offset-0 {
  margin-left: 0%;
}

.col-xs-offset-1 {
  margin-left: 8.33333%;
}

.col-xs-offset-2 {
  margin-left: 16.66667%;
}

.col-xs-offset-3 {
  margin-left: 25%;
}

.col-xs-offset-4 {
  margin-left: 33.33333%;
}

.col-xs-offset-5 {
  margin-left: 41.66667%;
}

.col-xs-offset-6 {
  margin-left: 50%;
}

.col-xs-offset-7 {
  margin-left: 58.33333%;
}

.col-xs-offset-8 {
  margin-left: 66.66667%;
}

.col-xs-offset-9 {
  margin-left: 75%;
}

.col-xs-offset-10 {
  margin-left: 83.33333%;
}

.col-xs-offset-11 {
  margin-left: 91.66667%;
}

.col-xs-offset-12 {
  margin-left: 100%;
}

@media (min-width: 768px) {
  .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12 {
    float: left;
  }
  .col-sm-1 {
    width: 8.33333%;
  }
  .col-sm-2 {
    width: 16.66667%;
  }
  .col-sm-3 {
    width: 25%;
  }
  .col-sm-4 {
    width: 33.33333%;
  }
  .col-sm-5 {
    width: 41.66667%;
  }
  .col-sm-6 {
    width: 50%;
  }
  .col-sm-7 {
    width: 58.33333%;
  }
  .col-sm-8 {
    width: 66.66667%;
  }
  .col-sm-9 {
    width: 75%;
  }
  .col-sm-10 {
    width: 83.33333%;
  }
  .col-sm-11 {
    width: 91.66667%;
  }
  .col-sm-12 {
    width: 100%;
  }
  .col-sm-pull-0 {
    right: auto;
  }
  .col-sm-pull-1 {
    right: 8.33333%;
  }
  .col-sm-pull-2 {
    right: 16.66667%;
  }
  .col-sm-pull-3 {
    right: 25%;
  }
  .col-sm-pull-4 {
    right: 33.33333%;
  }
  .col-sm-pull-5 {
    right: 41.66667%;
  }
  .col-sm-pull-6 {
    right: 50%;
  }
  .col-sm-pull-7 {
    right: 58.33333%;
  }
  .col-sm-pull-8 {
    right: 66.66667%;
  }
  .col-sm-pull-9 {
    right: 75%;
  }
  .col-sm-pull-10 {
    right: 83.33333%;
  }
  .col-sm-pull-11 {
    right: 91.66667%;
  }
  .col-sm-pull-12 {
    right: 100%;
  }
  .col-sm-push-0 {
    left: auto;
  }
  .col-sm-push-1 {
    left: 8.33333%;
  }
  .col-sm-push-2 {
    left: 16.66667%;
  }
  .col-sm-push-3 {
    left: 25%;
  }
  .col-sm-push-4 {
    left: 33.33333%;
  }
  .col-sm-push-5 {
    left: 41.66667%;
  }
  .col-sm-push-6 {
    left: 50%;
  }
  .col-sm-push-7 {
    left: 58.33333%;
  }
  .col-sm-push-8 {
    left: 66.66667%;
  }
  .col-sm-push-9 {
    left: 75%;
  }
  .col-sm-push-10 {
    left: 83.33333%;
  }
  .col-sm-push-11 {
    left: 91.66667%;
  }
  .col-sm-push-12 {
    left: 100%;
  }
  .col-sm-offset-0 {
    margin-left: 0%;
  }
  .col-sm-offset-1 {
    margin-left: 8.33333%;
  }
  .col-sm-offset-2 {
    margin-left: 16.66667%;
  }
  .col-sm-offset-3 {
    margin-left: 25%;
  }
  .col-sm-offset-4 {
    margin-left: 33.33333%;
  }
  .col-sm-offset-5 {
    margin-left: 41.66667%;
  }
  .col-sm-offset-6 {
    margin-left: 50%;
  }
  .col-sm-offset-7 {
    margin-left: 58.33333%;
  }
  .col-sm-offset-8 {
    margin-left: 66.66667%;
  }
  .col-sm-offset-9 {
    margin-left: 75%;
  }
  .col-sm-offset-10 {
    margin-left: 83.33333%;
  }
  .col-sm-offset-11 {
    margin-left: 91.66667%;
  }
  .col-sm-offset-12 {
    margin-left: 100%;
  }
}

@media (min-width: 992px) {
  .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, div.confirm + fieldset form, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12 {
    float: left;
  }
  .col-md-1 {
    width: 8.33333%;
  }
  .col-md-2 {
    width: 16.66667%;
  }
  .col-md-3 {
    width: 25%;
  }
  .col-md-4 {
    width: 33.33333%;
  }
  .col-md-5, div.confirm + fieldset form {
    width: 41.66667%;
  }
  .col-md-6 {
    width: 50%;
  }
  .col-md-7 {
    width: 58.33333%;
  }
  .col-md-8 {
    width: 66.66667%;
  }
  .col-md-9 {
    width: 75%;
  }
  .col-md-10 {
    width: 83.33333%;
  }
  .col-md-11 {
    width: 91.66667%;
  }
  .col-md-12 {
    width: 100%;
  }
  .col-md-pull-0 {
    right: auto;
  }
  .col-md-pull-1 {
    right: 8.33333%;
  }
  .col-md-pull-2 {
    right: 16.66667%;
  }
  .col-md-pull-3 {
    right: 25%;
  }
  .col-md-pull-4 {
    right: 33.33333%;
  }
  .col-md-pull-5 {
    right: 41.66667%;
  }
  .col-md-pull-6 {
    right: 50%;
  }
  .col-md-pull-7 {
    right: 58.33333%;
  }
  .col-md-pull-8 {
    right: 66.66667%;
  }
  .col-md-pull-9 {
    right: 75%;
  }
  .col-md-pull-10 {
    right: 83.33333%;
  }
  .col-md-pull-11 {
    right: 91.66667%;
  }
  .col-md-pull-12 {
    right: 100%;
  }
  .col-md-push-0 {
    left: auto;
  }
  .col-md-push-1 {
    left: 8.33333%;
  }
  .col-md-push-2 {
    left: 16.66667%;
  }
  .col-md-push-3 {
    left: 25%;
  }
  .col-md-push-4 {
    left: 33.33333%;
  }
  .col-md-push-5 {
    left: 41.66667%;
  }
  .col-md-push-6 {
    left: 50%;
  }
  .col-md-push-7 {
    left: 58.33333%;
  }
  .col-md-push-8 {
    left: 66.66667%;
  }
  .col-md-push-9 {
    left: 75%;
  }
  .col-md-push-10 {
    left: 83.33333%;
  }
  .col-md-push-11 {
    left: 91.66667%;
  }
  .col-md-push-12 {
    left: 100%;
  }
  .col-md-offset-0 {
    margin-left: 0%;
  }
  .col-md-offset-1 {
    margin-left: 8.33333%;
  }
  .col-md-offset-2 {
    margin-left: 16.66667%;
  }
  .col-md-offset-3 {
    margin-left: 25%;
  }
  .col-md-offset-4 {
    margin-left: 33.33333%;
  }
  .col-md-offset-5 {
    margin-left: 41.66667%;
  }
  .col-md-offset-6 {
    margin-left: 50%;
  }
  .col-md-offset-7 {
    margin-left: 58.33333%;
  }
  .col-md-offset-8 {
    margin-left: 66.66667%;
  }
  .col-md-offset-9 {
    margin-left: 75%;
  }
  .col-md-offset-10 {
    margin-left: 83.33333%;
  }
  .col-md-offset-11 {
    margin-left: 91.66667%;
  }
  .col-md-offset-12 {
    margin-left: 100%;
  }
}

@media (min-width: 1200px) {
  .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12 {
    float: left;
  }
  .col-lg-1 {
    width: 8.33333%;
  }
  .col-lg-2 {
    width: 16.66667%;
  }
  .col-lg-3 {
    width: 25%;
  }
  .col-lg-4 {
    width: 33.33333%;
  }
  .col-lg-5 {
    width: 41.66667%;
  }
  .col-lg-6 {
    width: 50%;
  }
  .col-lg-7 {
    width: 58.33333%;
  }
  .col-lg-8 {
    width: 66.66667%;
  }
  .col-lg-9 {
    width: 75%;
  }
  .col-lg-10 {
    width: 83.33333%;
  }
  .col-lg-11 {
    width: 91.66667%;
  }
  .col-lg-12 {
    width: 100%;
  }
  .col-lg-pull-0 {
    right: auto;
  }
  .col-lg-pull-1 {
    right: 8.33333%;
  }
  .col-lg-pull-2 {
    right: 16.66667%;
  }
  .col-lg-pull-3 {
    right: 25%;
  }
  .col-lg-pull-4 {
    right: 33.33333%;
  }
  .col-lg-pull-5 {
    right: 41.66667%;
  }
  .col-lg-pull-6 {
    right: 50%;
  }
  .col-lg-pull-7 {
    right: 58.33333%;
  }
  .col-lg-pull-8 {
    right: 66.66667%;
  }
  .col-lg-pull-9 {
    right: 75%;
  }
  .col-lg-pull-10 {
    right: 83.33333%;
  }
  .col-lg-pull-11 {
    right: 91.66667%;
  }
  .col-lg-pull-12 {
    right: 100%;
  }
  .col-lg-push-0 {
    left: auto;
  }
  .col-lg-push-1 {
    left: 8.33333%;
  }
  .col-lg-push-2 {
    left: 16.66667%;
  }
  .col-lg-push-3 {
    left: 25%;
  }
  .col-lg-push-4 {
    left: 33.33333%;
  }
  .col-lg-push-5 {
    left: 41.66667%;
  }
  .col-lg-push-6 {
    left: 50%;
  }
  .col-lg-push-7 {
    left: 58.33333%;
  }
  .col-lg-push-8 {
    left: 66.66667%;
  }
  .col-lg-push-9 {
    left: 75%;
  }
  .col-lg-push-10 {
    left: 83.33333%;
  }
  .col-lg-push-11 {
    left: 91.66667%;
  }
  .col-lg-push-12 {
    left: 100%;
  }
  .col-lg-offset-0 {
    margin-left: 0%;
  }
  .col-lg-offset-1 {
    margin-left: 8.33333%;
  }
  .col-lg-offset-2 {
    margin-left: 16.66667%;
  }
  .col-lg-offset-3 {
    margin-left: 25%;
  }
  .col-lg-offset-4 {
    margin-left: 33.33333%;
  }
  .col-lg-offset-5 {
    margin-left: 41.66667%;
  }
  .col-lg-offset-6 {
    margin-left: 50%;
  }
  .col-lg-offset-7 {
    margin-left: 58.33333%;
  }
  .col-lg-offset-8 {
    margin-left: 66.66667%;
  }
  .col-lg-offset-9 {
    margin-left: 75%;
  }
  .col-lg-offset-10 {
    margin-left: 83.33333%;
  }
  .col-lg-offset-11 {
    margin-left: 91.66667%;
  }
  .col-lg-offset-12 {
    margin-left: 100%;
  }
}

table {
  background-color: transparent;
}

caption {
  padding-top: 8px;
  padding-bottom: 8px;
  color: #777;
  text-align: left;
}

th {
  text-align: left;
}

.table, table.viewTable {
  width: 100%;
  max-width: 100%;
  margin-bottom: 20px;
}

.table > thead > tr > th, table.viewTable > thead > tr > th, .table > thead > tr > td, table.viewTable > thead > tr > td, .table > tbody > tr > th, table.viewTable > tbody > tr > th, .table > tbody > tr > td, table.viewTable > tbody > tr > td, .table > tfoot > tr > th, table.viewTable > tfoot > tr > th, .table > tfoot > tr > td, table.viewTable > tfoot > tr > td {
  padding: 8px;
  line-height: 1.42857;
  vertical-align: top;
  border-top: 1px solid #ddd;
}

.table > thead > tr > th, table.viewTable > thead > tr > th {
  vertical-align: bottom;
  border-bottom: 2px solid #ddd;
}

.table > caption + thead > tr:first-child > th, table.viewTable > caption + thead > tr:first-child > th, .table > caption + thead > tr:first-child > td, table.viewTable > caption + thead > tr:first-child > td, .table > colgroup + thead > tr:first-child > th, table.viewTable > colgroup + thead > tr:first-child > th, .table > colgroup + thead > tr:first-child > td, table.viewTable > colgroup + thead > tr:first-child > td, .table > thead:first-child > tr:first-child > th, table.viewTable > thead:first-child > tr:first-child > th, .table > thead:first-child > tr:first-child > td, table.viewTable > thead:first-child > tr:first-child > td {
  border-top: 0;
}

.table > tbody + tbody, table.viewTable > tbody + tbody {
  border-top: 2px solid #ddd;
}

.table .table, table.viewTable .table, .table table.viewTable, table.viewTable table.viewTable {
  background-color: #fff;
}

.table-condensed > thead > tr > th, table.viewTable > thead > tr > th, .table-condensed > thead > tr > td, table.viewTable > thead > tr > td, .table-condensed > tbody > tr > th, table.viewTable > tbody > tr > th, .table-condensed > tbody > tr > td, table.viewTable > tbody > tr > td, .table-condensed > tfoot > tr > th, table.viewTable > tfoot > tr > th, .table-condensed > tfoot > tr > td, table.viewTable > tfoot > tr > td {
  padding: 5px;
}

.table-bordered, table.viewTable, .table-bordered > thead > tr > th, table.viewTable > thead > tr > th, .table-bordered > thead > tr > td, table.viewTable > thead > tr > td, .table-bordered > tbody > tr > th, table.viewTable > tbody > tr > th, .table-bordered > tbody > tr > td, table.viewTable > tbody > tr > td, .table-bordered > tfoot > tr > th, table.viewTable > tfoot > tr > th, .table-bordered > tfoot > tr > td, table.viewTable > tfoot > tr > td {
  border: 1px solid #ddd;
}

.table-bordered > thead > tr > th, table.viewTable > thead > tr > th, .table-bordered > thead > tr > td, table.viewTable > thead > tr > td {
  border-bottom-width: 2px;
}

.table-striped > tbody > tr:nth-of-type(odd), table.viewTable > tbody > tr:nth-of-type(odd) {
  background-color: #f9f9f9;
}

.table-hover > tbody > tr:hover {
  background-color: #f5f5f5;
}

table {
  &.viewTable > tbody > tr:hover {
    background-color: #f5f5f5;
  }
  col[class*="col-"] {
    position: static;
    float: none;
    display: table-column;
  }
  td[class*="col-"], th[class*="col-"] {
    position: static;
    float: none;
    display: table-cell;
  }
}

.table > thead > tr > td.active, table.viewTable > thead > tr > td.active, .table > thead > tr > th.active, table.viewTable > thead > tr > th.active, .table > thead > tr.active > td, table.viewTable > thead > tr.active > td, .table > thead > tr.active > th, table.viewTable > thead > tr.active > th, .table > tbody > tr > td.active, table.viewTable > tbody > tr > td.active, .table > tbody > tr > th.active, table.viewTable > tbody > tr > th.active, .table > tbody > tr.active > td, table.viewTable > tbody > tr.active > td, .table > tbody > tr.active > th, table.viewTable > tbody > tr.active > th, .table > tfoot > tr > td.active, table.viewTable > tfoot > tr > td.active, .table > tfoot > tr > th.active, table.viewTable > tfoot > tr > th.active, .table > tfoot > tr.active > td, table.viewTable > tfoot > tr.active > td, .table > tfoot > tr.active > th, table.viewTable > tfoot > tr.active > th {
  background-color: #f5f5f5;
}

.table-hover > tbody > tr > td.active:hover, table.viewTable > tbody > tr > td.active:hover, .table-hover > tbody > tr > th.active:hover, table.viewTable > tbody > tr > th.active:hover, .table-hover > tbody > tr.active:hover > td, table.viewTable > tbody > tr.active:hover > td, .table-hover > tbody > tr:hover > .active, table.viewTable > tbody > tr:hover > .active, .table-hover > tbody > tr.active:hover > th, table.viewTable > tbody > tr.active:hover > th {
  background-color: #e8e8e8;
}

.table > thead > tr > td.success, table.viewTable > thead > tr > td.success, .table > thead > tr > th.success, table.viewTable > thead > tr > th.success, .table > thead > tr.success > td, table.viewTable > thead > tr.success > td, .table > thead > tr.success > th, table.viewTable > thead > tr.success > th, .table > tbody > tr > td.success, table.viewTable > tbody > tr > td.success, .table > tbody > tr > th.success, table.viewTable > tbody > tr > th.success, .table > tbody > tr.success > td, table.viewTable > tbody > tr.success > td, .table > tbody > tr.success > th, table.viewTable > tbody > tr.success > th, .table > tfoot > tr > td.success, table.viewTable > tfoot > tr > td.success, .table > tfoot > tr > th.success, table.viewTable > tfoot > tr > th.success, .table > tfoot > tr.success > td, table.viewTable > tfoot > tr.success > td, .table > tfoot > tr.success > th, table.viewTable > tfoot > tr.success > th {
  background-color: #dff0d8;
}

.table-hover > tbody > tr > td.success:hover, table.viewTable > tbody > tr > td.success:hover, .table-hover > tbody > tr > th.success:hover, table.viewTable > tbody > tr > th.success:hover, .table-hover > tbody > tr.success:hover > td, table.viewTable > tbody > tr.success:hover > td, .table-hover > tbody > tr:hover > .success, table.viewTable > tbody > tr:hover > .success, .table-hover > tbody > tr.success:hover > th, table.viewTable > tbody > tr.success:hover > th {
  background-color: #d0e9c6;
}

.table > thead > tr > td.info, table.viewTable > thead > tr > td.info, .table > thead > tr > th.info, table.viewTable > thead > tr > th.info, .table > thead > tr.info > td, table.viewTable > thead > tr.info > td, .table > thead > tr.info > th, table.viewTable > thead > tr.info > th, .table > tbody > tr > td.info, table.viewTable > tbody > tr > td.info, .table > tbody > tr > th.info, table.viewTable > tbody > tr > th.info, .table > tbody > tr.info > td, table.viewTable > tbody > tr.info > td, .table > tbody > tr.info > th, table.viewTable > tbody > tr.info > th, .table > tfoot > tr > td.info, table.viewTable > tfoot > tr > td.info, .table > tfoot > tr > th.info, table.viewTable > tfoot > tr > th.info, .table > tfoot > tr.info > td, table.viewTable > tfoot > tr.info > td, .table > tfoot > tr.info > th, table.viewTable > tfoot > tr.info > th {
  background-color: #d9edf7;
}

.table-hover > tbody > tr > td.info:hover, table.viewTable > tbody > tr > td.info:hover, .table-hover > tbody > tr > th.info:hover, table.viewTable > tbody > tr > th.info:hover, .table-hover > tbody > tr.info:hover > td, table.viewTable > tbody > tr.info:hover > td, .table-hover > tbody > tr:hover > .info, table.viewTable > tbody > tr:hover > .info, .table-hover > tbody > tr.info:hover > th, table.viewTable > tbody > tr.info:hover > th {
  background-color: #c4e3f3;
}

.table > thead > tr > td.warning, table.viewTable > thead > tr > td.warning, .table > thead > tr > th.warning, table.viewTable > thead > tr > th.warning, .table > thead > tr.warning > td, table.viewTable > thead > tr.warning > td, .table > thead > tr.warning > th, table.viewTable > thead > tr.warning > th, .table > tbody > tr > td.warning, table.viewTable > tbody > tr > td.warning, .table > tbody > tr > th.warning, table.viewTable > tbody > tr > th.warning, .table > tbody > tr.warning > td, table.viewTable > tbody > tr.warning > td, .table > tbody > tr.warning > th, table.viewTable > tbody > tr.warning > th, .table > tfoot > tr > td.warning, table.viewTable > tfoot > tr > td.warning, .table > tfoot > tr > th.warning, table.viewTable > tfoot > tr > th.warning, .table > tfoot > tr.warning > td, table.viewTable > tfoot > tr.warning > td, .table > tfoot > tr.warning > th, table.viewTable > tfoot > tr.warning > th {
  background-color: #fcf8e3;
}

.table-hover > tbody > tr > td.warning:hover, table.viewTable > tbody > tr > td.warning:hover, .table-hover > tbody > tr > th.warning:hover, table.viewTable > tbody > tr > th.warning:hover, .table-hover > tbody > tr.warning:hover > td, table.viewTable > tbody > tr.warning:hover > td, .table-hover > tbody > tr:hover > .warning, table.viewTable > tbody > tr:hover > .warning, .table-hover > tbody > tr.warning:hover > th, table.viewTable > tbody > tr.warning:hover > th {
  background-color: #faf2cc;
}

.table > thead > tr > td.danger, table.viewTable > thead > tr > td.danger, .table > thead > tr > th.danger, table.viewTable > thead > tr > th.danger, .table > thead > tr.danger > td, table.viewTable > thead > tr.danger > td, .table > thead > tr.danger > th, table.viewTable > thead > tr.danger > th, .table > tbody > tr > td.danger, table.viewTable > tbody > tr > td.danger, .table > tbody > tr > th.danger, table.viewTable > tbody > tr > th.danger, .table > tbody > tr.danger > td, table.viewTable > tbody > tr.danger > td, .table > tbody > tr.danger > th, table.viewTable > tbody > tr.danger > th, .table > tfoot > tr > td.danger, table.viewTable > tfoot > tr > td.danger, .table > tfoot > tr > th.danger, table.viewTable > tfoot > tr > th.danger, .table > tfoot > tr.danger > td, table.viewTable > tfoot > tr.danger > td, .table > tfoot > tr.danger > th, table.viewTable > tfoot > tr.danger > th {
  background-color: #f2dede;
}

.table-hover > tbody > tr > td.danger:hover, table.viewTable > tbody > tr > td.danger:hover, .table-hover > tbody > tr > th.danger:hover, table.viewTable > tbody > tr > th.danger:hover, .table-hover > tbody > tr.danger:hover > td, table.viewTable > tbody > tr.danger:hover > td, .table-hover > tbody > tr:hover > .danger, table.viewTable > tbody > tr:hover > .danger, .table-hover > tbody > tr.danger:hover > th, table.viewTable > tbody > tr.danger:hover > th {
  background-color: #ebcccc;
}

.table-responsive {
  overflow-x: auto;
  min-height: 0.01%;
}

@media screen and (max-width: 767px) {
  .table-responsive {
    width: 100%;
    margin-bottom: 15px;
    overflow-y: hidden;
    -ms-overflow-style: -ms-autohiding-scrollbar;
    border: 1px solid #ddd;
    > {
      .table, table.viewTable {
        margin-bottom: 0;
      }
      .table > thead > tr > th, table.viewTable > thead > tr > th, .table > thead > tr > td, table.viewTable > thead > tr > td, .table > tbody > tr > th, table.viewTable > tbody > tr > th, .table > tbody > tr > td, table.viewTable > tbody > tr > td, .table > tfoot > tr > th, table.viewTable > tfoot > tr > th, .table > tfoot > tr > td, table.viewTable > tfoot > tr > td {
        white-space: nowrap;
      }
      .table-bordered, table.viewTable {
        border: 0;
      }
      .table-bordered > thead > tr > th:first-child, table.viewTable > thead > tr > th:first-child, .table-bordered > thead > tr > td:first-child, table.viewTable > thead > tr > td:first-child, .table-bordered > tbody > tr > th:first-child, table.viewTable > tbody > tr > th:first-child, .table-bordered > tbody > tr > td:first-child, table.viewTable > tbody > tr > td:first-child, .table-bordered > tfoot > tr > th:first-child, table.viewTable > tfoot > tr > th:first-child, .table-bordered > tfoot > tr > td:first-child, table.viewTable > tfoot > tr > td:first-child {
        border-left: 0;
      }
      .table-bordered > thead > tr > th:last-child, table.viewTable > thead > tr > th:last-child, .table-bordered > thead > tr > td:last-child, table.viewTable > thead > tr > td:last-child, .table-bordered > tbody > tr > th:last-child, table.viewTable > tbody > tr > th:last-child, .table-bordered > tbody > tr > td:last-child, table.viewTable > tbody > tr > td:last-child, .table-bordered > tfoot > tr > th:last-child, table.viewTable > tfoot > tr > th:last-child, .table-bordered > tfoot > tr > td:last-child, table.viewTable > tfoot > tr > td:last-child {
        border-right: 0;
      }
      .table-bordered > tbody > tr:last-child > th, table.viewTable > tbody > tr:last-child > th, .table-bordered > tbody > tr:last-child > td, table.viewTable > tbody > tr:last-child > td, .table-bordered > tfoot > tr:last-child > th, table.viewTable > tfoot > tr:last-child > th, .table-bordered > tfoot > tr:last-child > td, table.viewTable > tfoot > tr:last-child > td {
        border-bottom: 0;
      }
    }
  }
}

fieldset {
  padding: 0;
  margin: 0;
  border: 0;
  min-width: 0;
}

legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 21px;
  line-height: inherit;
  color: #333;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
}

label {
  display: inline-block;
  max-width: 100%;
  margin-bottom: 5px;
  font-weight: bold;
}

input {
  &[type="search"] {
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
  }
  &[type="radio"], &[type="checkbox"] {
    margin: 4px 0 0;
    margin-top: 1px \9;
    line-height: normal;
  }
  &[type="file"] {
    display: block;
  }
  &[type="range"] {
    display: block;
    width: 100%;
  }
}

select {
  &[multiple], &[size] {
    height: auto;
  }
}

input {
  &[type="file"]:focus, &[type="radio"]:focus, &[type="checkbox"]:focus {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

output {
  display: block;
  padding-top: 7px;
  font-size: 14px;
  line-height: 1.42857;
  color: #555;
}

.form-control, #loginBox form input[type="password"], div.confirm + fieldset form input[type=text], #headerlinks + fieldset + fieldset + fieldset input[type=text] {
  display: block;
  width: 100%;
  height: 34px;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857;
  color: #555;
  background-color: #fff;
  background-image: none;
  border: 1px solid #ccc;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s;
  -webkit-transition: border-color ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s;
  transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
}

input {
  &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
    display: block;
    width: 100%;
    height: 34px;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    color: #555;
    background-color: #fff;
    background-image: none;
    border: 1px solid #ccc;
    border-radius: 4px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -webkit-transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s;
    -webkit-transition: border-color ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
  }
}

select {
  &[name=viewtype], &[name=type] {
    display: block;
    width: 100%;
    height: 34px;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    color: #555;
    background-color: #fff;
    background-image: none;
    border: 1px solid #ccc;
    border-radius: 4px;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    -webkit-transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s;
    -webkit-transition: border-color ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s;
    transition: border-color ease-in-out 0.15s,box-shadow ease-in-out 0.15s,-webkit-box-shadow ease-in-out 0.15s;
  }
}

.form-control:focus, #loginBox form input[type="password"]:focus, div.confirm + fieldset form input[type=text]:focus, #headerlinks + fieldset + fieldset + fieldset input[type=text]:focus {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
}

input {
  &[name=newname]:focus, &[name=tablefields]:focus, &[name=select]:focus, &[name=tablename]:focus, &[name=viewname]:focus, &[name=numRows]:focus, &[name=startRow]:focus {
    border-color: #66afe9;
    outline: 0;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
  }
}

select {
  &[name=viewtype]:focus, &[name=type]:focus {
    border-color: #66afe9;
    outline: 0;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
  }
}

.form-control::-moz-placeholder, #loginBox form input[type="password"]::-moz-placeholder, div.confirm + fieldset form input[type=text]::-moz-placeholder, #headerlinks + fieldset + fieldset + fieldset input[type=text]::-moz-placeholder {
  color: #999;
  opacity: 1;
}

input {
  &[name=newname]::-moz-placeholder, &[name=tablefields]::-moz-placeholder, &[name=select]::-moz-placeholder, &[name=tablename]::-moz-placeholder, &[name=viewname]::-moz-placeholder, &[name=numRows]::-moz-placeholder, &[name=startRow]::-moz-placeholder {
    color: #999;
    opacity: 1;
  }
}

select {
  &[name=viewtype]::-moz-placeholder, &[name=type]::-moz-placeholder {
    color: #999;
    opacity: 1;
  }
}

.form-control:-ms-input-placeholder, #loginBox form input[type="password"]:-ms-input-placeholder, div.confirm + fieldset form input[type=text]:-ms-input-placeholder, #headerlinks + fieldset + fieldset + fieldset input[type=text]:-ms-input-placeholder {
  color: #999;
}

input {
  &[name=newname]:-ms-input-placeholder, &[name=tablefields]:-ms-input-placeholder, &[name=select]:-ms-input-placeholder, &[name=tablename]:-ms-input-placeholder, &[name=viewname]:-ms-input-placeholder, &[name=numRows]:-ms-input-placeholder, &[name=startRow]:-ms-input-placeholder {
    color: #999;
  }
}

select {
  &[name=viewtype]:-ms-input-placeholder, &[name=type]:-ms-input-placeholder {
    color: #999;
  }
}

.form-control::-webkit-input-placeholder, #loginBox form input[type="password"]::-webkit-input-placeholder, div.confirm + fieldset form input[type=text]::-webkit-input-placeholder, #headerlinks + fieldset + fieldset + fieldset input[type=text]::-webkit-input-placeholder {
  color: #999;
}

input {
  &[name=newname]::-webkit-input-placeholder, &[name=tablefields]::-webkit-input-placeholder, &[name=select]::-webkit-input-placeholder, &[name=tablename]::-webkit-input-placeholder, &[name=viewname]::-webkit-input-placeholder, &[name=numRows]::-webkit-input-placeholder, &[name=startRow]::-webkit-input-placeholder {
    color: #999;
  }
}

select {
  &[name=viewtype]::-webkit-input-placeholder, &[name=type]::-webkit-input-placeholder {
    color: #999;
  }
}

.form-control::-ms-expand, #loginBox form input[type="password"]::-ms-expand, div.confirm + fieldset form input[type=text]::-ms-expand, #headerlinks + fieldset + fieldset + fieldset input[type=text]::-ms-expand {
  border: 0;
  background-color: transparent;
}

input {
  &[name=newname]::-ms-expand, &[name=tablefields]::-ms-expand, &[name=select]::-ms-expand, &[name=tablename]::-ms-expand, &[name=viewname]::-ms-expand, &[name=numRows]::-ms-expand, &[name=startRow]::-ms-expand {
    border: 0;
    background-color: transparent;
  }
}

select {
  &[name=viewtype]::-ms-expand, &[name=type]::-ms-expand {
    border: 0;
    background-color: transparent;
  }
}

.form-control[disabled], #loginBox form input[disabled][type="password"], div.confirm + fieldset form input[disabled][type=text], #headerlinks + fieldset + fieldset + fieldset input[disabled][type=text] {
  background-color: #eee;
  opacity: 1;
}

input[disabled] {
  &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
    background-color: #eee;
    opacity: 1;
  }
}

select[disabled] {
  &[name=viewtype], &[name=type] {
    background-color: #eee;
    opacity: 1;
  }
}

.form-control[readonly], #loginBox form input[readonly][type="password"], div.confirm + fieldset form input[readonly][type=text], #headerlinks + fieldset + fieldset + fieldset input[readonly][type=text] {
  background-color: #eee;
  opacity: 1;
}

input[readonly] {
  &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
    background-color: #eee;
    opacity: 1;
  }
}

select[readonly] {
  &[name=viewtype], &[name=type] {
    background-color: #eee;
    opacity: 1;
  }
}

fieldset[disabled] {
  .form-control, #loginBox form input[type="password"] {
    background-color: #eee;
    opacity: 1;
  }
}

#loginBox form fieldset[disabled] input[type="password"], fieldset[disabled] div.confirm + fieldset form input[type=text], div.confirm + fieldset form fieldset[disabled] input[type=text], fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=text] {
  background-color: #eee;
  opacity: 1;
}

fieldset[disabled] {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      background-color: #eee;
      opacity: 1;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      background-color: #eee;
      opacity: 1;
    }
  }
}

.form-control[disabled], #loginBox form input[disabled][type="password"], div.confirm + fieldset form input[disabled][type=text], #headerlinks + fieldset + fieldset + fieldset input[disabled][type=text] {
  cursor: not-allowed;
}

input[disabled] {
  &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
    cursor: not-allowed;
  }
}

select[disabled] {
  &[name=viewtype], &[name=type] {
    cursor: not-allowed;
  }
}

fieldset[disabled] {
  .form-control, #loginBox form input[type="password"] {
    cursor: not-allowed;
  }
}

#loginBox form fieldset[disabled] input[type="password"], fieldset[disabled] div.confirm + fieldset form input[type=text], div.confirm + fieldset form fieldset[disabled] input[type=text], fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=text] {
  cursor: not-allowed;
}

fieldset[disabled] {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      cursor: not-allowed;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      cursor: not-allowed;
    }
  }
}

textarea.form-control {
  height: auto;
}

input[type="search"] {
  -webkit-appearance: none;
}

@media screen and (-webkit-min-device-pixel-ratio: 0) {
  input[type="date"].form-control, #loginBox form input[type="date"][type="password"], div.confirm + fieldset form input[type="date"][type=text], #headerlinks + fieldset + fieldset + fieldset input[type="date"][type=text] {
    line-height: 34px;
  }
  input {
    &[type="date"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
        line-height: 34px;
      }
    }
    &[type="time"].form-control {
      line-height: 34px;
    }
  }
  #loginBox form input[type="time"][type="password"], div.confirm + fieldset form input[type="time"][type=text], #headerlinks + fieldset + fieldset + fieldset input[type="time"][type=text] {
    line-height: 34px;
  }
  input {
    &[type="time"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
        line-height: 34px;
      }
    }
    &[type="datetime-local"].form-control {
      line-height: 34px;
    }
  }
  #loginBox form input[type="datetime-local"][type="password"], div.confirm + fieldset form input[type="datetime-local"][type=text], #headerlinks + fieldset + fieldset + fieldset input[type="datetime-local"][type=text] {
    line-height: 34px;
  }
  input {
    &[type="datetime-local"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
        line-height: 34px;
      }
    }
    &[type="month"].form-control {
      line-height: 34px;
    }
  }
  #loginBox form input[type="month"][type="password"], div.confirm + fieldset form input[type="month"][type=text], #headerlinks + fieldset + fieldset + fieldset input[type="month"][type=text] {
    line-height: 34px;
  }
  input {
    &[type="month"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
        line-height: 34px;
      }
    }
    &[type="date"].input-sm {
      line-height: 30px;
    }
  }
  .input-group-sm > input[type="date"].form-control, #loginBox form .input-group-sm > input[type="date"][type="password"], div.confirm + fieldset form .input-group-sm > input[type="date"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input[type="date"][type=text] {
    line-height: 30px;
  }
  .input-group-sm > {
    input[type="date"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 30px;
      }
    }
    .input-group-btn > input[type="date"].btn {
      line-height: 30px;
    }
  }
  #loginBox form .input-group-sm > .input-group-btn > input[type="date"][type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input[type="date"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input[type="date"][type=submit] {
    line-height: 30px;
  }
  .input-group-sm {
    > .input-group-btn > input[type="date"][name=logout], input[type="date"] {
      line-height: 30px;
    }
  }
  input[type="time"].input-sm, .input-group-sm > input[type="time"].form-control, #loginBox form .input-group-sm > input[type="time"][type="password"], div.confirm + fieldset form .input-group-sm > input[type="time"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input[type="time"][type=text] {
    line-height: 30px;
  }
  .input-group-sm > {
    input[type="time"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 30px;
      }
    }
    .input-group-btn > input[type="time"].btn {
      line-height: 30px;
    }
  }
  #loginBox form .input-group-sm > .input-group-btn > input[type="time"][type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input[type="time"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input[type="time"][type=submit] {
    line-height: 30px;
  }
  .input-group-sm {
    > .input-group-btn > input[type="time"][name=logout], input[type="time"] {
      line-height: 30px;
    }
  }
  input[type="datetime-local"].input-sm, .input-group-sm > input[type="datetime-local"].form-control, #loginBox form .input-group-sm > input[type="datetime-local"][type="password"], div.confirm + fieldset form .input-group-sm > input[type="datetime-local"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input[type="datetime-local"][type=text] {
    line-height: 30px;
  }
  .input-group-sm > {
    input[type="datetime-local"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 30px;
      }
    }
    .input-group-btn > input[type="datetime-local"].btn {
      line-height: 30px;
    }
  }
  #loginBox form .input-group-sm > .input-group-btn > input[type="datetime-local"][type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input[type="datetime-local"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input[type="datetime-local"][type=submit] {
    line-height: 30px;
  }
  .input-group-sm {
    > .input-group-btn > input[type="datetime-local"][name=logout], input[type="datetime-local"] {
      line-height: 30px;
    }
  }
  input[type="month"].input-sm, .input-group-sm > input[type="month"].form-control, #loginBox form .input-group-sm > input[type="month"][type="password"], div.confirm + fieldset form .input-group-sm > input[type="month"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input[type="month"][type=text] {
    line-height: 30px;
  }
  .input-group-sm > {
    input[type="month"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 30px;
      }
    }
    .input-group-btn > input[type="month"].btn {
      line-height: 30px;
    }
  }
  #loginBox form .input-group-sm > .input-group-btn > input[type="month"][type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input[type="month"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input[type="month"][type=submit] {
    line-height: 30px;
  }
  .input-group-sm {
    > .input-group-btn > input[type="month"][name=logout], input[type="month"] {
      line-height: 30px;
    }
  }
  input[type="date"].input-lg, .input-group-lg > input[type="date"].form-control, #loginBox form .input-group-lg > input[type="date"][type="password"], div.confirm + fieldset form .input-group-lg > input[type="date"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input[type="date"][type=text] {
    line-height: 46px;
  }
  .input-group-lg > {
    input[type="date"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 46px;
      }
    }
    .input-group-btn > input[type="date"].btn {
      line-height: 46px;
    }
  }
  #loginBox form .input-group-lg > .input-group-btn > input[type="date"][type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input[type="date"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input[type="date"][type=submit] {
    line-height: 46px;
  }
  .input-group-lg {
    > .input-group-btn > input[type="date"][name=logout], input[type="date"] {
      line-height: 46px;
    }
  }
  input[type="time"].input-lg, .input-group-lg > input[type="time"].form-control, #loginBox form .input-group-lg > input[type="time"][type="password"], div.confirm + fieldset form .input-group-lg > input[type="time"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input[type="time"][type=text] {
    line-height: 46px;
  }
  .input-group-lg > {
    input[type="time"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 46px;
      }
    }
    .input-group-btn > input[type="time"].btn {
      line-height: 46px;
    }
  }
  #loginBox form .input-group-lg > .input-group-btn > input[type="time"][type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input[type="time"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input[type="time"][type=submit] {
    line-height: 46px;
  }
  .input-group-lg {
    > .input-group-btn > input[type="time"][name=logout], input[type="time"] {
      line-height: 46px;
    }
  }
  input[type="datetime-local"].input-lg, .input-group-lg > input[type="datetime-local"].form-control, #loginBox form .input-group-lg > input[type="datetime-local"][type="password"], div.confirm + fieldset form .input-group-lg > input[type="datetime-local"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input[type="datetime-local"][type=text] {
    line-height: 46px;
  }
  .input-group-lg > {
    input[type="datetime-local"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 46px;
      }
    }
    .input-group-btn > input[type="datetime-local"].btn {
      line-height: 46px;
    }
  }
  #loginBox form .input-group-lg > .input-group-btn > input[type="datetime-local"][type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input[type="datetime-local"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input[type="datetime-local"][type=submit] {
    line-height: 46px;
  }
  .input-group-lg {
    > .input-group-btn > input[type="datetime-local"][name=logout], input[type="datetime-local"] {
      line-height: 46px;
    }
  }
  input[type="month"].input-lg, .input-group-lg > input[type="month"].form-control, #loginBox form .input-group-lg > input[type="month"][type="password"], div.confirm + fieldset form .input-group-lg > input[type="month"][type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input[type="month"][type=text] {
    line-height: 46px;
  }
  .input-group-lg > {
    input[type="month"] {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow], &.input-group-addon {
        line-height: 46px;
      }
    }
    .input-group-btn > input[type="month"].btn {
      line-height: 46px;
    }
  }
  #loginBox form .input-group-lg > .input-group-btn > input[type="month"][type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input[type="month"][type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input[type="month"][type=submit] {
    line-height: 46px;
  }
  .input-group-lg {
    > .input-group-btn > input[type="month"][name=logout], input[type="month"] {
      line-height: 46px;
    }
  }
}

.form-group {
  margin-bottom: 15px;
}

.radio, .checkbox {
  position: relative;
  display: block;
  margin-top: 10px;
  margin-bottom: 10px;
}

.radio label, .checkbox label {
  min-height: 20px;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: normal;
  cursor: pointer;
}

.radio input[type="radio"], .radio-inline input[type="radio"], .checkbox input[type="checkbox"], .checkbox-inline input[type="checkbox"] {
  position: absolute;
  margin-left: -20px;
  margin-top: 4px \9;
}

.radio + .radio, .checkbox + .checkbox {
  margin-top: -5px;
}

.radio-inline, .checkbox-inline {
  position: relative;
  display: inline-block;
  padding-left: 20px;
  margin-bottom: 0;
  vertical-align: middle;
  font-weight: normal;
  cursor: pointer;
}

.radio-inline + .radio-inline, .checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 10px;
}

input[type="radio"] {
  &[disabled], &.disabled {
    cursor: not-allowed;
  }
}

fieldset[disabled] input[type="radio"] {
  cursor: not-allowed;
}

input[type="checkbox"] {
  &[disabled], &.disabled {
    cursor: not-allowed;
  }
}

fieldset[disabled] input[type="checkbox"], .radio-inline.disabled, fieldset[disabled] .radio-inline, .checkbox-inline.disabled, fieldset[disabled] .checkbox-inline, .radio.disabled label, fieldset[disabled] .radio label, .checkbox.disabled label, fieldset[disabled] .checkbox label {
  cursor: not-allowed;
}

.form-control-static {
  padding-top: 7px;
  padding-bottom: 7px;
  margin-bottom: 0;
  min-height: 34px;
  &.input-lg {
    padding-left: 0;
    padding-right: 0;
  }
}

.input-group-lg > .form-control-static.form-control, #loginBox form .input-group-lg > input.form-control-static[type="password"], div.confirm + fieldset form .input-group-lg > input.form-control-static[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input.form-control-static[type=text] {
  padding-left: 0;
  padding-right: 0;
}

.input-group-lg > {
  input.form-control-static {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      padding-left: 0;
      padding-right: 0;
    }
  }
  select.form-control-static {
    &[name=viewtype], &[name=type] {
      padding-left: 0;
      padding-right: 0;
    }
  }
  .form-control-static.input-group-addon, .input-group-btn > .form-control-static.btn {
    padding-left: 0;
    padding-right: 0;
  }
}

#loginBox form .input-group-lg > .input-group-btn > input.form-control-static[type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input.form-control-static[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input.form-control-static[type=submit] {
  padding-left: 0;
  padding-right: 0;
}

.input-group-lg > .input-group-btn > input {
  &.form-control-static[name=logout], &[name="database_delete"] + input[type="submit"] + a.form-control-static, &[value=Confirm] + a.form-control-static:hover {
    padding-left: 0;
    padding-right: 0;
  }
}

.form-control-static.input-sm, .input-group-sm > .form-control-static.form-control, #loginBox form .input-group-sm > input.form-control-static[type="password"], div.confirm + fieldset form .input-group-sm > input.form-control-static[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input.form-control-static[type=text] {
  padding-left: 0;
  padding-right: 0;
}

.input-group-sm > {
  input.form-control-static {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      padding-left: 0;
      padding-right: 0;
    }
  }
  select.form-control-static {
    &[name=viewtype], &[name=type] {
      padding-left: 0;
      padding-right: 0;
    }
  }
  .form-control-static.input-group-addon, .input-group-btn > .form-control-static.btn {
    padding-left: 0;
    padding-right: 0;
  }
}

#loginBox form .input-group-sm > .input-group-btn > input.form-control-static[type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input.form-control-static[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input.form-control-static[type=submit] {
  padding-left: 0;
  padding-right: 0;
}

.input-group-sm > .input-group-btn > input {
  &.form-control-static[name=logout], &[name="database_delete"] + input[type="submit"] + a.form-control-static, &[value=Confirm] + a.form-control-static:hover {
    padding-left: 0;
    padding-right: 0;
  }
}

.input-sm, .input-group-sm > .form-control, #loginBox form .input-group-sm > input[type="password"], div.confirm + fieldset form .input-group-sm > input[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input[type=text] {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

.input-group-sm > {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      height: 30px;
      padding: 5px 10px;
      font-size: 12px;
      line-height: 1.5;
      border-radius: 3px;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      height: 30px;
      padding: 5px 10px;
      font-size: 12px;
      line-height: 1.5;
      border-radius: 3px;
    }
  }
  .input-group-addon, .input-group-btn > .btn {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px;
  }
}

#loginBox form .input-group-sm > .input-group-btn > input[type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input[type=submit] {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

.input-group-sm > .input-group-btn > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px;
  }
}

select.input-sm {
  height: 30px;
  line-height: 30px;
}

.input-group-sm > {
  select {
    &.form-control, &[name=viewtype], &[name=type], &.input-group-addon {
      height: 30px;
      line-height: 30px;
    }
  }
  .input-group-btn > select.btn {
    height: 30px;
    line-height: 30px;
  }
}

textarea.input-sm {
  height: auto;
}

.input-group-sm > {
  textarea {
    &.form-control, &.input-group-addon {
      height: auto;
    }
  }
  .input-group-btn > textarea.btn {
    height: auto;
  }
}

select[multiple].input-sm {
  height: auto;
}

.input-group-sm > {
  select[multiple] {
    &.form-control, &[name=viewtype], &[name=type], &.input-group-addon {
      height: auto;
    }
  }
  .input-group-btn > select[multiple].btn {
    height: auto;
  }
}

.form-group-sm {
  .form-control, #loginBox form input[type="password"] {
    height: 30px;
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px;
  }
}

#loginBox form .form-group-sm input[type="password"], .form-group-sm div.confirm + fieldset form input[type=text], div.confirm + fieldset form .form-group-sm input[type=text], .form-group-sm #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-group-sm input[type=text] {
  height: 30px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

.form-group-sm {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      height: 30px;
      padding: 5px 10px;
      font-size: 12px;
      line-height: 1.5;
      border-radius: 3px;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      height: 30px;
      padding: 5px 10px;
      font-size: 12px;
      line-height: 1.5;
      border-radius: 3px;
    }
    &.form-control, &[name=viewtype], &[name=type] {
      height: 30px;
      line-height: 30px;
    }
  }
  textarea.form-control {
    height: auto;
  }
  select[multiple] {
    &.form-control, &[name=viewtype], &[name=type] {
      height: auto;
    }
  }
  .form-control-static {
    height: 30px;
    min-height: 32px;
    padding: 6px 10px;
    font-size: 12px;
    line-height: 1.5;
  }
}

.input-lg, .input-group-lg > .form-control, #loginBox form .input-group-lg > input[type="password"], div.confirm + fieldset form .input-group-lg > input[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input[type=text] {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33333;
  border-radius: 6px;
}

.input-group-lg > {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      height: 46px;
      padding: 10px 16px;
      font-size: 18px;
      line-height: 1.33333;
      border-radius: 6px;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      height: 46px;
      padding: 10px 16px;
      font-size: 18px;
      line-height: 1.33333;
      border-radius: 6px;
    }
  }
  .input-group-addon, .input-group-btn > .btn {
    height: 46px;
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px;
  }
}

#loginBox form .input-group-lg > .input-group-btn > input[type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input[type=submit] {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33333;
  border-radius: 6px;
}

.input-group-lg > .input-group-btn > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    height: 46px;
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px;
  }
}

select.input-lg {
  height: 46px;
  line-height: 46px;
}

.input-group-lg > {
  select {
    &.form-control, &[name=viewtype], &[name=type], &.input-group-addon {
      height: 46px;
      line-height: 46px;
    }
  }
  .input-group-btn > select.btn {
    height: 46px;
    line-height: 46px;
  }
}

textarea.input-lg {
  height: auto;
}

.input-group-lg > {
  textarea {
    &.form-control, &.input-group-addon {
      height: auto;
    }
  }
  .input-group-btn > textarea.btn {
    height: auto;
  }
}

select[multiple].input-lg {
  height: auto;
}

.input-group-lg > {
  select[multiple] {
    &.form-control, &[name=viewtype], &[name=type], &.input-group-addon {
      height: auto;
    }
  }
  .input-group-btn > select[multiple].btn {
    height: auto;
  }
}

.form-group-lg {
  .form-control, #loginBox form input[type="password"] {
    height: 46px;
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px;
  }
}

#loginBox form .form-group-lg input[type="password"], .form-group-lg div.confirm + fieldset form input[type=text], div.confirm + fieldset form .form-group-lg input[type=text], .form-group-lg #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-group-lg input[type=text] {
  height: 46px;
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33333;
  border-radius: 6px;
}

.form-group-lg {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      height: 46px;
      padding: 10px 16px;
      font-size: 18px;
      line-height: 1.33333;
      border-radius: 6px;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      height: 46px;
      padding: 10px 16px;
      font-size: 18px;
      line-height: 1.33333;
      border-radius: 6px;
    }
    &.form-control, &[name=viewtype], &[name=type] {
      height: 46px;
      line-height: 46px;
    }
  }
  textarea.form-control {
    height: auto;
  }
  select[multiple] {
    &.form-control, &[name=viewtype], &[name=type] {
      height: auto;
    }
  }
  .form-control-static {
    height: 46px;
    min-height: 38px;
    padding: 11px 16px;
    font-size: 18px;
    line-height: 1.33333;
  }
}

.has-feedback {
  position: relative;
  .form-control, #loginBox form input[type="password"] {
    padding-right: 42.5px;
  }
}

#loginBox form .has-feedback input[type="password"], .has-feedback div.confirm + fieldset form input[type=text], div.confirm + fieldset form .has-feedback input[type=text], .has-feedback #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .has-feedback input[type=text] {
  padding-right: 42.5px;
}

.has-feedback {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      padding-right: 42.5px;
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      padding-right: 42.5px;
    }
  }
}

.form-control-feedback {
  position: absolute;
  top: 0;
  right: 0;
  z-index: 2;
  display: block;
  width: 34px;
  height: 34px;
  line-height: 34px;
  text-align: center;
  pointer-events: none;
}

.input-lg + .form-control-feedback, .input-group-lg > .form-control + .form-control-feedback, #loginBox form .input-group-lg > input[type="password"] + .form-control-feedback, div.confirm + fieldset form .input-group-lg > input[type=text] + .form-control-feedback, #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input[type=text] + .form-control-feedback {
  width: 46px;
  height: 46px;
  line-height: 46px;
}

.input-group-lg > {
  input {
    &[name=newname] + .form-control-feedback, &[name=tablefields] + .form-control-feedback, &[name=select] + .form-control-feedback, &[name=tablename] + .form-control-feedback, &[name=viewname] + .form-control-feedback, &[name=numRows] + .form-control-feedback, &[name=startRow] + .form-control-feedback {
      width: 46px;
      height: 46px;
      line-height: 46px;
    }
  }
  select {
    &[name=viewtype] + .form-control-feedback, &[name=type] + .form-control-feedback {
      width: 46px;
      height: 46px;
      line-height: 46px;
    }
  }
  .input-group-addon + .form-control-feedback, .input-group-btn > .btn + .form-control-feedback {
    width: 46px;
    height: 46px;
    line-height: 46px;
  }
}

#loginBox form .input-group-lg > .input-group-btn > input[type="submit"] + .form-control-feedback, div.confirm + fieldset form .input-group-lg > .input-group-btn > input[type=submit] + .form-control-feedback, #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input[type=submit] + .form-control-feedback {
  width: 46px;
  height: 46px;
  line-height: 46px;
}

.input-group-lg {
  > .input-group-btn > input {
    &[name=logout] + .form-control-feedback, &[name="database_delete"] + input[type="submit"] + a + .form-control-feedback, &[value=Confirm] + a:hover + .form-control-feedback {
      width: 46px;
      height: 46px;
      line-height: 46px;
    }
  }
  + .form-control-feedback {
    width: 46px;
    height: 46px;
    line-height: 46px;
  }
}

.form-group-lg {
  .form-control + .form-control-feedback, #loginBox form input[type="password"] + .form-control-feedback {
    width: 46px;
    height: 46px;
    line-height: 46px;
  }
}

#loginBox form .form-group-lg input[type="password"] + .form-control-feedback, .form-group-lg div.confirm + fieldset form input[type=text] + .form-control-feedback, div.confirm + fieldset form .form-group-lg input[type=text] + .form-control-feedback, .form-group-lg #headerlinks + fieldset + fieldset + fieldset input[type=text] + .form-control-feedback, #headerlinks + fieldset + fieldset + fieldset .form-group-lg input[type=text] + .form-control-feedback {
  width: 46px;
  height: 46px;
  line-height: 46px;
}

.form-group-lg {
  input {
    &[name=newname] + .form-control-feedback, &[name=tablefields] + .form-control-feedback, &[name=select] + .form-control-feedback, &[name=tablename] + .form-control-feedback, &[name=viewname] + .form-control-feedback, &[name=numRows] + .form-control-feedback, &[name=startRow] + .form-control-feedback {
      width: 46px;
      height: 46px;
      line-height: 46px;
    }
  }
  select {
    &[name=viewtype] + .form-control-feedback, &[name=type] + .form-control-feedback {
      width: 46px;
      height: 46px;
      line-height: 46px;
    }
  }
}

.input-sm + .form-control-feedback, .input-group-sm > .form-control + .form-control-feedback, #loginBox form .input-group-sm > input[type="password"] + .form-control-feedback, div.confirm + fieldset form .input-group-sm > input[type=text] + .form-control-feedback, #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input[type=text] + .form-control-feedback {
  width: 30px;
  height: 30px;
  line-height: 30px;
}

.input-group-sm > {
  input {
    &[name=newname] + .form-control-feedback, &[name=tablefields] + .form-control-feedback, &[name=select] + .form-control-feedback, &[name=tablename] + .form-control-feedback, &[name=viewname] + .form-control-feedback, &[name=numRows] + .form-control-feedback, &[name=startRow] + .form-control-feedback {
      width: 30px;
      height: 30px;
      line-height: 30px;
    }
  }
  select {
    &[name=viewtype] + .form-control-feedback, &[name=type] + .form-control-feedback {
      width: 30px;
      height: 30px;
      line-height: 30px;
    }
  }
  .input-group-addon + .form-control-feedback, .input-group-btn > .btn + .form-control-feedback {
    width: 30px;
    height: 30px;
    line-height: 30px;
  }
}

#loginBox form .input-group-sm > .input-group-btn > input[type="submit"] + .form-control-feedback, div.confirm + fieldset form .input-group-sm > .input-group-btn > input[type=submit] + .form-control-feedback, #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input[type=submit] + .form-control-feedback {
  width: 30px;
  height: 30px;
  line-height: 30px;
}

.input-group-sm {
  > .input-group-btn > input {
    &[name=logout] + .form-control-feedback, &[name="database_delete"] + input[type="submit"] + a + .form-control-feedback, &[value=Confirm] + a:hover + .form-control-feedback {
      width: 30px;
      height: 30px;
      line-height: 30px;
    }
  }
  + .form-control-feedback {
    width: 30px;
    height: 30px;
    line-height: 30px;
  }
}

.form-group-sm {
  .form-control + .form-control-feedback, #loginBox form input[type="password"] + .form-control-feedback {
    width: 30px;
    height: 30px;
    line-height: 30px;
  }
}

#loginBox form .form-group-sm input[type="password"] + .form-control-feedback, .form-group-sm div.confirm + fieldset form input[type=text] + .form-control-feedback, div.confirm + fieldset form .form-group-sm input[type=text] + .form-control-feedback, .form-group-sm #headerlinks + fieldset + fieldset + fieldset input[type=text] + .form-control-feedback, #headerlinks + fieldset + fieldset + fieldset .form-group-sm input[type=text] + .form-control-feedback {
  width: 30px;
  height: 30px;
  line-height: 30px;
}

.form-group-sm {
  input {
    &[name=newname] + .form-control-feedback, &[name=tablefields] + .form-control-feedback, &[name=select] + .form-control-feedback, &[name=tablename] + .form-control-feedback, &[name=viewname] + .form-control-feedback, &[name=numRows] + .form-control-feedback, &[name=startRow] + .form-control-feedback {
      width: 30px;
      height: 30px;
      line-height: 30px;
    }
  }
  select {
    &[name=viewtype] + .form-control-feedback, &[name=type] + .form-control-feedback {
      width: 30px;
      height: 30px;
      line-height: 30px;
    }
  }
}

.has-success {
  .help-block, .control-label, .radio, .checkbox, .radio-inline, .checkbox-inline, &.radio label, &.checkbox label, &.radio-inline label, &.checkbox-inline label {
    color: #3c763d;
  }
  .form-control, #loginBox form input[type="password"] {
    border-color: #3c763d;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  }
}

#loginBox form .has-success input[type="password"], .has-success div.confirm + fieldset form input[type=text], div.confirm + fieldset form .has-success input[type=text], .has-success #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .has-success input[type=text] {
  border-color: #3c763d;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.has-success {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      border-color: #3c763d;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      border-color: #3c763d;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    }
  }
  .form-control:focus, #loginBox form input[type="password"]:focus {
    border-color: #2b542c;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
  }
}

#loginBox form .has-success input[type="password"]:focus, .has-success div.confirm + fieldset form input[type=text]:focus, div.confirm + fieldset form .has-success input[type=text]:focus, .has-success #headerlinks + fieldset + fieldset + fieldset input[type=text]:focus, #headerlinks + fieldset + fieldset + fieldset .has-success input[type=text]:focus {
  border-color: #2b542c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
}

.has-success {
  input {
    &[name=newname]:focus, &[name=tablefields]:focus, &[name=select]:focus, &[name=tablename]:focus, &[name=viewname]:focus, &[name=numRows]:focus, &[name=startRow]:focus {
      border-color: #2b542c;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
    }
  }
  select {
    &[name=viewtype]:focus, &[name=type]:focus {
      border-color: #2b542c;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
    }
  }
  .input-group-addon {
    color: #3c763d;
    border-color: #3c763d;
    background-color: #dff0d8;
  }
  .form-control-feedback {
    color: #3c763d;
  }
}

.has-warning {
  .help-block, .control-label, .radio, .checkbox, .radio-inline, .checkbox-inline, &.radio label, &.checkbox label, &.radio-inline label, &.checkbox-inline label {
    color: #8a6d3b;
  }
  .form-control, #loginBox form input[type="password"] {
    border-color: #8a6d3b;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  }
}

#loginBox form .has-warning input[type="password"], .has-warning div.confirm + fieldset form input[type=text], div.confirm + fieldset form .has-warning input[type=text], .has-warning #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .has-warning input[type=text] {
  border-color: #8a6d3b;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.has-warning {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      border-color: #8a6d3b;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      border-color: #8a6d3b;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    }
  }
  .form-control:focus, #loginBox form input[type="password"]:focus {
    border-color: #66512c;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
  }
}

#loginBox form .has-warning input[type="password"]:focus, .has-warning div.confirm + fieldset form input[type=text]:focus, div.confirm + fieldset form .has-warning input[type=text]:focus, .has-warning #headerlinks + fieldset + fieldset + fieldset input[type=text]:focus, #headerlinks + fieldset + fieldset + fieldset .has-warning input[type=text]:focus {
  border-color: #66512c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
}

.has-warning {
  input {
    &[name=newname]:focus, &[name=tablefields]:focus, &[name=select]:focus, &[name=tablename]:focus, &[name=viewname]:focus, &[name=numRows]:focus, &[name=startRow]:focus {
      border-color: #66512c;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
    }
  }
  select {
    &[name=viewtype]:focus, &[name=type]:focus {
      border-color: #66512c;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
    }
  }
  .input-group-addon {
    color: #8a6d3b;
    border-color: #8a6d3b;
    background-color: #fcf8e3;
  }
  .form-control-feedback {
    color: #8a6d3b;
  }
}

.has-error {
  .help-block, .control-label, .radio, .checkbox, .radio-inline, .checkbox-inline, &.radio label, &.checkbox label, &.radio-inline label, &.checkbox-inline label {
    color: #a94442;
  }
  .form-control, #loginBox form input[type="password"] {
    border-color: #a94442;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  }
}

#loginBox form .has-error input[type="password"], .has-error div.confirm + fieldset form input[type=text], div.confirm + fieldset form .has-error input[type=text], .has-error #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .has-error input[type=text] {
  border-color: #a94442;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.has-error {
  input {
    &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
      border-color: #a94442;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    }
  }
  select {
    &[name=viewtype], &[name=type] {
      border-color: #a94442;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
    }
  }
  .form-control:focus, #loginBox form input[type="password"]:focus {
    border-color: #843534;
    -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
  }
}

#loginBox form .has-error input[type="password"]:focus, .has-error div.confirm + fieldset form input[type=text]:focus, div.confirm + fieldset form .has-error input[type=text]:focus, .has-error #headerlinks + fieldset + fieldset + fieldset input[type=text]:focus, #headerlinks + fieldset + fieldset + fieldset .has-error input[type=text]:focus {
  border-color: #843534;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
}

.has-error {
  input {
    &[name=newname]:focus, &[name=tablefields]:focus, &[name=select]:focus, &[name=tablename]:focus, &[name=viewname]:focus, &[name=numRows]:focus, &[name=startRow]:focus {
      border-color: #843534;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
    }
  }
  select {
    &[name=viewtype]:focus, &[name=type]:focus {
      border-color: #843534;
      -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
      box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
    }
  }
  .input-group-addon {
    color: #a94442;
    border-color: #a94442;
    background-color: #f2dede;
  }
  .form-control-feedback {
    color: #a94442;
  }
}

.has-feedback label {
  ~ .form-control-feedback {
    top: 25px;
  }
  &.sr-only ~ .form-control-feedback {
    top: 0;
  }
}

.help-block {
  display: block;
  margin-top: 5px;
  margin-bottom: 10px;
  color: #737373;
}

@media (min-width: 768px) {
  .form-inline {
    .form-group {
      display: inline-block;
      margin-bottom: 0;
      vertical-align: middle;
    }
    .form-control, #loginBox form input[type="password"] {
      display: inline-block;
      width: auto;
      vertical-align: middle;
    }
  }
  #loginBox form .form-inline input[type="password"], .form-inline div.confirm + fieldset form input[type=text], div.confirm + fieldset form .form-inline input[type=text], .form-inline #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-inline input[type=text] {
    display: inline-block;
    width: auto;
    vertical-align: middle;
  }
  .form-inline {
    input {
      &[name=newname], &[name=tablefields], &[name=select], &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
        display: inline-block;
        width: auto;
        vertical-align: middle;
      }
    }
    select {
      &[name=viewtype], &[name=type] {
        display: inline-block;
        width: auto;
        vertical-align: middle;
      }
    }
    .form-control-static {
      display: inline-block;
    }
    .input-group, div.confirm + fieldset form {
      display: inline-table;
      vertical-align: middle;
    }
  }
  div.confirm + fieldset .form-inline form {
    display: inline-table;
    vertical-align: middle;
  }
  .form-inline {
    .input-group .input-group-addon, div.confirm + fieldset form .input-group-addon {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form .input-group-addon {
    width: auto;
  }
  .form-inline {
    .input-group .input-group-btn, div.confirm + fieldset form .input-group-btn {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form .input-group-btn {
    width: auto;
  }
  .form-inline {
    .input-group .form-control, div.confirm + fieldset form .form-control {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form .form-control, .form-inline .input-group #loginBox form input[type="password"], #loginBox form .form-inline .input-group input[type="password"], .form-inline div.confirm + fieldset #loginBox form input[type="password"], #loginBox .form-inline div.confirm + fieldset form input[type="password"], div.confirm + fieldset .form-inline #loginBox form input[type="password"], #loginBox div.confirm + fieldset .form-inline form input[type="password"], div.confirm + fieldset form .form-inline .input-group input[type=text], .form-inline div.confirm + fieldset form input[type=text], div.confirm + fieldset .form-inline form input[type=text], .form-inline .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-inline .input-group input[type=text], .form-inline div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-inline div.confirm + fieldset form input[type=text], div.confirm + fieldset .form-inline form #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset .form-inline form input[type=text] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=newname], div.confirm + fieldset form input[name=newname] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=newname] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=tablefields], div.confirm + fieldset form input[name=tablefields] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=tablefields] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=select], div.confirm + fieldset form input[name=select] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=select] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=tablename], div.confirm + fieldset form input[name=tablename] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=tablename] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=viewname], div.confirm + fieldset form input[name=viewname] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=viewname] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=numRows], div.confirm + fieldset form input[name=numRows] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=numRows] {
    width: auto;
  }
  .form-inline {
    .input-group input[name=startRow], div.confirm + fieldset form input[name=startRow] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form input[name=startRow] {
    width: auto;
  }
  .form-inline {
    .input-group select[name=viewtype], div.confirm + fieldset form select[name=viewtype] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form select[name=viewtype] {
    width: auto;
  }
  .form-inline {
    .input-group select[name=type], div.confirm + fieldset form select[name=type] {
      width: auto;
    }
  }
  div.confirm + fieldset .form-inline form select[name=type] {
    width: auto;
  }
  .form-inline {
    .input-group > .form-control, div.confirm + fieldset form > .form-control {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > .form-control, .form-inline #loginBox form .input-group > input[type="password"], #loginBox form .form-inline .input-group > input[type="password"], .form-inline div.confirm + fieldset #loginBox form > input[type="password"], #loginBox .form-inline div.confirm + fieldset form > input[type="password"], div.confirm + fieldset .form-inline #loginBox form > input[type="password"], #loginBox div.confirm + fieldset .form-inline form > input[type="password"], .form-inline div.confirm + fieldset form .input-group > input[type=text], div.confirm + fieldset form .form-inline .input-group > input[type=text], .form-inline div.confirm + fieldset form > input[type=text], div.confirm + fieldset .form-inline form > input[type=text], .form-inline #headerlinks + fieldset + fieldset + fieldset .input-group > input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-inline .input-group > input[type=text], .form-inline div.confirm + fieldset #headerlinks + fieldset + fieldset + fieldset form > input[type=text], #headerlinks + fieldset + fieldset + fieldset .form-inline div.confirm + fieldset form > input[type=text], div.confirm + fieldset .form-inline #headerlinks + fieldset + fieldset + fieldset form > input[type=text], #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset .form-inline form > input[type=text] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=newname], div.confirm + fieldset form > input[name=newname] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=newname] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=tablefields], div.confirm + fieldset form > input[name=tablefields] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=tablefields] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=select], div.confirm + fieldset form > input[name=select] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=select] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=tablename], div.confirm + fieldset form > input[name=tablename] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=tablename] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=viewname], div.confirm + fieldset form > input[name=viewname] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=viewname] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=numRows], div.confirm + fieldset form > input[name=numRows] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=numRows] {
    width: 100%;
  }
  .form-inline {
    .input-group > input[name=startRow], div.confirm + fieldset form > input[name=startRow] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > input[name=startRow] {
    width: 100%;
  }
  .form-inline {
    .input-group > select[name=viewtype], div.confirm + fieldset form > select[name=viewtype] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > select[name=viewtype] {
    width: 100%;
  }
  .form-inline {
    .input-group > select[name=type], div.confirm + fieldset form > select[name=type] {
      width: 100%;
    }
  }
  div.confirm + fieldset .form-inline form > select[name=type] {
    width: 100%;
  }
  .form-inline {
    .control-label {
      margin-bottom: 0;
      vertical-align: middle;
    }
    .radio, .checkbox {
      display: inline-block;
      margin-top: 0;
      margin-bottom: 0;
      vertical-align: middle;
    }
    .radio label, .checkbox label {
      padding-left: 0;
    }
    .radio input[type="radio"], .checkbox input[type="checkbox"] {
      position: relative;
      margin-left: 0;
    }
    .has-feedback .form-control-feedback {
      top: 0;
    }
  }
}

.form-horizontal {
  .radio, .checkbox, .radio-inline, .checkbox-inline {
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 7px;
  }
  .radio, .checkbox {
    min-height: 27px;
  }
  .form-group {
    margin-left: -15px;
    margin-right: -15px;
    &:before {
      content: " ";
      display: table;
    }
    &:after {
      content: " ";
      display: table;
      clear: both;
    }
  }
  .has-feedback .form-control-feedback {
    right: 15px;
  }
}

@media (min-width: 768px) {
  .form-horizontal .control-label {
    text-align: right;
    margin-bottom: 0;
    padding-top: 7px;
  }
}

@media (min-width: 768px) {
  .form-horizontal .form-group-lg .control-label {
    padding-top: 11px;
    font-size: 18px;
  }
}

@media (min-width: 768px) {
  .form-horizontal .form-group-sm .control-label {
    padding-top: 6px;
    font-size: 12px;
  }
}

.btn, #loginBox form input[type="submit"], div.confirm + fieldset form input[type=submit], #headerlinks + fieldset + fieldset + fieldset input[type=submit] {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  vertical-align: middle;
  -ms-touch-action: manipulation;
  touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  white-space: nowrap;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    display: inline-block;
    margin-bottom: 0;
    font-weight: normal;
    text-align: center;
    vertical-align: middle;
    -ms-touch-action: manipulation;
    touch-action: manipulation;
    cursor: pointer;
    background-image: none;
    border: 1px solid transparent;
    white-space: nowrap;
    padding: 6px 12px;
    font-size: 14px;
    line-height: 1.42857;
    border-radius: 4px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
  }
}

.btn:focus, #loginBox form input[type="submit"]:focus, div.confirm + fieldset form input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input {
  &[name=logout]:focus, &[name="database_delete"] + input[type="submit"] + a:focus, &[value=Confirm] + a:focus:hover {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

.btn.focus, #loginBox form input.focus[type="submit"], div.confirm + fieldset form input.focus[type=submit], #headerlinks + fieldset + fieldset + fieldset input.focus[type=submit] {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input {
  &.focus[name=logout], &[name="database_delete"] + input[type="submit"] + a.focus, &[value=Confirm] + a.focus:hover {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

.btn:active:focus, #loginBox form input[type="submit"]:active:focus, div.confirm + fieldset form input[type=submit]:active:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active:focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input {
  &[name=logout]:active:focus, &[name="database_delete"] + input[type="submit"] + a:active:focus, &[value=Confirm] + a:active:focus:hover {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

.btn:active.focus, #loginBox form input[type="submit"]:active.focus, div.confirm + fieldset form input[type=submit]:active.focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active.focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input {
  &[name=logout]:active.focus, &[name="database_delete"] + input[type="submit"] + a:active.focus, &[value=Confirm] + a:active.focus:hover {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

.btn.active:focus, #loginBox form input.active[type="submit"]:focus, div.confirm + fieldset form input.active[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset input.active[type=submit]:focus {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input {
  &.active[name=logout]:focus, &[name="database_delete"] + input[type="submit"] + a.active:focus, &[value=Confirm] + a.active:focus:hover {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

.btn.active.focus, #loginBox form input.active.focus[type="submit"], div.confirm + fieldset form input.active.focus[type=submit], #headerlinks + fieldset + fieldset + fieldset input.active.focus[type=submit] {
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input {
  &.active.focus[name=logout], &[name="database_delete"] + input[type="submit"] + a.active.focus, &[value=Confirm] + a.active.focus:hover {
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
  }
}

.btn:hover, #loginBox form input[type="submit"]:hover, div.confirm + fieldset form input[type=submit]:hover, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:hover {
  color: #333;
  text-decoration: none;
}

input {
  &[name=logout]:hover, &[name="database_delete"] + input[type="submit"] + a:hover, &[value=Confirm] + a:hover {
    color: #333;
    text-decoration: none;
  }
}

.btn:focus, #loginBox form input[type="submit"]:focus, div.confirm + fieldset form input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:focus {
  color: #333;
  text-decoration: none;
}

input {
  &[name=logout]:focus, &[name="database_delete"] + input[type="submit"] + a:focus, &[value=Confirm] + a:focus:hover {
    color: #333;
    text-decoration: none;
  }
}

.btn.focus, #loginBox form input.focus[type="submit"], div.confirm + fieldset form input.focus[type=submit], #headerlinks + fieldset + fieldset + fieldset input.focus[type=submit] {
  color: #333;
  text-decoration: none;
}

input {
  &.focus[name=logout], &[name="database_delete"] + input[type="submit"] + a.focus, &[value=Confirm] + a.focus:hover {
    color: #333;
    text-decoration: none;
  }
}

.btn:active, #loginBox form input[type="submit"]:active, div.confirm + fieldset form input[type=submit]:active, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active {
  outline: 0;
  background-image: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}

input {
  &[name=logout]:active, &[name="database_delete"] + input[type="submit"] + a:active, &[value=Confirm] + a:active:hover {
    outline: 0;
    background-image: none;
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  }
}

.btn.active, #loginBox form input.active[type="submit"], div.confirm + fieldset form input.active[type=submit], #headerlinks + fieldset + fieldset + fieldset input.active[type=submit] {
  outline: 0;
  background-image: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}

input {
  &.active[name=logout], &[name="database_delete"] + input[type="submit"] + a.active, &[value=Confirm] + a.active:hover {
    outline: 0;
    background-image: none;
    -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
    box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  }
}

.btn.disabled, #loginBox form input.disabled[type="submit"], div.confirm + fieldset form input.disabled[type=submit], #headerlinks + fieldset + fieldset + fieldset input.disabled[type=submit] {
  cursor: not-allowed;
  opacity: .65;
  filter: alpha(opacity = 65);
  -webkit-box-shadow: none;
  box-shadow: none;
}

input {
  &.disabled[name=logout], &[name="database_delete"] + input[type="submit"] + a.disabled, &[value=Confirm] + a.disabled:hover {
    cursor: not-allowed;
    opacity: .65;
    filter: alpha(opacity = 65);
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

.btn[disabled], #loginBox form input[disabled][type="submit"], div.confirm + fieldset form input[disabled][type=submit], #headerlinks + fieldset + fieldset + fieldset input[disabled][type=submit] {
  cursor: not-allowed;
  opacity: .65;
  filter: alpha(opacity = 65);
  -webkit-box-shadow: none;
  box-shadow: none;
}

input {
  &[disabled][name=logout], &[name="database_delete"] + input[type="submit"] + a[disabled], &[value=Confirm] + a[disabled]:hover {
    cursor: not-allowed;
    opacity: .65;
    filter: alpha(opacity = 65);
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

fieldset[disabled] {
  .btn, #loginBox form input[type="submit"] {
    cursor: not-allowed;
    opacity: .65;
    filter: alpha(opacity = 65);
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

#loginBox form fieldset[disabled] input[type="submit"], fieldset[disabled] div.confirm + fieldset form input[type=submit], div.confirm + fieldset form fieldset[disabled] input[type=submit], fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=submit], #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=submit] {
  cursor: not-allowed;
  opacity: .65;
  filter: alpha(opacity = 65);
  -webkit-box-shadow: none;
  box-shadow: none;
}

fieldset[disabled] input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    cursor: not-allowed;
    opacity: .65;
    filter: alpha(opacity = 65);
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

a.btn.disabled {
  pointer-events: none;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.disabled, &[value=Confirm] + a.disabled:hover {
    pointer-events: none;
  }
}

fieldset[disabled] {
  a.btn {
    pointer-events: none;
  }
  input {
    &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      pointer-events: none;
    }
  }
}

.btn-default, div.confirm + fieldset form input[type=submit] {
  color: #333;
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a, &[name=rename], &[name=createtable], &[value=Confirm] {
    color: #333;
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn, #loginBox form input[type="submit"], #headerlinks + fieldset + fieldset + fieldset input[type=submit] {
  color: #333;
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name=logout], &[value=Confirm] + a:hover {
    color: #333;
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default:focus, div.confirm + fieldset form input[type=submit]:focus {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:focus, &[name=rename]:focus, &[name=createtable]:focus, &[value=Confirm]:focus {
    color: #333;
    background-color: #e6e6e6;
    border-color: #8c8c8c;
  }
}

.btn:focus, #loginBox form input[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:focus {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}

input {
  &[name=logout]:focus, &[value=Confirm] + a:focus:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #8c8c8c;
  }
}

.btn-default.focus, div.confirm + fieldset form input.focus[type=submit] {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.focus {
    color: #333;
    background-color: #e6e6e6;
    border-color: #8c8c8c;
  }
  &.focus {
    &[name=rename], &[name=createtable], &[value=Confirm] {
      color: #333;
      background-color: #e6e6e6;
      border-color: #8c8c8c;
    }
  }
}

.focus.btn, #loginBox form input.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.focus[type=submit] {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}

input {
  &.focus[name=logout], &[value=Confirm] + a.focus:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #8c8c8c;
  }
}

.btn-default:hover, div.confirm + fieldset form input[type=submit]:hover {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:hover, &[name=rename]:hover, &[name=createtable]:hover, &[value=Confirm]:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

.btn:hover, #loginBox form input[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:hover {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

input {
  &[name=logout]:hover, &[value=Confirm] + a:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

.btn-default:active, div.confirm + fieldset form input[type=submit]:active {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:active, &[name=rename]:active, &[name=createtable]:active, &[value=Confirm]:active {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

.btn:active, #loginBox form input[type="submit"]:active, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

input {
  &[name=logout]:active, &[value=Confirm] + a:active:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

.btn-default.active, div.confirm + fieldset form input.active[type=submit] {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.active {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
  &.active {
    &[name=rename], &[name=createtable], &[value=Confirm] {
      color: #333;
      background-color: #e6e6e6;
      border-color: #adadad;
    }
  }
}

.active.btn, #loginBox form input.active[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.active[type=submit] {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

input {
  &.active[name=logout], &[value=Confirm] + a.active:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

.open > .btn-default.dropdown-toggle, div.confirm + fieldset form .open > input.dropdown-toggle[type=submit] {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

.open > {
  input {
    &[name="database_delete"] + input[type="submit"] + a.dropdown-toggle {
      color: #333;
      background-color: #e6e6e6;
      border-color: #adadad;
    }
    &.dropdown-toggle {
      &[name=rename], &[name=createtable], &[value=Confirm] {
        color: #333;
        background-color: #e6e6e6;
        border-color: #adadad;
      }
    }
  }
  .dropdown-toggle.btn {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

#loginBox form .open > input.dropdown-toggle[type="submit"], #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit] {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}

.open > input {
  &.dropdown-toggle[name=logout], &[value=Confirm] + a.dropdown-toggle:hover {
    color: #333;
    background-color: #e6e6e6;
    border-color: #adadad;
  }
}

.btn-default:active:hover, div.confirm + fieldset form input[type=submit]:active:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:active:hover, &[name=rename]:active:hover, &[name=createtable]:active:hover, &[value=Confirm]:active:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn:active:hover, #loginBox form input[type="submit"]:active:hover, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name=logout]:active:hover, &[value=Confirm] + a:active:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn-default:active:focus, div.confirm + fieldset form input[type=submit]:active:focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:active:focus, &[name=rename]:active:focus, &[name=createtable]:active:focus, &[value=Confirm]:active:focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn:active:focus, #loginBox form input[type="submit"]:active:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active:focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name=logout]:active:focus, &[value=Confirm] + a:active:focus:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn-default:active.focus, div.confirm + fieldset form input[type=submit]:active.focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:active.focus, &[name=rename]:active.focus, &[name=createtable]:active.focus, &[value=Confirm]:active.focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn:active.focus, #loginBox form input[type="submit"]:active.focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active.focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name=logout]:active.focus, &[value=Confirm] + a:active.focus:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn-default.active:hover, div.confirm + fieldset form input.active[type=submit]:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.active:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
  &.active {
    &[name=rename]:hover, &[name=createtable]:hover, &[value=Confirm]:hover {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
  }
}

.active.btn:hover, #loginBox form input.active[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input.active[type=submit]:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &.active[name=logout]:hover, &[value=Confirm] + a.active:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn-default.active:focus, div.confirm + fieldset form input.active[type=submit]:focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.active:focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
  &.active {
    &[name=rename]:focus, &[name=createtable]:focus, &[value=Confirm]:focus {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
  }
}

.active.btn:focus, #loginBox form input.active[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input.active[type=submit]:focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &.active[name=logout]:focus, &[value=Confirm] + a.active:focus:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn-default.active.focus, div.confirm + fieldset form input.active.focus[type=submit] {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.active.focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
  &.active.focus {
    &[name=rename], &[name=createtable], &[value=Confirm] {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
  }
}

.active.focus.btn, #loginBox form input.active.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.active.focus[type=submit] {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

input {
  &.active.focus[name=logout], &[value=Confirm] + a.active.focus:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.open > .btn-default.dropdown-toggle:hover, div.confirm + fieldset form .open > input.dropdown-toggle[type=submit]:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

.open > {
  input {
    &[name="database_delete"] + input[type="submit"] + a.dropdown-toggle:hover {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
    &.dropdown-toggle {
      &[name=rename]:hover, &[name=createtable]:hover, &[value=Confirm]:hover {
        color: #333;
        background-color: #d4d4d4;
        border-color: #8c8c8c;
      }
    }
  }
  .dropdown-toggle.btn:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

#loginBox form .open > input.dropdown-toggle[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit]:hover {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

.open > {
  input {
    &.dropdown-toggle[name=logout]:hover, &[value=Confirm] + a.dropdown-toggle:hover {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
  }
  .btn-default.dropdown-toggle:focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

div.confirm + fieldset form .open > input.dropdown-toggle[type=submit]:focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

.open > {
  input {
    &[name="database_delete"] + input[type="submit"] + a.dropdown-toggle:focus {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
    &.dropdown-toggle {
      &[name=rename]:focus, &[name=createtable]:focus, &[value=Confirm]:focus {
        color: #333;
        background-color: #d4d4d4;
        border-color: #8c8c8c;
      }
    }
  }
  .dropdown-toggle.btn:focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

#loginBox form .open > input.dropdown-toggle[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit]:focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

.open > {
  input {
    &.dropdown-toggle[name=logout]:focus, &[value=Confirm] + a.dropdown-toggle:focus:hover {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
  }
  .btn-default.dropdown-toggle.focus {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

div.confirm + fieldset form .open > input.dropdown-toggle.focus[type=submit] {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

.open > {
  input {
    &[name="database_delete"] + input[type="submit"] + a.dropdown-toggle.focus {
      color: #333;
      background-color: #d4d4d4;
      border-color: #8c8c8c;
    }
    &.dropdown-toggle.focus {
      &[name=rename], &[name=createtable], &[value=Confirm] {
        color: #333;
        background-color: #d4d4d4;
        border-color: #8c8c8c;
      }
    }
  }
  .dropdown-toggle.focus.btn {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

#loginBox form .open > input.dropdown-toggle.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle.focus[type=submit] {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}

.open > input {
  &.dropdown-toggle.focus[name=logout], &[value=Confirm] + a.dropdown-toggle.focus:hover {
    color: #333;
    background-color: #d4d4d4;
    border-color: #8c8c8c;
  }
}

.btn-default:active, div.confirm + fieldset form input[type=submit]:active {
  background-image: none;
}

input {
  &[name="database_delete"] + input[type="submit"] + a:active, &[name=rename]:active, &[name=createtable]:active, &[value=Confirm]:active {
    background-image: none;
  }
}

.btn:active, #loginBox form input[type="submit"]:active, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active {
  background-image: none;
}

input {
  &[name=logout]:active, &[value=Confirm] + a:active:hover {
    background-image: none;
  }
}

.btn-default.active, div.confirm + fieldset form input.active[type=submit] {
  background-image: none;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.active {
    background-image: none;
  }
  &.active {
    &[name=rename], &[name=createtable], &[value=Confirm] {
      background-image: none;
    }
  }
}

.active.btn, #loginBox form input.active[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.active[type=submit] {
  background-image: none;
}

input {
  &.active[name=logout], &[value=Confirm] + a.active:hover {
    background-image: none;
  }
}

.open > .btn-default.dropdown-toggle, div.confirm + fieldset form .open > input.dropdown-toggle[type=submit] {
  background-image: none;
}

.open > {
  input {
    &[name="database_delete"] + input[type="submit"] + a.dropdown-toggle {
      background-image: none;
    }
    &.dropdown-toggle {
      &[name=rename], &[name=createtable], &[value=Confirm] {
        background-image: none;
      }
    }
  }
  .dropdown-toggle.btn {
    background-image: none;
  }
}

#loginBox form .open > input.dropdown-toggle[type="submit"], #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit] {
  background-image: none;
}

.open > input {
  &.dropdown-toggle[name=logout], &[value=Confirm] + a.dropdown-toggle:hover {
    background-image: none;
  }
}

.btn-default.disabled:hover, div.confirm + fieldset form input.disabled[type=submit]:hover {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.disabled:hover {
    background-color: #fff;
    border-color: #ccc;
  }
  &.disabled {
    &[name=rename]:hover, &[name=createtable]:hover, &[value=Confirm]:hover {
      background-color: #fff;
      border-color: #ccc;
    }
  }
}

.disabled.btn:hover, #loginBox form input.disabled[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input.disabled[type=submit]:hover {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &.disabled[name=logout]:hover, &[value=Confirm] + a.disabled:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default.disabled:focus, div.confirm + fieldset form input.disabled[type=submit]:focus {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.disabled:focus {
    background-color: #fff;
    border-color: #ccc;
  }
  &.disabled {
    &[name=rename]:focus, &[name=createtable]:focus, &[value=Confirm]:focus {
      background-color: #fff;
      border-color: #ccc;
    }
  }
}

.disabled.btn:focus, #loginBox form input.disabled[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input.disabled[type=submit]:focus {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &.disabled[name=logout]:focus, &[value=Confirm] + a.disabled:focus:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default.disabled.focus, div.confirm + fieldset form input.disabled.focus[type=submit] {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a.disabled.focus {
    background-color: #fff;
    border-color: #ccc;
  }
  &.disabled.focus {
    &[name=rename], &[name=createtable], &[value=Confirm] {
      background-color: #fff;
      border-color: #ccc;
    }
  }
}

.disabled.focus.btn, #loginBox form input.disabled.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.disabled.focus[type=submit] {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &.disabled.focus[name=logout], &[value=Confirm] + a.disabled.focus:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default[disabled]:hover, div.confirm + fieldset form input[disabled][type=submit]:hover {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a[disabled]:hover {
    background-color: #fff;
    border-color: #ccc;
  }
  &[disabled] {
    &[name=rename]:hover, &[name=createtable]:hover, &[value=Confirm]:hover {
      background-color: #fff;
      border-color: #ccc;
    }
  }
}

[disabled].btn:hover, #loginBox form input[disabled][type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input[disabled][type=submit]:hover {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[disabled][name=logout]:hover, &[value=Confirm] + a[disabled]:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default[disabled]:focus, div.confirm + fieldset form input[disabled][type=submit]:focus {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a[disabled]:focus {
    background-color: #fff;
    border-color: #ccc;
  }
  &[disabled] {
    &[name=rename]:focus, &[name=createtable]:focus, &[value=Confirm]:focus {
      background-color: #fff;
      border-color: #ccc;
    }
  }
}

[disabled].btn:focus, #loginBox form input[disabled][type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input[disabled][type=submit]:focus {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[disabled][name=logout]:focus, &[value=Confirm] + a[disabled]:focus:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default[disabled].focus, div.confirm + fieldset form input[disabled].focus[type=submit] {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[name="database_delete"] + input[type="submit"] + a[disabled].focus {
    background-color: #fff;
    border-color: #ccc;
  }
  &[disabled].focus {
    &[name=rename], &[name=createtable], &[value=Confirm] {
      background-color: #fff;
      border-color: #ccc;
    }
  }
}

[disabled].focus.btn, #loginBox form input[disabled].focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input[disabled].focus[type=submit] {
  background-color: #fff;
  border-color: #ccc;
}

input {
  &[disabled].focus[name=logout], &[value=Confirm] + a[disabled].focus:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

fieldset[disabled] {
  .btn-default:hover, div.confirm + fieldset form input[type=submit]:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

div.confirm + fieldset form fieldset[disabled] input[type=submit]:hover {
  background-color: #fff;
  border-color: #ccc;
}

fieldset[disabled] {
  input {
    &[name="database_delete"] + input[type="submit"] + a:hover, &[name=rename]:hover, &[name=createtable]:hover, &[value=Confirm]:hover {
      background-color: #fff;
      border-color: #ccc;
    }
  }
  .btn:hover, #loginBox form input[type="submit"]:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

#loginBox form fieldset[disabled] input[type="submit"]:hover, fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=submit]:hover, #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=submit]:hover {
  background-color: #fff;
  border-color: #ccc;
}

fieldset[disabled] {
  input {
    &[name=logout]:hover, &[value=Confirm] + a:hover {
      background-color: #fff;
      border-color: #ccc;
    }
  }
  .btn-default:focus, div.confirm + fieldset form input[type=submit]:focus {
    background-color: #fff;
    border-color: #ccc;
  }
}

div.confirm + fieldset form fieldset[disabled] input[type=submit]:focus {
  background-color: #fff;
  border-color: #ccc;
}

fieldset[disabled] {
  input {
    &[name="database_delete"] + input[type="submit"] + a:focus, &[name=rename]:focus, &[name=createtable]:focus, &[value=Confirm]:focus {
      background-color: #fff;
      border-color: #ccc;
    }
  }
  .btn:focus, #loginBox form input[type="submit"]:focus {
    background-color: #fff;
    border-color: #ccc;
  }
}

#loginBox form fieldset[disabled] input[type="submit"]:focus, fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=submit]:focus {
  background-color: #fff;
  border-color: #ccc;
}

fieldset[disabled] {
  input {
    &[name=logout]:focus, &[value=Confirm] + a:focus:hover {
      background-color: #fff;
      border-color: #ccc;
    }
  }
  .btn-default.focus, div.confirm + fieldset form input.focus[type=submit] {
    background-color: #fff;
    border-color: #ccc;
  }
}

div.confirm + fieldset form fieldset[disabled] input.focus[type=submit] {
  background-color: #fff;
  border-color: #ccc;
}

fieldset[disabled] {
  input {
    &[name="database_delete"] + input[type="submit"] + a.focus {
      background-color: #fff;
      border-color: #ccc;
    }
    &.focus {
      &[name=rename], &[name=createtable], &[value=Confirm] {
        background-color: #fff;
        border-color: #ccc;
      }
    }
  }
  .focus.btn, #loginBox form input.focus[type="submit"] {
    background-color: #fff;
    border-color: #ccc;
  }
}

#loginBox form fieldset[disabled] input.focus[type="submit"], fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input.focus[type=submit], #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input.focus[type=submit] {
  background-color: #fff;
  border-color: #ccc;
}

fieldset[disabled] input {
  &.focus[name=logout], &[value=Confirm] + a.focus:hover {
    background-color: #fff;
    border-color: #ccc;
  }
}

.btn-default .badge, div.confirm + fieldset form input[type=submit] .badge {
  color: #fff;
  background-color: #333;
}

input {
  &[name="database_delete"] + input[type="submit"] + a .badge, &[name=rename] .badge, &[name=createtable] .badge, &[value=Confirm] .badge {
    color: #fff;
    background-color: #333;
  }
}

.btn .badge, #loginBox form input[type="submit"] .badge, #headerlinks + fieldset + fieldset + fieldset input[type=submit] .badge {
  color: #fff;
  background-color: #333;
}

input {
  &[name=logout] .badge, &[value=Confirm] + a:hover .badge {
    color: #fff;
    background-color: #333;
  }
}

.btn-primary, #loginBox form input[type="submit"], #headerlinks + fieldset + fieldset + fieldset input[type=submit], input[name=createtable]:hover {
  color: #fff;
  background-color: #337ab7;
  border-color: #2e6da4;
}

.btn-primary:focus, #loginBox form input[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:focus, input[name=createtable]:focus:hover, .btn-primary.focus, #loginBox form input.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.focus[type=submit], input.focus[name=createtable]:hover {
  color: #fff;
  background-color: #286090;
  border-color: #122b40;
}

.btn-primary:hover, #loginBox form input[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:hover, input[name=createtable]:hover, .btn-primary:active, #loginBox form input[type="submit"]:active, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active, input[name=createtable]:active:hover, .btn-primary.active, #loginBox form input.active[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.active[type=submit], input.active[name=createtable]:hover, .open > .btn-primary.dropdown-toggle, #loginBox form .open > input.dropdown-toggle[type="submit"], #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit], .open > input.dropdown-toggle[name=createtable]:hover {
  color: #fff;
  background-color: #286090;
  border-color: #204d74;
}

.btn-primary:active:hover, #loginBox form input[type="submit"]:active:hover, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active:hover, input[name=createtable]:active:hover, .btn-primary:active:focus, #loginBox form input[type="submit"]:active:focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active:focus, input[name=createtable]:active:focus:hover, .btn-primary:active.focus, #loginBox form input[type="submit"]:active.focus, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active.focus, input[name=createtable]:active.focus:hover, .btn-primary.active:hover, #loginBox form input.active[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input.active[type=submit]:hover, input.active[name=createtable]:hover, .btn-primary.active:focus, #loginBox form input.active[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input.active[type=submit]:focus, input.active[name=createtable]:focus:hover, .btn-primary.active.focus, #loginBox form input.active.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.active.focus[type=submit], input.active.focus[name=createtable]:hover, .open > .btn-primary.dropdown-toggle:hover, #loginBox form .open > input.dropdown-toggle[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit]:hover {
  color: #fff;
  background-color: #204d74;
  border-color: #122b40;
}

.open > {
  input.dropdown-toggle[name=createtable]:hover, .btn-primary.dropdown-toggle:focus {
    color: #fff;
    background-color: #204d74;
    border-color: #122b40;
  }
}

#loginBox form .open > input.dropdown-toggle[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit]:focus {
  color: #fff;
  background-color: #204d74;
  border-color: #122b40;
}

.open > {
  input.dropdown-toggle[name=createtable]:focus:hover, .btn-primary.dropdown-toggle.focus {
    color: #fff;
    background-color: #204d74;
    border-color: #122b40;
  }
}

#loginBox form .open > input.dropdown-toggle.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle.focus[type=submit], .open > input.dropdown-toggle.focus[name=createtable]:hover {
  color: #fff;
  background-color: #204d74;
  border-color: #122b40;
}

.btn-primary:active, #loginBox form input[type="submit"]:active, #headerlinks + fieldset + fieldset + fieldset input[type=submit]:active, input[name=createtable]:active:hover, .btn-primary.active, #loginBox form input.active[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.active[type=submit], input.active[name=createtable]:hover, .open > .btn-primary.dropdown-toggle, #loginBox form .open > input.dropdown-toggle[type="submit"], #headerlinks + fieldset + fieldset + fieldset .open > input.dropdown-toggle[type=submit], .open > input.dropdown-toggle[name=createtable]:hover {
  background-image: none;
}

.btn-primary.disabled:hover, #loginBox form input.disabled[type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input.disabled[type=submit]:hover, input.disabled[name=createtable]:hover, .btn-primary.disabled:focus, #loginBox form input.disabled[type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input.disabled[type=submit]:focus, input.disabled[name=createtable]:focus:hover, .btn-primary.disabled.focus, #loginBox form input.disabled.focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input.disabled.focus[type=submit], input.disabled.focus[name=createtable]:hover, .btn-primary[disabled]:hover, #loginBox form input[disabled][type="submit"]:hover, #headerlinks + fieldset + fieldset + fieldset input[disabled][type=submit]:hover, input[disabled][name=createtable]:hover, .btn-primary[disabled]:focus, #loginBox form input[disabled][type="submit"]:focus, #headerlinks + fieldset + fieldset + fieldset input[disabled][type=submit]:focus, input[disabled][name=createtable]:focus:hover, .btn-primary[disabled].focus, #loginBox form input[disabled].focus[type="submit"], #headerlinks + fieldset + fieldset + fieldset input[disabled].focus[type=submit], input[disabled].focus[name=createtable]:hover {
  background-color: #337ab7;
  border-color: #2e6da4;
}

fieldset[disabled] {
  .btn-primary:hover, #loginBox form input[type="submit"]:hover {
    background-color: #337ab7;
    border-color: #2e6da4;
  }
}

#loginBox form fieldset[disabled] input[type="submit"]:hover, fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=submit]:hover, #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=submit]:hover {
  background-color: #337ab7;
  border-color: #2e6da4;
}

fieldset[disabled] {
  input[name=createtable]:hover, .btn-primary:focus, #loginBox form input[type="submit"]:focus {
    background-color: #337ab7;
    border-color: #2e6da4;
  }
}

#loginBox form fieldset[disabled] input[type="submit"]:focus, fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input[type=submit]:focus {
  background-color: #337ab7;
  border-color: #2e6da4;
}

fieldset[disabled] {
  input[name=createtable]:focus:hover, .btn-primary.focus, #loginBox form input.focus[type="submit"] {
    background-color: #337ab7;
    border-color: #2e6da4;
  }
}

#loginBox form fieldset[disabled] input.focus[type="submit"], fieldset[disabled] #headerlinks + fieldset + fieldset + fieldset input.focus[type=submit], #headerlinks + fieldset + fieldset + fieldset fieldset[disabled] input.focus[type=submit], fieldset[disabled] input.focus[name=createtable]:hover {
  background-color: #337ab7;
  border-color: #2e6da4;
}

.btn-primary .badge, #loginBox form input[type="submit"] .badge, #headerlinks + fieldset + fieldset + fieldset input[type=submit] .badge, input[name=createtable]:hover .badge {
  color: #337ab7;
  background-color: #fff;
}

.btn-success, input[value=Confirm] + a:hover {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}

.btn-success:focus, input[value=Confirm] + a:focus:hover, .btn-success.focus, input[value=Confirm] + a.focus:hover {
  color: #fff;
  background-color: #449d44;
  border-color: #255625;
}

.btn-success:hover, input[value=Confirm] + a:hover, .btn-success:active, input[value=Confirm] + a:active:hover, .btn-success.active, input[value=Confirm] + a.active:hover {
  color: #fff;
  background-color: #449d44;
  border-color: #398439;
}

.open > {
  .btn-success.dropdown-toggle, input[value=Confirm] + a.dropdown-toggle:hover {
    color: #fff;
    background-color: #449d44;
    border-color: #398439;
  }
}

.btn-success:active:hover, input[value=Confirm] + a:active:hover, .btn-success:active:focus, input[value=Confirm] + a:active:focus:hover, .btn-success:active.focus, input[value=Confirm] + a:active.focus:hover, .btn-success.active:hover, input[value=Confirm] + a.active:hover, .btn-success.active:focus, input[value=Confirm] + a.active:focus:hover, .btn-success.active.focus, input[value=Confirm] + a.active.focus:hover {
  color: #fff;
  background-color: #398439;
  border-color: #255625;
}

.open > {
  .btn-success.dropdown-toggle:hover, input[value=Confirm] + a.dropdown-toggle:hover, .btn-success.dropdown-toggle:focus, input[value=Confirm] + a.dropdown-toggle:focus:hover, .btn-success.dropdown-toggle.focus, input[value=Confirm] + a.dropdown-toggle.focus:hover {
    color: #fff;
    background-color: #398439;
    border-color: #255625;
  }
}

.btn-success:active, input[value=Confirm] + a:active:hover, .btn-success.active, input[value=Confirm] + a.active:hover {
  background-image: none;
}

.open > {
  .btn-success.dropdown-toggle, input[value=Confirm] + a.dropdown-toggle:hover {
    background-image: none;
  }
}

.btn-success.disabled:hover, input[value=Confirm] + a.disabled:hover, .btn-success.disabled:focus, input[value=Confirm] + a.disabled:focus:hover, .btn-success.disabled.focus, input[value=Confirm] + a.disabled.focus:hover, .btn-success[disabled]:hover, input[value=Confirm] + a[disabled]:hover, .btn-success[disabled]:focus, input[value=Confirm] + a[disabled]:focus:hover, .btn-success[disabled].focus, input[value=Confirm] + a[disabled].focus:hover {
  background-color: #5cb85c;
  border-color: #4cae4c;
}

fieldset[disabled] {
  .btn-success:hover, input[value=Confirm] + a:hover, .btn-success:focus, input[value=Confirm] + a:focus:hover, .btn-success.focus, input[value=Confirm] + a.focus:hover {
    background-color: #5cb85c;
    border-color: #4cae4c;
  }
}

.btn-success .badge, input[value=Confirm] + a:hover .badge {
  color: #5cb85c;
  background-color: #fff;
}

.btn-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da;
  &:focus, &.focus {
    color: #fff;
    background-color: #31b0d5;
    border-color: #1b6d85;
  }
  &:hover, &:active, &.active {
    color: #fff;
    background-color: #31b0d5;
    border-color: #269abc;
  }
}

.open > .btn-info.dropdown-toggle {
  color: #fff;
  background-color: #31b0d5;
  border-color: #269abc;
}

.btn-info {
  &:active {
    &:hover, &:focus, &.focus {
      color: #fff;
      background-color: #269abc;
      border-color: #1b6d85;
    }
  }
  &.active {
    &:hover, &:focus, &.focus {
      color: #fff;
      background-color: #269abc;
      border-color: #1b6d85;
    }
  }
}

.open > .btn-info.dropdown-toggle {
  &:hover, &:focus, &.focus {
    color: #fff;
    background-color: #269abc;
    border-color: #1b6d85;
  }
}

.btn-info {
  &:active, &.active {
    background-image: none;
  }
}

.open > .btn-info.dropdown-toggle {
  background-image: none;
}

.btn-info {
  &.disabled {
    &:hover, &:focus, &.focus {
      background-color: #5bc0de;
      border-color: #46b8da;
    }
  }
  &[disabled] {
    &:hover, &:focus, &.focus {
      background-color: #5bc0de;
      border-color: #46b8da;
    }
  }
}

fieldset[disabled] .btn-info {
  &:hover, &:focus, &.focus {
    background-color: #5bc0de;
    border-color: #46b8da;
  }
}

.btn-info .badge {
  color: #5bc0de;
  background-color: #fff;
}

.btn-warning, input[name=rename]:hover {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236;
}

.btn-warning:focus, input[name=rename]:focus:hover, .btn-warning.focus, input.focus[name=rename]:hover {
  color: #fff;
  background-color: #ec971f;
  border-color: #985f0d;
}

.btn-warning:hover, input[name=rename]:hover, .btn-warning:active, input[name=rename]:active:hover, .btn-warning.active, input.active[name=rename]:hover {
  color: #fff;
  background-color: #ec971f;
  border-color: #d58512;
}

.open > {
  .btn-warning.dropdown-toggle, input.dropdown-toggle[name=rename]:hover {
    color: #fff;
    background-color: #ec971f;
    border-color: #d58512;
  }
}

.btn-warning:active:hover, input[name=rename]:active:hover, .btn-warning:active:focus, input[name=rename]:active:focus:hover, .btn-warning:active.focus, input[name=rename]:active.focus:hover, .btn-warning.active:hover, input.active[name=rename]:hover, .btn-warning.active:focus, input.active[name=rename]:focus:hover, .btn-warning.active.focus, input.active.focus[name=rename]:hover {
  color: #fff;
  background-color: #d58512;
  border-color: #985f0d;
}

.open > {
  .btn-warning.dropdown-toggle:hover, input.dropdown-toggle[name=rename]:hover, .btn-warning.dropdown-toggle:focus, input.dropdown-toggle[name=rename]:focus:hover, .btn-warning.dropdown-toggle.focus, input.dropdown-toggle.focus[name=rename]:hover {
    color: #fff;
    background-color: #d58512;
    border-color: #985f0d;
  }
}

.btn-warning:active, input[name=rename]:active:hover, .btn-warning.active, input.active[name=rename]:hover {
  background-image: none;
}

.open > {
  .btn-warning.dropdown-toggle, input.dropdown-toggle[name=rename]:hover {
    background-image: none;
  }
}

.btn-warning.disabled:hover, input.disabled[name=rename]:hover, .btn-warning.disabled:focus, input.disabled[name=rename]:focus:hover, .btn-warning.disabled.focus, input.disabled.focus[name=rename]:hover, .btn-warning[disabled]:hover, input[disabled][name=rename]:hover, .btn-warning[disabled]:focus, input[disabled][name=rename]:focus:hover, .btn-warning[disabled].focus, input[disabled].focus[name=rename]:hover {
  background-color: #f0ad4e;
  border-color: #eea236;
}

fieldset[disabled] {
  .btn-warning:hover, input[name=rename]:hover, .btn-warning:focus, input[name=rename]:focus:hover, .btn-warning.focus, input.focus[name=rename]:hover {
    background-color: #f0ad4e;
    border-color: #eea236;
  }
}

.btn-warning .badge, input[name=rename]:hover .badge {
  color: #f0ad4e;
  background-color: #fff;
}

.btn-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &[name=logout], &[name="database_delete"] + input[type="submit"], &[value=Confirm]:hover, &[name=vacuum] {
    color: #fff;
    background-color: #d9534f;
    border-color: #d43f3a;
  }
}

.btn-danger:focus {
  color: #fff;
  background-color: #c9302c;
  border-color: #761c19;
}

input {
  &[name=logout]:focus, &[name="database_delete"] + input[type="submit"]:focus, &[value=Confirm]:focus:hover, &[name=vacuum]:focus {
    color: #fff;
    background-color: #c9302c;
    border-color: #761c19;
  }
}

.btn-danger.focus {
  color: #fff;
  background-color: #c9302c;
  border-color: #761c19;
}

input {
  &.focus[name=logout], &[name="database_delete"] + input.focus[type="submit"] {
    color: #fff;
    background-color: #c9302c;
    border-color: #761c19;
  }
  &.focus {
    &[value=Confirm]:hover, &[name=vacuum] {
      color: #fff;
      background-color: #c9302c;
      border-color: #761c19;
    }
  }
}

.btn-danger:hover {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925;
}

input {
  &[name=logout]:hover, &[name="database_delete"] + input[type="submit"]:hover, &[value=Confirm]:hover, &[name=vacuum]:hover {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925;
  }
}

.btn-danger:active {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925;
}

input {
  &[name=logout]:active, &[name="database_delete"] + input[type="submit"]:active, &[value=Confirm]:active:hover, &[name=vacuum]:active {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925;
  }
}

.btn-danger.active {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925;
}

input {
  &.active[name=logout], &[name="database_delete"] + input.active[type="submit"] {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925;
  }
  &.active {
    &[value=Confirm]:hover, &[name=vacuum] {
      color: #fff;
      background-color: #c9302c;
      border-color: #ac2925;
    }
  }
}

.open > {
  .btn-danger.dropdown-toggle {
    color: #fff;
    background-color: #c9302c;
    border-color: #ac2925;
  }
  input {
    &.dropdown-toggle[name=logout], &[name="database_delete"] + input.dropdown-toggle[type="submit"] {
      color: #fff;
      background-color: #c9302c;
      border-color: #ac2925;
    }
    &.dropdown-toggle {
      &[value=Confirm]:hover, &[name=vacuum] {
        color: #fff;
        background-color: #c9302c;
        border-color: #ac2925;
      }
    }
  }
}

.btn-danger:active:hover {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}

input {
  &[name=logout]:active:hover, &[name="database_delete"] + input[type="submit"]:active:hover, &[value=Confirm]:active:hover, &[name=vacuum]:active:hover {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
}

.btn-danger:active:focus {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}

input {
  &[name=logout]:active:focus, &[name="database_delete"] + input[type="submit"]:active:focus, &[value=Confirm]:active:focus:hover, &[name=vacuum]:active:focus {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
}

.btn-danger:active.focus {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}

input {
  &[name=logout]:active.focus, &[name="database_delete"] + input[type="submit"]:active.focus, &[value=Confirm]:active.focus:hover, &[name=vacuum]:active.focus {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
}

.btn-danger.active:hover {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}

input {
  &.active[name=logout]:hover, &[name="database_delete"] + input.active[type="submit"]:hover {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
  &.active {
    &[value=Confirm]:hover, &[name=vacuum]:hover {
      color: #fff;
      background-color: #ac2925;
      border-color: #761c19;
    }
  }
}

.btn-danger.active:focus {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}

input {
  &.active[name=logout]:focus, &[name="database_delete"] + input.active[type="submit"]:focus {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
  &.active {
    &[value=Confirm]:focus:hover, &[name=vacuum]:focus {
      color: #fff;
      background-color: #ac2925;
      border-color: #761c19;
    }
  }
}

.btn-danger.active.focus {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}

input {
  &.active.focus[name=logout], &[name="database_delete"] + input.active.focus[type="submit"] {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
  &.active.focus {
    &[value=Confirm]:hover, &[name=vacuum] {
      color: #fff;
      background-color: #ac2925;
      border-color: #761c19;
    }
  }
}

.open > {
  .btn-danger.dropdown-toggle:hover {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
  input {
    &.dropdown-toggle[name=logout]:hover, &[name="database_delete"] + input.dropdown-toggle[type="submit"]:hover {
      color: #fff;
      background-color: #ac2925;
      border-color: #761c19;
    }
    &.dropdown-toggle {
      &[value=Confirm]:hover, &[name=vacuum]:hover {
        color: #fff;
        background-color: #ac2925;
        border-color: #761c19;
      }
    }
  }
  .btn-danger.dropdown-toggle:focus {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
  input {
    &.dropdown-toggle[name=logout]:focus, &[name="database_delete"] + input.dropdown-toggle[type="submit"]:focus {
      color: #fff;
      background-color: #ac2925;
      border-color: #761c19;
    }
    &.dropdown-toggle {
      &[value=Confirm]:focus:hover, &[name=vacuum]:focus {
        color: #fff;
        background-color: #ac2925;
        border-color: #761c19;
      }
    }
  }
  .btn-danger.dropdown-toggle.focus {
    color: #fff;
    background-color: #ac2925;
    border-color: #761c19;
  }
  input {
    &.dropdown-toggle.focus[name=logout], &[name="database_delete"] + input.dropdown-toggle.focus[type="submit"] {
      color: #fff;
      background-color: #ac2925;
      border-color: #761c19;
    }
    &.dropdown-toggle.focus {
      &[value=Confirm]:hover, &[name=vacuum] {
        color: #fff;
        background-color: #ac2925;
        border-color: #761c19;
      }
    }
  }
}

.btn-danger:active {
  background-image: none;
}

input {
  &[name=logout]:active, &[name="database_delete"] + input[type="submit"]:active, &[value=Confirm]:active:hover, &[name=vacuum]:active {
    background-image: none;
  }
}

.btn-danger.active {
  background-image: none;
}

input {
  &.active[name=logout], &[name="database_delete"] + input.active[type="submit"] {
    background-image: none;
  }
  &.active {
    &[value=Confirm]:hover, &[name=vacuum] {
      background-image: none;
    }
  }
}

.open > {
  .btn-danger.dropdown-toggle {
    background-image: none;
  }
  input {
    &.dropdown-toggle[name=logout], &[name="database_delete"] + input.dropdown-toggle[type="submit"] {
      background-image: none;
    }
    &.dropdown-toggle {
      &[value=Confirm]:hover, &[name=vacuum] {
        background-image: none;
      }
    }
  }
}

.btn-danger.disabled:hover {
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &.disabled[name=logout]:hover, &[name="database_delete"] + input.disabled[type="submit"]:hover {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  &.disabled {
    &[value=Confirm]:hover, &[name=vacuum]:hover {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
}

.btn-danger.disabled:focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &.disabled[name=logout]:focus, &[name="database_delete"] + input.disabled[type="submit"]:focus {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  &.disabled {
    &[value=Confirm]:focus:hover, &[name=vacuum]:focus {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
}

.btn-danger.disabled.focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &.disabled.focus[name=logout], &[name="database_delete"] + input.disabled.focus[type="submit"] {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  &.disabled.focus {
    &[value=Confirm]:hover, &[name=vacuum] {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
}

.btn-danger[disabled]:hover {
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &[disabled][name=logout]:hover, &[name="database_delete"] + input[disabled][type="submit"]:hover {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  &[disabled] {
    &[value=Confirm]:hover, &[name=vacuum]:hover {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
}

.btn-danger[disabled]:focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &[disabled][name=logout]:focus, &[name="database_delete"] + input[disabled][type="submit"]:focus {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  &[disabled] {
    &[value=Confirm]:focus:hover, &[name=vacuum]:focus {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
}

.btn-danger[disabled].focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}

input {
  &[disabled].focus[name=logout], &[name="database_delete"] + input[disabled].focus[type="submit"] {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  &[disabled].focus {
    &[value=Confirm]:hover, &[name=vacuum] {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
}

fieldset[disabled] {
  .btn-danger:hover {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  input {
    &[name=logout]:hover, &[name="database_delete"] + input[type="submit"]:hover, &[value=Confirm]:hover, &[name=vacuum]:hover {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
  .btn-danger:focus {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  input {
    &[name=logout]:focus, &[name="database_delete"] + input[type="submit"]:focus, &[value=Confirm]:focus:hover, &[name=vacuum]:focus {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
  }
  .btn-danger.focus {
    background-color: #d9534f;
    border-color: #d43f3a;
  }
  input {
    &.focus[name=logout], &[name="database_delete"] + input.focus[type="submit"] {
      background-color: #d9534f;
      border-color: #d43f3a;
    }
    &.focus {
      &[value=Confirm]:hover, &[name=vacuum] {
        background-color: #d9534f;
        border-color: #d43f3a;
      }
    }
  }
}

.btn-danger .badge {
  color: #d9534f;
  background-color: #fff;
}

input {
  &[name=logout] .badge, &[name="database_delete"] + input[type="submit"] .badge, &[value=Confirm]:hover .badge, &[name=vacuum] .badge {
    color: #d9534f;
    background-color: #fff;
  }
}

.btn-link {
  color: #337ab7;
  font-weight: normal;
  border-radius: 0;
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
  &:active, &.active, &[disabled] {
    background-color: transparent;
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

fieldset[disabled] .btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}

.btn-link {
  border-color: transparent;
  &:hover, &:focus, &:active {
    border-color: transparent;
  }
  &:hover, &:focus {
    color: #23527c;
    text-decoration: underline;
    background-color: transparent;
  }
  &[disabled] {
    &:hover, &:focus {
      color: #777;
      text-decoration: none;
    }
  }
}

fieldset[disabled] .btn-link {
  &:hover, &:focus {
    color: #777;
    text-decoration: none;
  }
}

.btn-lg, .btn-group-lg > .btn, #loginBox form .btn-group-lg > input[type="submit"], div.confirm + fieldset form .btn-group-lg > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-lg > input[type=submit] {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33333;
  border-radius: 6px;
}

.btn-group-lg > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    padding: 10px 16px;
    font-size: 18px;
    line-height: 1.33333;
    border-radius: 6px;
  }
}

.btn-sm, .btn-group-sm > .btn, #loginBox form .btn-group-sm > input[type="submit"], div.confirm + fieldset form .btn-group-sm > input[type=submit] {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

.btn-group-sm > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    padding: 5px 10px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px;
  }
}

#headerlinks + fieldset + fieldset + fieldset input[type=submit], input[name=logout] {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

.btn-xs, .btn-group-xs > .btn, #loginBox form .btn-group-xs > input[type="submit"], div.confirm + fieldset form .btn-group-xs > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-xs > input[type=submit] {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

.btn-group-xs > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    padding: 1px 5px;
    font-size: 12px;
    line-height: 1.5;
    border-radius: 3px;
  }
}

.btn-block, #loginBox form input[type="submit"] {
  display: block;
  width: 100%;
}

.btn-block + .btn-block {
  margin-top: 5px;
}

#loginBox form {
  input[type="submit"] + .btn-block, .btn-block + input[type="submit"], input[type="submit"] + input[type="submit"] {
    margin-top: 5px;
  }
}

input[type="submit"].btn-block, #loginBox form input[type="submit"], input[type="reset"].btn-block, #loginBox form input[type="reset"][type="submit"], input[type="button"].btn-block, #loginBox form input[type="button"][type="submit"] {
  width: 100%;
}

.btn-group, .btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}

.btn-group > .btn, #loginBox form .btn-group > input[type="submit"], div.confirm + fieldset form .btn-group > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit] {
  position: relative;
  float: left;
}

.btn-group > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    position: relative;
    float: left;
  }
}

.btn-group-vertical > .btn, #loginBox form .btn-group-vertical > input[type="submit"], div.confirm + fieldset form .btn-group-vertical > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit] {
  position: relative;
  float: left;
}

.btn-group-vertical > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    position: relative;
    float: left;
  }
}

.btn-group > .btn:hover, #loginBox form .btn-group > input[type="submit"]:hover, div.confirm + fieldset form .btn-group > input[type=submit]:hover, #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:hover {
  z-index: 2;
}

.btn-group > {
  input {
    &[name=logout]:hover, &[name="database_delete"] + input[type="submit"] + a:hover, &[value=Confirm] + a:hover {
      z-index: 2;
    }
  }
  .btn:focus {
    z-index: 2;
  }
}

#loginBox form .btn-group > input[type="submit"]:focus, div.confirm + fieldset form .btn-group > input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:focus {
  z-index: 2;
}

.btn-group > {
  input {
    &[name=logout]:focus, &[name="database_delete"] + input[type="submit"] + a:focus, &[value=Confirm] + a:focus:hover {
      z-index: 2;
    }
  }
  .btn:active {
    z-index: 2;
  }
}

#loginBox form .btn-group > input[type="submit"]:active, div.confirm + fieldset form .btn-group > input[type=submit]:active, #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:active {
  z-index: 2;
}

.btn-group > {
  input {
    &[name=logout]:active, &[name="database_delete"] + input[type="submit"] + a:active, &[value=Confirm] + a:active:hover {
      z-index: 2;
    }
  }
  .btn.active {
    z-index: 2;
  }
}

#loginBox form .btn-group > input.active[type="submit"], div.confirm + fieldset form .btn-group > input.active[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group > input.active[type=submit] {
  z-index: 2;
}

.btn-group > input {
  &.active[name=logout], &[name="database_delete"] + input[type="submit"] + a.active, &[value=Confirm] + a.active:hover {
    z-index: 2;
  }
}

.btn-group-vertical > .btn:hover, #loginBox form .btn-group-vertical > input[type="submit"]:hover, div.confirm + fieldset form .btn-group-vertical > input[type=submit]:hover, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit]:hover {
  z-index: 2;
}

.btn-group-vertical > {
  input {
    &[name=logout]:hover, &[name="database_delete"] + input[type="submit"] + a:hover, &[value=Confirm] + a:hover {
      z-index: 2;
    }
  }
  .btn:focus {
    z-index: 2;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"]:focus, div.confirm + fieldset form .btn-group-vertical > input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit]:focus {
  z-index: 2;
}

.btn-group-vertical > {
  input {
    &[name=logout]:focus, &[name="database_delete"] + input[type="submit"] + a:focus, &[value=Confirm] + a:focus:hover {
      z-index: 2;
    }
  }
  .btn:active {
    z-index: 2;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"]:active, div.confirm + fieldset form .btn-group-vertical > input[type=submit]:active, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit]:active {
  z-index: 2;
}

.btn-group-vertical > {
  input {
    &[name=logout]:active, &[name="database_delete"] + input[type="submit"] + a:active, &[value=Confirm] + a:active:hover {
      z-index: 2;
    }
  }
  .btn.active {
    z-index: 2;
  }
}

#loginBox form .btn-group-vertical > input.active[type="submit"], div.confirm + fieldset form .btn-group-vertical > input.active[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input.active[type=submit] {
  z-index: 2;
}

.btn-group-vertical > input {
  &.active[name=logout], &[name="database_delete"] + input[type="submit"] + a.active, &[value=Confirm] + a.active:hover {
    z-index: 2;
  }
}

.btn-group {
  .btn + .btn, #loginBox form input[type="submit"] + .btn {
    margin-left: -1px;
  }
}

#loginBox form .btn-group input[type="submit"] + .btn, .btn-group div.confirm + fieldset form input[type=submit] + .btn, div.confirm + fieldset form .btn-group input[type=submit] + .btn, .btn-group #headerlinks + fieldset + fieldset + fieldset input[type=submit] + .btn, #headerlinks + fieldset + fieldset + fieldset .btn-group input[type=submit] + .btn {
  margin-left: -1px;
}

.btn-group {
  input {
    &[name=logout] + .btn, &[name="database_delete"] + input[type="submit"] + a + .btn, &[value=Confirm] + a:hover + .btn {
      margin-left: -1px;
    }
  }
  #loginBox form .btn + input[type="submit"] {
    margin-left: -1px;
  }
}

#loginBox form .btn-group .btn + input[type="submit"], .btn-group #loginBox form input[type="submit"] + input[type="submit"], #loginBox form .btn-group input[type="submit"] + input[type="submit"], .btn-group div.confirm + fieldset #loginBox form input[type=submit] + input[type="submit"], #loginBox .btn-group div.confirm + fieldset form input[type=submit] + input[type="submit"], div.confirm + fieldset #loginBox form .btn-group input[type=submit] + input[type="submit"], #loginBox div.confirm + fieldset form .btn-group input[type=submit] + input[type="submit"], .btn-group #headerlinks + fieldset + fieldset + fieldset #loginBox form input[type=submit] + input[type="submit"], #loginBox form .btn-group #headerlinks + fieldset + fieldset + fieldset input[type=submit] + input[type="submit"], #headerlinks + fieldset + fieldset + fieldset .btn-group #loginBox form input[type=submit] + input[type="submit"], #loginBox form #headerlinks + fieldset + fieldset + fieldset .btn-group input[type=submit] + input[type="submit"], .btn-group #loginBox form input[name=logout] + input[type="submit"], #loginBox form .btn-group input[name=logout] + input[type="submit"], .btn-group #loginBox form input[name="database_delete"] + input[type="submit"] + a + input[type="submit"], #loginBox form .btn-group input[name="database_delete"] + input[type="submit"] + a + input[type="submit"], .btn-group #loginBox form input[value=Confirm] + a:hover + input[type="submit"], #loginBox form .btn-group input[value=Confirm] + a:hover + input[type="submit"], .btn-group div.confirm + fieldset form .btn + input[type=submit], div.confirm + fieldset form .btn-group .btn + input[type=submit], .btn-group #loginBox div.confirm + fieldset form input[type="submit"] + input[type=submit], div.confirm + fieldset .btn-group #loginBox form input[type="submit"] + input[type=submit], #loginBox div.confirm + fieldset form .btn-group input[type="submit"] + input[type=submit], div.confirm + fieldset #loginBox form .btn-group input[type="submit"] + input[type=submit], .btn-group div.confirm + fieldset form input[type=submit] + input[type=submit], div.confirm + fieldset form .btn-group input[type=submit] + input[type=submit] {
  margin-left: -1px;
}

.btn-group {
  #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=submit] + input[type=submit], div.confirm + fieldset form input[name=logout] + input[type=submit] {
    margin-left: -1px;
  }
}

div.confirm + fieldset form .btn-group input[name=logout] + input[type=submit], .btn-group div.confirm + fieldset form input[name="database_delete"] + input[type="submit"] + a + input[type=submit], div.confirm + fieldset form .btn-group input[name="database_delete"] + input[type="submit"] + a + input[type=submit], .btn-group div.confirm + fieldset form input[value=Confirm] + a:hover + input[type=submit], div.confirm + fieldset form .btn-group input[value=Confirm] + a:hover + input[type=submit], .btn-group #headerlinks + fieldset + fieldset + fieldset .btn + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group .btn + input[type=submit], .btn-group #loginBox form #headerlinks + fieldset + fieldset + fieldset input[type="submit"] + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group #loginBox form input[type="submit"] + input[type=submit], #loginBox form .btn-group #headerlinks + fieldset + fieldset + fieldset input[type="submit"] + input[type=submit] {
  margin-left: -1px;
}

#headerlinks + fieldset + fieldset + fieldset {
  #loginBox form .btn-group input[type="submit"] + input[type=submit], .btn-group div.confirm + fieldset form input[type=submit] + input[type=submit] {
    margin-left: -1px;
  }
}

.btn-group #headerlinks + fieldset + fieldset + fieldset input[type=submit] + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group input[type=submit] + input[type=submit], .btn-group #headerlinks + fieldset + fieldset + fieldset input[name=logout] + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group input[name=logout] + input[type=submit], .btn-group #headerlinks + fieldset + fieldset + fieldset input[name="database_delete"] + input[type="submit"] + a + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group input[name="database_delete"] + input[type="submit"] + a + input[type=submit], .btn-group #headerlinks + fieldset + fieldset + fieldset input[value=Confirm] + a:hover + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group input[value=Confirm] + a:hover + input[type=submit] {
  margin-left: -1px;
}

.btn-group {
  .btn + input[name=logout], #loginBox form input[type="submit"] + input[name=logout] {
    margin-left: -1px;
  }
}

#loginBox form .btn-group input[type="submit"] + input[name=logout], .btn-group div.confirm + fieldset form input[type=submit] + input[name=logout], div.confirm + fieldset form .btn-group input[type=submit] + input[name=logout], .btn-group #headerlinks + fieldset + fieldset + fieldset input[type=submit] + input[name=logout], #headerlinks + fieldset + fieldset + fieldset .btn-group input[type=submit] + input[name=logout] {
  margin-left: -1px;
}

.btn-group {
  input {
    &[name=logout] + input[name=logout], &[name="database_delete"] + input[type="submit"] + a + input[name=logout], &[value=Confirm] + a:hover + input[name=logout], &[name="database_delete"] + input[type="submit"].btn + a {
      margin-left: -1px;
    }
  }
  #loginBox form input[name="database_delete"] + input[type="submit"] + a {
    margin-left: -1px;
  }
}

#loginBox form .btn-group input[name="database_delete"] + input[type="submit"] + a, .btn-group div.confirm + fieldset form input[name="database_delete"] + input[type="submit"][type=submit] + a, div.confirm + fieldset form .btn-group input[name="database_delete"] + input[type="submit"][type=submit] + a, .btn-group #headerlinks + fieldset + fieldset + fieldset input[name="database_delete"] + input[type="submit"][type=submit] + a, #headerlinks + fieldset + fieldset + fieldset .btn-group input[name="database_delete"] + input[type="submit"][type=submit] + a {
  margin-left: -1px;
}

.btn-group {
  input {
    &[name="database_delete"] + input[type="submit"][name=logout] + a, &[value=Confirm].btn + a:hover {
      margin-left: -1px;
    }
  }
  #loginBox form input[value=Confirm][type="submit"] + a:hover {
    margin-left: -1px;
  }
}

#loginBox form .btn-group input[value=Confirm][type="submit"] + a:hover, .btn-group div.confirm + fieldset form input[value=Confirm][type=submit] + a:hover, div.confirm + fieldset form .btn-group input[value=Confirm][type=submit] + a:hover, .btn-group #headerlinks + fieldset + fieldset + fieldset input[value=Confirm][type=submit] + a:hover, #headerlinks + fieldset + fieldset + fieldset .btn-group input[value=Confirm][type=submit] + a:hover {
  margin-left: -1px;
}

.btn-group {
  input[value=Confirm][name=logout] + a:hover, .btn + .btn-group, #loginBox form input[type="submit"] + .btn-group {
    margin-left: -1px;
  }
}

#loginBox form .btn-group input[type="submit"] + .btn-group, .btn-group div.confirm + fieldset form input[type=submit] + .btn-group, div.confirm + fieldset form .btn-group input[type=submit] + .btn-group, .btn-group #headerlinks + fieldset + fieldset + fieldset input[type=submit] + .btn-group, #headerlinks + fieldset + fieldset + fieldset .btn-group input[type=submit] + .btn-group {
  margin-left: -1px;
}

.btn-group {
  input {
    &[name=logout] + .btn-group, &[name="database_delete"] + input[type="submit"] + a + .btn-group, &[value=Confirm] + a:hover + .btn-group {
      margin-left: -1px;
    }
  }
  .btn-group + .btn, #loginBox form .btn-group + input[type="submit"] {
    margin-left: -1px;
  }
}

#loginBox form .btn-group .btn-group + input[type="submit"], .btn-group div.confirm + fieldset form .btn-group + input[type=submit], div.confirm + fieldset form .btn-group .btn-group + input[type=submit], .btn-group #headerlinks + fieldset + fieldset + fieldset .btn-group + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group .btn-group + input[type=submit] {
  margin-left: -1px;
}

.btn-group {
  .btn-group + input[name=logout] {
    margin-left: -1px;
  }
  input {
    &[name="database_delete"] + input[type="submit"].btn-group + a, &[value=Confirm].btn-group + a:hover {
      margin-left: -1px;
    }
  }
  .btn-group + .btn-group {
    margin-left: -1px;
  }
}

.btn-toolbar {
  margin-left: -5px;
  &:before {
    content: " ";
    display: table;
  }
  &:after {
    content: " ";
    display: table;
    clear: both;
  }
  .btn, #loginBox form input[type="submit"] {
    float: left;
  }
}

#loginBox form .btn-toolbar input[type="submit"], .btn-toolbar div.confirm + fieldset form input[type=submit], div.confirm + fieldset form .btn-toolbar input[type=submit], .btn-toolbar #headerlinks + fieldset + fieldset + fieldset input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-toolbar input[type=submit] {
  float: left;
}

.btn-toolbar {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      float: left;
    }
  }
  .btn-group, .input-group, div.confirm + fieldset form {
    float: left;
  }
}

div.confirm + fieldset .btn-toolbar form {
  float: left;
}

.btn-toolbar > .btn, #loginBox form .btn-toolbar > input[type="submit"], div.confirm + fieldset form .btn-toolbar > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-toolbar > input[type=submit] {
  margin-left: 5px;
}

.btn-toolbar > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      margin-left: 5px;
    }
  }
  .btn-group, .input-group {
    margin-left: 5px;
  }
}

div.confirm + fieldset .btn-toolbar > form {
  margin-left: 5px;
}

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle), #loginBox form .btn-group > input[type="submit"]:not(:first-child):not(:last-child):not(.dropdown-toggle), div.confirm + fieldset form .btn-group > input[type=submit]:not(:first-child):not(:last-child):not(.dropdown-toggle), #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
}

.btn-group > {
  input {
    &[name=logout]:not(:first-child):not(:last-child):not(.dropdown-toggle), &[name="database_delete"] + input[type="submit"] + a:not(:first-child):not(:last-child):not(.dropdown-toggle), &[value=Confirm] + a:not(:first-child):not(:last-child):not(.dropdown-toggle):hover {
      border-radius: 0;
    }
  }
  .btn:first-child {
    margin-left: 0;
  }
}

#loginBox form .btn-group > input[type="submit"]:first-child, div.confirm + fieldset form .btn-group > input[type=submit]:first-child, #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:first-child {
  margin-left: 0;
}

.btn-group > {
  input {
    &[name=logout]:first-child, &[name="database_delete"] + input[type="submit"] + a:first-child, &[value=Confirm] + a:first-child:hover {
      margin-left: 0;
    }
  }
  .btn:first-child:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
  }
}

#loginBox form .btn-group > input[type="submit"]:first-child:not(:last-child):not(.dropdown-toggle), div.confirm + fieldset form .btn-group > input[type=submit]:first-child:not(:last-child):not(.dropdown-toggle), #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:first-child:not(:last-child):not(.dropdown-toggle) {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

.btn-group > {
  input {
    &[name=logout]:first-child:not(:last-child):not(.dropdown-toggle), &[name="database_delete"] + input[type="submit"] + a:first-child:not(:last-child):not(.dropdown-toggle), &[value=Confirm] + a:first-child:not(:last-child):not(.dropdown-toggle):hover {
      border-bottom-right-radius: 0;
      border-top-right-radius: 0;
    }
  }
  .btn:last-child:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
}

#loginBox form .btn-group > input[type="submit"]:last-child:not(:first-child), div.confirm + fieldset form .btn-group > input[type=submit]:last-child:not(:first-child), #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit]:last-child:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

.btn-group > {
  input {
    &[name=logout]:last-child:not(:first-child), &[name="database_delete"] + input[type="submit"] + a:last-child:not(:first-child), &[value=Confirm] + a:last-child:not(:first-child):hover {
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
    }
  }
  .dropdown-toggle:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
  .btn-group {
    float: left;
    &:not(:first-child):not(:last-child) > .btn {
      border-radius: 0;
    }
  }
}

#loginBox form .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type="submit"], div.confirm + fieldset form .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group > .btn-group:not(:first-child):not(:last-child) > input[type=submit] {
  border-radius: 0;
}

.btn-group > .btn-group {
  &:not(:first-child):not(:last-child) > input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      border-radius: 0;
    }
  }
  &:first-child:not(:last-child) > .btn:last-child {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
  }
}

#loginBox form .btn-group > .btn-group:first-child:not(:last-child) > input[type="submit"]:last-child, div.confirm + fieldset form .btn-group > .btn-group:first-child:not(:last-child) > input[type=submit]:last-child, #headerlinks + fieldset + fieldset + fieldset .btn-group > .btn-group:first-child:not(:last-child) > input[type=submit]:last-child {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

.btn-group > .btn-group {
  &:first-child:not(:last-child) > {
    input {
      &[name=logout]:last-child, &[name="database_delete"] + input[type="submit"] + a:last-child, &[value=Confirm] + a:last-child:hover {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0;
      }
    }
    .dropdown-toggle {
      border-bottom-right-radius: 0;
      border-top-right-radius: 0;
    }
  }
  &:last-child:not(:first-child) > .btn:first-child {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
}

#loginBox form .btn-group > .btn-group:last-child:not(:first-child) > input[type="submit"]:first-child, div.confirm + fieldset form .btn-group > .btn-group:last-child:not(:first-child) > input[type=submit]:first-child, #headerlinks + fieldset + fieldset + fieldset .btn-group > .btn-group:last-child:not(:first-child) > input[type=submit]:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

.btn-group {
  > .btn-group:last-child:not(:first-child) > input {
    &[name=logout]:first-child, &[name="database_delete"] + input[type="submit"] + a:first-child, &[value=Confirm] + a:first-child:hover {
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
    }
  }
  .dropdown-toggle:active, &.open .dropdown-toggle {
    outline: 0;
  }
  > .btn + .dropdown-toggle {
    padding-left: 8px;
    padding-right: 8px;
  }
}

#loginBox form .btn-group > input[type="submit"] + .dropdown-toggle, div.confirm + fieldset form .btn-group > input[type=submit] + .dropdown-toggle, #headerlinks + fieldset + fieldset + fieldset .btn-group > input[type=submit] + .dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px;
}

.btn-group > {
  input {
    &[name=logout] + .dropdown-toggle, &[name="database_delete"] + input[type="submit"] + a + .dropdown-toggle, &[value=Confirm] + a:hover + .dropdown-toggle {
      padding-left: 8px;
      padding-right: 8px;
    }
  }
  .btn-lg + .dropdown-toggle {
    padding-left: 12px;
    padding-right: 12px;
  }
}

.btn-group-lg.btn-group > .btn + .dropdown-toggle, #loginBox form .btn-group-lg.btn-group > input[type="submit"] + .dropdown-toggle, div.confirm + fieldset form .btn-group-lg.btn-group > input[type=submit] + .dropdown-toggle, #headerlinks + fieldset + fieldset + fieldset .btn-group-lg.btn-group > input[type=submit] + .dropdown-toggle {
  padding-left: 12px;
  padding-right: 12px;
}

.btn-group-lg.btn-group > input {
  &[name=logout] + .dropdown-toggle, &[name="database_delete"] + input[type="submit"] + a + .dropdown-toggle, &[value=Confirm] + a:hover + .dropdown-toggle {
    padding-left: 12px;
    padding-right: 12px;
  }
}

.btn-group.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  &.btn-link {
    -webkit-box-shadow: none;
    box-shadow: none;
  }
}

.btn .caret, #loginBox form input[type="submit"] .caret, div.confirm + fieldset form input[type=submit] .caret, #headerlinks + fieldset + fieldset + fieldset input[type=submit] .caret {
  margin-left: 0;
}

input {
  &[name=logout] .caret, &[name="database_delete"] + input[type="submit"] + a .caret, &[value=Confirm] + a:hover .caret {
    margin-left: 0;
  }
}

.btn-lg .caret, .btn-group-lg > .btn .caret, #loginBox form .btn-group-lg > input[type="submit"] .caret, div.confirm + fieldset form .btn-group-lg > input[type=submit] .caret, #headerlinks + fieldset + fieldset + fieldset .btn-group-lg > input[type=submit] .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0;
}

.btn-group-lg > input {
  &[name=logout] .caret, &[name="database_delete"] + input[type="submit"] + a .caret, &[value=Confirm] + a:hover .caret {
    border-width: 5px 5px 0;
    border-bottom-width: 0;
  }
}

.dropup {
  .btn-lg .caret, .btn-group-lg > .btn .caret, #loginBox form .btn-group-lg > input[type="submit"] .caret {
    border-width: 0 5px 5px;
  }
}

#loginBox form .dropup .btn-group-lg > input[type="submit"] .caret, .dropup div.confirm + fieldset form .btn-group-lg > input[type=submit] .caret, div.confirm + fieldset form .dropup .btn-group-lg > input[type=submit] .caret, .dropup #headerlinks + fieldset + fieldset + fieldset .btn-group-lg > input[type=submit] .caret, #headerlinks + fieldset + fieldset + fieldset .dropup .btn-group-lg > input[type=submit] .caret {
  border-width: 0 5px 5px;
}

.dropup .btn-group-lg > input {
  &[name=logout] .caret, &[name="database_delete"] + input[type="submit"] + a .caret, &[value=Confirm] + a:hover .caret {
    border-width: 0 5px 5px;
  }
}

.btn-group-vertical > .btn, #loginBox form .btn-group-vertical > input[type="submit"], div.confirm + fieldset form .btn-group-vertical > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit] {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}

.btn-group-vertical > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      display: block;
      float: none;
      width: 100%;
      max-width: 100%;
    }
  }
  .btn-group {
    display: block;
    float: none;
    width: 100%;
    max-width: 100%;
    > .btn {
      display: block;
      float: none;
      width: 100%;
      max-width: 100%;
    }
  }
}

#loginBox form .btn-group-vertical > .btn-group > input[type="submit"], div.confirm + fieldset form .btn-group-vertical > .btn-group > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn-group > input[type=submit] {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}

.btn-group-vertical > .btn-group {
  > input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      display: block;
      float: none;
      width: 100%;
      max-width: 100%;
    }
  }
  &:before {
    content: " ";
    display: table;
  }
  &:after {
    content: " ";
    display: table;
    clear: both;
  }
  > .btn {
    float: none;
  }
}

#loginBox form .btn-group-vertical > .btn-group > input[type="submit"], div.confirm + fieldset form .btn-group-vertical > .btn-group > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn-group > input[type=submit] {
  float: none;
}

.btn-group-vertical > {
  .btn-group > input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      float: none;
    }
  }
  .btn + .btn {
    margin-top: -1px;
    margin-left: 0;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"] + .btn, div.confirm + fieldset form .btn-group-vertical > input[type=submit] + .btn, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit] + .btn {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > input {
  &[name=logout] + .btn, &[name="database_delete"] + input[type="submit"] + a + .btn, &[value=Confirm] + a:hover + .btn {
    margin-top: -1px;
    margin-left: 0;
  }
}

#loginBox form .btn-group-vertical > {
  .btn + input[type="submit"], input[type="submit"] + input[type="submit"] {
    margin-top: -1px;
    margin-left: 0;
  }
}

div.confirm + fieldset #loginBox form .btn-group-vertical > input[type=submit] + input[type="submit"], #loginBox div.confirm + fieldset form .btn-group-vertical > input[type=submit] + input[type="submit"], #headerlinks + fieldset + fieldset + fieldset #loginBox form .btn-group-vertical > input[type=submit] + input[type="submit"] {
  margin-top: -1px;
  margin-left: 0;
}

#loginBox form {
  #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit] + input[type="submit"] {
    margin-top: -1px;
    margin-left: 0;
  }
  .btn-group-vertical > input {
    &[name=logout] + input[type="submit"], &[name="database_delete"] + input[type="submit"] + a + input[type="submit"], &[value=Confirm] + a:hover + input[type="submit"] {
      margin-top: -1px;
      margin-left: 0;
    }
  }
}

div.confirm + fieldset form .btn-group-vertical > .btn + input[type=submit], #loginBox div.confirm + fieldset form .btn-group-vertical > input[type="submit"] + input[type=submit] {
  margin-top: -1px;
  margin-left: 0;
}

div.confirm + fieldset {
  #loginBox form .btn-group-vertical > input[type="submit"] + input[type=submit] {
    margin-top: -1px;
    margin-left: 0;
  }
  form .btn-group-vertical > input {
    &[type=submit] + input[type=submit], &[name=logout] + input[type=submit], &[name="database_delete"] + input[type="submit"] + a + input[type=submit], &[value=Confirm] + a:hover + input[type=submit] {
      margin-top: -1px;
      margin-left: 0;
    }
  }
}

#headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn + input[type=submit], #loginBox form #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type="submit"] + input[type=submit] {
  margin-top: -1px;
  margin-left: 0;
}

#headerlinks + fieldset + fieldset + fieldset {
  #loginBox form .btn-group-vertical > input[type="submit"] + input[type=submit] {
    margin-top: -1px;
    margin-left: 0;
  }
  .btn-group-vertical > input {
    &[type=submit] + input[type=submit], &[name=logout] + input[type=submit], &[name="database_delete"] + input[type="submit"] + a + input[type=submit], &[value=Confirm] + a:hover + input[type=submit] {
      margin-top: -1px;
      margin-left: 0;
    }
  }
}

.btn-group-vertical > .btn + input[name=logout], #loginBox form .btn-group-vertical > input[type="submit"] + input[name=logout], div.confirm + fieldset form .btn-group-vertical > input[type=submit] + input[name=logout], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit] + input[name=logout] {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > input {
  &[name=logout] + input[name=logout], &[name="database_delete"] + input[type="submit"] + a + input[name=logout], &[value=Confirm] + a:hover + input[name=logout], &[name="database_delete"] + input[type="submit"].btn + a {
    margin-top: -1px;
    margin-left: 0;
  }
}

#loginBox form .btn-group-vertical > input[name="database_delete"] + input[type="submit"] + a, div.confirm + fieldset form .btn-group-vertical > input[name="database_delete"] + input[type="submit"][type=submit] + a, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[name="database_delete"] + input[type="submit"][type=submit] + a {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > input {
  &[name="database_delete"] + input[type="submit"][name=logout] + a, &[value=Confirm].btn + a:hover {
    margin-top: -1px;
    margin-left: 0;
  }
}

#loginBox form .btn-group-vertical > input[value=Confirm][type="submit"] + a:hover, div.confirm + fieldset form .btn-group-vertical > input[value=Confirm][type=submit] + a:hover, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[value=Confirm][type=submit] + a:hover {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > {
  input[value=Confirm][name=logout] + a:hover, .btn + .btn-group {
    margin-top: -1px;
    margin-left: 0;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"] + .btn-group, div.confirm + fieldset form .btn-group-vertical > input[type=submit] + .btn-group, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit] + .btn-group {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > {
  input {
    &[name=logout] + .btn-group, &[name="database_delete"] + input[type="submit"] + a + .btn-group, &[value=Confirm] + a:hover + .btn-group {
      margin-top: -1px;
      margin-left: 0;
    }
  }
  .btn-group + .btn {
    margin-top: -1px;
    margin-left: 0;
  }
}

#loginBox form .btn-group-vertical > .btn-group + input[type="submit"], div.confirm + fieldset form .btn-group-vertical > .btn-group + input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn-group + input[type=submit] {
  margin-top: -1px;
  margin-left: 0;
}

.btn-group-vertical > {
  .btn-group + input[name=logout] {
    margin-top: -1px;
    margin-left: 0;
  }
  input {
    &[name="database_delete"] + input[type="submit"].btn-group + a, &[value=Confirm].btn-group + a:hover {
      margin-top: -1px;
      margin-left: 0;
    }
  }
  .btn-group + .btn-group {
    margin-top: -1px;
    margin-left: 0;
  }
  .btn:not(:first-child):not(:last-child) {
    border-radius: 0;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"]:not(:first-child):not(:last-child), div.confirm + fieldset form .btn-group-vertical > input[type=submit]:not(:first-child):not(:last-child), #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit]:not(:first-child):not(:last-child) {
  border-radius: 0;
}

.btn-group-vertical > {
  input {
    &[name=logout]:not(:first-child):not(:last-child), &[name="database_delete"] + input[type="submit"] + a:not(:first-child):not(:last-child), &[value=Confirm] + a:not(:first-child):not(:last-child):hover {
      border-radius: 0;
    }
  }
  .btn:first-child:not(:last-child) {
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"]:first-child:not(:last-child), div.confirm + fieldset form .btn-group-vertical > input[type=submit]:first-child:not(:last-child), #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit]:first-child:not(:last-child) {
  border-top-right-radius: 4px;
  border-top-left-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.btn-group-vertical > {
  input {
    &[name=logout]:first-child:not(:last-child), &[name="database_delete"] + input[type="submit"] + a:first-child:not(:last-child), &[value=Confirm] + a:first-child:not(:last-child):hover {
      border-top-right-radius: 4px;
      border-top-left-radius: 4px;
      border-bottom-right-radius: 0;
      border-bottom-left-radius: 0;
    }
  }
  .btn:last-child:not(:first-child) {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px;
  }
}

#loginBox form .btn-group-vertical > input[type="submit"]:last-child:not(:first-child), div.confirm + fieldset form .btn-group-vertical > input[type=submit]:last-child:not(:first-child), #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > input[type=submit]:last-child:not(:first-child) {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}

.btn-group-vertical > {
  input {
    &[name=logout]:last-child:not(:first-child), &[name="database_delete"] + input[type="submit"] + a:last-child:not(:first-child), &[value=Confirm] + a:last-child:not(:first-child):hover {
      border-top-right-radius: 0;
      border-top-left-radius: 0;
      border-bottom-right-radius: 4px;
      border-bottom-left-radius: 4px;
    }
  }
  .btn-group:not(:first-child):not(:last-child) > .btn {
    border-radius: 0;
  }
}

#loginBox form .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type="submit"], div.confirm + fieldset form .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > input[type=submit] {
  border-radius: 0;
}

.btn-group-vertical > .btn-group {
  &:not(:first-child):not(:last-child) > input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      border-radius: 0;
    }
  }
  &:first-child:not(:last-child) > .btn:last-child {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
  }
}

#loginBox form .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type="submit"]:last-child, div.confirm + fieldset form .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type=submit]:last-child, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn-group:first-child:not(:last-child) > input[type=submit]:last-child {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.btn-group-vertical > .btn-group {
  &:first-child:not(:last-child) > {
    input {
      &[name=logout]:last-child, &[name="database_delete"] + input[type="submit"] + a:last-child, &[value=Confirm] + a:last-child:hover {
        border-bottom-right-radius: 0;
        border-bottom-left-radius: 0;
      }
    }
    .dropdown-toggle {
      border-bottom-right-radius: 0;
      border-bottom-left-radius: 0;
    }
  }
  &:last-child:not(:first-child) > .btn:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
  }
}

#loginBox form .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type="submit"]:first-child, div.confirm + fieldset form .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type=submit]:first-child, #headerlinks + fieldset + fieldset + fieldset .btn-group-vertical > .btn-group:last-child:not(:first-child) > input[type=submit]:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

.btn-group-vertical > .btn-group:last-child:not(:first-child) > input {
  &[name=logout]:first-child, &[name="database_delete"] + input[type="submit"] + a:first-child, &[value=Confirm] + a:first-child:hover {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
  }
}

.btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
  > .btn {
    float: none;
    display: table-cell;
    width: 1%;
  }
}

#loginBox form .btn-group-justified > input[type="submit"], div.confirm + fieldset form .btn-group-justified > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-justified > input[type=submit] {
  float: none;
  display: table-cell;
  width: 1%;
}

.btn-group-justified > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      float: none;
      display: table-cell;
      width: 1%;
    }
  }
  .btn-group {
    float: none;
    display: table-cell;
    width: 1%;
    .btn, #loginBox form input[type="submit"] {
      width: 100%;
    }
  }
}

#loginBox form .btn-group-justified > .btn-group input[type="submit"], .btn-group-justified > .btn-group div.confirm + fieldset form input[type=submit], div.confirm + fieldset form .btn-group-justified > .btn-group input[type=submit], .btn-group-justified > .btn-group #headerlinks + fieldset + fieldset + fieldset input[type=submit], #headerlinks + fieldset + fieldset + fieldset .btn-group-justified > .btn-group input[type=submit] {
  width: 100%;
}

.btn-group-justified > .btn-group {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      width: 100%;
    }
  }
  .dropdown-menu {
    left: auto;
  }
}

[data-toggle="buttons"] > .btn input[type="radio"], #loginBox form [data-toggle="buttons"] > input[type="submit"] input[type="radio"], div.confirm + fieldset form [data-toggle="buttons"] > input[type=submit] input[type="radio"], #headerlinks + fieldset + fieldset + fieldset [data-toggle="buttons"] > input[type=submit] input[type="radio"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}

[data-toggle="buttons"] > {
  input {
    &[name=logout] input[type="radio"], &[name="database_delete"] + input[type="submit"] + a input[type="radio"], &[value=Confirm] + a:hover input[type="radio"] {
      position: absolute;
      clip: rect(0, 0, 0, 0);
      pointer-events: none;
    }
  }
  .btn input[type="checkbox"] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none;
  }
}

#loginBox form [data-toggle="buttons"] > input[type="submit"] input[type="checkbox"], div.confirm + fieldset form [data-toggle="buttons"] > input[type=submit] input[type="checkbox"], #headerlinks + fieldset + fieldset + fieldset [data-toggle="buttons"] > input[type=submit] input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}

[data-toggle="buttons"] > {
  input {
    &[name=logout] input[type="checkbox"], &[name="database_delete"] + input[type="submit"] + a input[type="checkbox"], &[value=Confirm] + a:hover input[type="checkbox"] {
      position: absolute;
      clip: rect(0, 0, 0, 0);
      pointer-events: none;
    }
  }
  .btn-group > .btn input[type="radio"] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none;
  }
}

#loginBox form [data-toggle="buttons"] > .btn-group > input[type="submit"] input[type="radio"], div.confirm + fieldset form [data-toggle="buttons"] > .btn-group > input[type=submit] input[type="radio"], #headerlinks + fieldset + fieldset + fieldset [data-toggle="buttons"] > .btn-group > input[type=submit] input[type="radio"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}

[data-toggle="buttons"] > .btn-group > {
  input {
    &[name=logout] input[type="radio"], &[name="database_delete"] + input[type="submit"] + a input[type="radio"], &[value=Confirm] + a:hover input[type="radio"] {
      position: absolute;
      clip: rect(0, 0, 0, 0);
      pointer-events: none;
    }
  }
  .btn input[type="checkbox"] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none;
  }
}

#loginBox form [data-toggle="buttons"] > .btn-group > input[type="submit"] input[type="checkbox"], div.confirm + fieldset form [data-toggle="buttons"] > .btn-group > input[type=submit] input[type="checkbox"], #headerlinks + fieldset + fieldset + fieldset [data-toggle="buttons"] > .btn-group > input[type=submit] input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}

[data-toggle="buttons"] > .btn-group > input {
  &[name=logout] input[type="checkbox"], &[name="database_delete"] + input[type="submit"] + a input[type="checkbox"], &[value=Confirm] + a:hover input[type="checkbox"] {
    position: absolute;
    clip: rect(0, 0, 0, 0);
    pointer-events: none;
  }
}

.input-group, div.confirm + fieldset form {
  position: relative;
  display: table;
  border-collapse: separate;
}

.input-group[class*="col-"], div.confirm + fieldset form[class*="col-"] {
  float: none;
  padding-left: 0;
  padding-right: 0;
}

.input-group .form-control, div.confirm + fieldset form .form-control, .input-group #loginBox form input[type="password"], #loginBox form .input-group input[type="password"], div.confirm + fieldset #loginBox form input[type="password"], #loginBox div.confirm + fieldset form input[type="password"], div.confirm + fieldset form input[type=text], .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group input[type=text], div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=text], .input-group input[name=newname], div.confirm + fieldset form input[name=newname], .input-group input[name=tablefields], div.confirm + fieldset form input[name=tablefields], .input-group input[name=select], div.confirm + fieldset form input[name=select], .input-group input[name=tablename], div.confirm + fieldset form input[name=tablename], .input-group input[name=viewname], div.confirm + fieldset form input[name=viewname], .input-group input[name=numRows], div.confirm + fieldset form input[name=numRows], .input-group input[name=startRow], div.confirm + fieldset form input[name=startRow], .input-group select[name=viewtype], div.confirm + fieldset form select[name=viewtype], .input-group select[name=type], div.confirm + fieldset form select[name=type] {
  position: relative;
  z-index: 2;
  float: left;
  width: 100%;
  margin-bottom: 0;
}

.input-group .form-control:focus, div.confirm + fieldset form .form-control:focus, .input-group #loginBox form input[type="password"]:focus, #loginBox form .input-group input[type="password"]:focus, div.confirm + fieldset #loginBox form input[type="password"]:focus, #loginBox div.confirm + fieldset form input[type="password"]:focus, div.confirm + fieldset form input[type=text]:focus, .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text]:focus, #headerlinks + fieldset + fieldset + fieldset .input-group input[type=text]:focus, div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text]:focus, #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=text]:focus, .input-group input[name=newname]:focus, div.confirm + fieldset form input[name=newname]:focus, .input-group input[name=tablefields]:focus, div.confirm + fieldset form input[name=tablefields]:focus, .input-group input[name=select]:focus, div.confirm + fieldset form input[name=select]:focus, .input-group input[name=tablename]:focus, div.confirm + fieldset form input[name=tablename]:focus, .input-group input[name=viewname]:focus, div.confirm + fieldset form input[name=viewname]:focus, .input-group input[name=numRows]:focus, div.confirm + fieldset form input[name=numRows]:focus, .input-group input[name=startRow]:focus, div.confirm + fieldset form input[name=startRow]:focus, .input-group select[name=viewtype]:focus, div.confirm + fieldset form select[name=viewtype]:focus, .input-group select[name=type]:focus, div.confirm + fieldset form select[name=type]:focus {
  z-index: 3;
}

.input-group-addon, .input-group-btn, .input-group .form-control, div.confirm + fieldset form .form-control, .input-group #loginBox form input[type="password"], #loginBox form .input-group input[type="password"], div.confirm + fieldset #loginBox form input[type="password"], #loginBox div.confirm + fieldset form input[type="password"], div.confirm + fieldset form input[type=text], .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group input[type=text], div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text], #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=text], .input-group input[name=newname], div.confirm + fieldset form input[name=newname], .input-group input[name=tablefields], div.confirm + fieldset form input[name=tablefields], .input-group input[name=select], div.confirm + fieldset form input[name=select], .input-group input[name=tablename], div.confirm + fieldset form input[name=tablename], .input-group input[name=viewname], div.confirm + fieldset form input[name=viewname], .input-group input[name=numRows], div.confirm + fieldset form input[name=numRows], .input-group input[name=startRow], div.confirm + fieldset form input[name=startRow], .input-group select[name=viewtype], div.confirm + fieldset form select[name=viewtype], .input-group select[name=type], div.confirm + fieldset form select[name=type] {
  display: table-cell;
}

.input-group-addon:not(:first-child):not(:last-child), .input-group-btn:not(:first-child):not(:last-child), .input-group .form-control:not(:first-child):not(:last-child), div.confirm + fieldset form .form-control:not(:first-child):not(:last-child), .input-group #loginBox form input[type="password"]:not(:first-child):not(:last-child), #loginBox form .input-group input[type="password"]:not(:first-child):not(:last-child), div.confirm + fieldset #loginBox form input[type="password"]:not(:first-child):not(:last-child), #loginBox div.confirm + fieldset form input[type="password"]:not(:first-child):not(:last-child), div.confirm + fieldset form input[type=text]:not(:first-child):not(:last-child), .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text]:not(:first-child):not(:last-child), #headerlinks + fieldset + fieldset + fieldset .input-group input[type=text]:not(:first-child):not(:last-child), div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text]:not(:first-child):not(:last-child), #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=text]:not(:first-child):not(:last-child), .input-group input[name=newname]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=newname]:not(:first-child):not(:last-child), .input-group input[name=tablefields]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=tablefields]:not(:first-child):not(:last-child), .input-group input[name=select]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=select]:not(:first-child):not(:last-child), .input-group input[name=tablename]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=tablename]:not(:first-child):not(:last-child), .input-group input[name=viewname]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=viewname]:not(:first-child):not(:last-child), .input-group input[name=numRows]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=numRows]:not(:first-child):not(:last-child), .input-group input[name=startRow]:not(:first-child):not(:last-child), div.confirm + fieldset form input[name=startRow]:not(:first-child):not(:last-child), .input-group select[name=viewtype]:not(:first-child):not(:last-child), div.confirm + fieldset form select[name=viewtype]:not(:first-child):not(:last-child), .input-group select[name=type]:not(:first-child):not(:last-child), div.confirm + fieldset form select[name=type]:not(:first-child):not(:last-child) {
  border-radius: 0;
}

.input-group-addon, .input-group-btn {
  width: 1%;
  white-space: nowrap;
  vertical-align: middle;
}

.input-group-addon {
  padding: 6px 12px;
  font-size: 14px;
  font-weight: normal;
  line-height: 1;
  color: #555;
  text-align: center;
  background-color: #eee;
  border: 1px solid #ccc;
  border-radius: 4px;
  &.input-sm {
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 3px;
  }
}

#loginBox form .input-group-sm > input.input-group-addon[type="password"], div.confirm + fieldset form .input-group-sm > input.input-group-addon[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > input.input-group-addon[type=text] {
  padding: 5px 10px;
  font-size: 12px;
  border-radius: 3px;
}

.input-group-sm > {
  .input-group-addon, .input-group-btn > .input-group-addon.btn {
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 3px;
  }
}

#loginBox form .input-group-sm > .input-group-btn > input.input-group-addon[type="submit"], div.confirm + fieldset form .input-group-sm > .input-group-btn > input.input-group-addon[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-sm > .input-group-btn > input.input-group-addon[type=submit] {
  padding: 5px 10px;
  font-size: 12px;
  border-radius: 3px;
}

.input-group-sm > .input-group-btn > input {
  &.input-group-addon[name=logout], &[name="database_delete"] + input[type="submit"] + a.input-group-addon, &[value=Confirm] + a.input-group-addon:hover {
    padding: 5px 10px;
    font-size: 12px;
    border-radius: 3px;
  }
}

.input-group-addon.input-lg, #loginBox form .input-group-lg > input.input-group-addon[type="password"], div.confirm + fieldset form .input-group-lg > input.input-group-addon[type=text], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > input.input-group-addon[type=text] {
  padding: 10px 16px;
  font-size: 18px;
  border-radius: 6px;
}

.input-group-lg > {
  .input-group-addon, .input-group-btn > .input-group-addon.btn {
    padding: 10px 16px;
    font-size: 18px;
    border-radius: 6px;
  }
}

#loginBox form .input-group-lg > .input-group-btn > input.input-group-addon[type="submit"], div.confirm + fieldset form .input-group-lg > .input-group-btn > input.input-group-addon[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-lg > .input-group-btn > input.input-group-addon[type=submit] {
  padding: 10px 16px;
  font-size: 18px;
  border-radius: 6px;
}

.input-group-lg > .input-group-btn > input {
  &.input-group-addon[name=logout], &[name="database_delete"] + input[type="submit"] + a.input-group-addon, &[value=Confirm] + a.input-group-addon:hover {
    padding: 10px 16px;
    font-size: 18px;
    border-radius: 6px;
  }
}

.input-group-addon input {
  &[type="radio"], &[type="checkbox"] {
    margin-top: 0;
  }
}

.input-group .form-control:first-child, div.confirm + fieldset form .form-control:first-child, .input-group #loginBox form input[type="password"]:first-child, #loginBox form .input-group input[type="password"]:first-child, div.confirm + fieldset #loginBox form input[type="password"]:first-child, #loginBox div.confirm + fieldset form input[type="password"]:first-child, div.confirm + fieldset form input[type=text]:first-child, .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text]:first-child, #headerlinks + fieldset + fieldset + fieldset .input-group input[type=text]:first-child, div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text]:first-child, #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=text]:first-child, .input-group input[name=newname]:first-child, div.confirm + fieldset form input[name=newname]:first-child, .input-group input[name=tablefields]:first-child, div.confirm + fieldset form input[name=tablefields]:first-child, .input-group input[name=select]:first-child, div.confirm + fieldset form input[name=select]:first-child, .input-group input[name=tablename]:first-child, div.confirm + fieldset form input[name=tablename]:first-child, .input-group input[name=viewname]:first-child, div.confirm + fieldset form input[name=viewname]:first-child, .input-group input[name=numRows]:first-child, div.confirm + fieldset form input[name=numRows]:first-child, .input-group input[name=startRow]:first-child, div.confirm + fieldset form input[name=startRow]:first-child, .input-group select[name=viewtype]:first-child, div.confirm + fieldset form select[name=viewtype]:first-child, .input-group select[name=type]:first-child, div.confirm + fieldset form select[name=type]:first-child, .input-group-addon:first-child, .input-group-btn:first-child > .btn, #loginBox form .input-group-btn:first-child > input[type="submit"], div.confirm + fieldset form .input-group-btn:first-child > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:first-child > input[type=submit] {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

.input-group-btn:first-child > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      border-bottom-right-radius: 0;
      border-top-right-radius: 0;
    }
  }
  .btn-group > .btn {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
  }
}

#loginBox form .input-group-btn:first-child > .btn-group > input[type="submit"], div.confirm + fieldset form .input-group-btn:first-child > .btn-group > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:first-child > .btn-group > input[type=submit] {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

.input-group-btn {
  &:first-child > {
    .btn-group > input {
      &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0;
      }
    }
    .dropdown-toggle {
      border-bottom-right-radius: 0;
      border-top-right-radius: 0;
    }
  }
  &:last-child > .btn:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
  }
}

#loginBox form .input-group-btn:last-child > input[type="submit"]:not(:last-child):not(.dropdown-toggle), div.confirm + fieldset form .input-group-btn:last-child > input[type=submit]:not(:last-child):not(.dropdown-toggle), #headerlinks + fieldset + fieldset + fieldset .input-group-btn:last-child > input[type=submit]:not(:last-child):not(.dropdown-toggle) {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

.input-group-btn:last-child > {
  input {
    &[name=logout]:not(:last-child):not(.dropdown-toggle), &[name="database_delete"] + input[type="submit"] + a:not(:last-child):not(.dropdown-toggle), &[value=Confirm] + a:not(:last-child):not(.dropdown-toggle):hover {
      border-bottom-right-radius: 0;
      border-top-right-radius: 0;
    }
  }
  .btn-group:not(:last-child) > .btn {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
  }
}

#loginBox form .input-group-btn:last-child > .btn-group:not(:last-child) > input[type="submit"], div.confirm + fieldset form .input-group-btn:last-child > .btn-group:not(:last-child) > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:last-child > .btn-group:not(:last-child) > input[type=submit] {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

.input-group-btn:last-child > .btn-group:not(:last-child) > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0;
  }
}

.input-group-addon:first-child {
  border-right: 0;
}

.input-group .form-control:last-child, div.confirm + fieldset form .form-control:last-child, .input-group #loginBox form input[type="password"]:last-child, #loginBox form .input-group input[type="password"]:last-child, div.confirm + fieldset #loginBox form input[type="password"]:last-child, #loginBox div.confirm + fieldset form input[type="password"]:last-child, div.confirm + fieldset form input[type=text]:last-child, .input-group #headerlinks + fieldset + fieldset + fieldset input[type=text]:last-child, #headerlinks + fieldset + fieldset + fieldset .input-group input[type=text]:last-child, div.confirm + fieldset form #headerlinks + fieldset + fieldset + fieldset input[type=text]:last-child, #headerlinks + fieldset + fieldset + fieldset div.confirm + fieldset form input[type=text]:last-child, .input-group input[name=newname]:last-child, div.confirm + fieldset form input[name=newname]:last-child, .input-group input[name=tablefields]:last-child, div.confirm + fieldset form input[name=tablefields]:last-child, .input-group input[name=select]:last-child, div.confirm + fieldset form input[name=select]:last-child, .input-group input[name=tablename]:last-child, div.confirm + fieldset form input[name=tablename]:last-child, .input-group input[name=viewname]:last-child, div.confirm + fieldset form input[name=viewname]:last-child, .input-group input[name=numRows]:last-child, div.confirm + fieldset form input[name=numRows]:last-child, .input-group input[name=startRow]:last-child, div.confirm + fieldset form input[name=startRow]:last-child, .input-group select[name=viewtype]:last-child, div.confirm + fieldset form select[name=viewtype]:last-child, .input-group select[name=type]:last-child, div.confirm + fieldset form select[name=type]:last-child, .input-group-addon:last-child, .input-group-btn:last-child > .btn, #loginBox form .input-group-btn:last-child > input[type="submit"], div.confirm + fieldset form .input-group-btn:last-child > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:last-child > input[type=submit] {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

.input-group-btn:last-child > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
    }
  }
  .btn-group > .btn {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
}

#loginBox form .input-group-btn:last-child > .btn-group > input[type="submit"], div.confirm + fieldset form .input-group-btn:last-child > .btn-group > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:last-child > .btn-group > input[type=submit] {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

.input-group-btn {
  &:last-child > {
    .btn-group > input {
      &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
        border-bottom-left-radius: 0;
        border-top-left-radius: 0;
      }
    }
    .dropdown-toggle {
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
    }
  }
  &:first-child > .btn:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
}

#loginBox form .input-group-btn:first-child > input[type="submit"]:not(:first-child), div.confirm + fieldset form .input-group-btn:first-child > input[type=submit]:not(:first-child), #headerlinks + fieldset + fieldset + fieldset .input-group-btn:first-child > input[type=submit]:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

.input-group-btn:first-child > {
  input {
    &[name=logout]:not(:first-child), &[name="database_delete"] + input[type="submit"] + a:not(:first-child), &[value=Confirm] + a:not(:first-child):hover {
      border-bottom-left-radius: 0;
      border-top-left-radius: 0;
    }
  }
  .btn-group:not(:first-child) > .btn {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
}

#loginBox form .input-group-btn:first-child > .btn-group:not(:first-child) > input[type="submit"], div.confirm + fieldset form .input-group-btn:first-child > .btn-group:not(:first-child) > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:first-child > .btn-group:not(:first-child) > input[type=submit] {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

.input-group-btn:first-child > .btn-group:not(:first-child) > input {
  &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0;
  }
}

.input-group-addon:last-child {
  border-left: 0;
}

.input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap;
  > .btn {
    position: relative;
  }
}

#loginBox form .input-group-btn > input[type="submit"], div.confirm + fieldset form .input-group-btn > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit] {
  position: relative;
}

.input-group-btn > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      position: relative;
    }
  }
  .btn + .btn {
    margin-left: -1px;
  }
}

#loginBox form .input-group-btn > input[type="submit"] + .btn, div.confirm + fieldset form .input-group-btn > input[type=submit] + .btn, #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit] + .btn {
  margin-left: -1px;
}

.input-group-btn > input {
  &[name=logout] + .btn, &[name="database_delete"] + input[type="submit"] + a + .btn, &[value=Confirm] + a:hover + .btn {
    margin-left: -1px;
  }
}

#loginBox form .input-group-btn > {
  .btn + input[type="submit"], input[type="submit"] + input[type="submit"] {
    margin-left: -1px;
  }
}

div.confirm + fieldset #loginBox form .input-group-btn > input[type=submit] + input[type="submit"], #loginBox div.confirm + fieldset form .input-group-btn > input[type=submit] + input[type="submit"], #headerlinks + fieldset + fieldset + fieldset #loginBox form .input-group-btn > input[type=submit] + input[type="submit"] {
  margin-left: -1px;
}

#loginBox form {
  #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit] + input[type="submit"] {
    margin-left: -1px;
  }
  .input-group-btn > input {
    &[name=logout] + input[type="submit"], &[name="database_delete"] + input[type="submit"] + a + input[type="submit"], &[value=Confirm] + a:hover + input[type="submit"] {
      margin-left: -1px;
    }
  }
}

div.confirm + fieldset form .input-group-btn > .btn + input[type=submit], #loginBox div.confirm + fieldset form .input-group-btn > input[type="submit"] + input[type=submit] {
  margin-left: -1px;
}

div.confirm + fieldset {
  #loginBox form .input-group-btn > input[type="submit"] + input[type=submit] {
    margin-left: -1px;
  }
  form .input-group-btn > input {
    &[type=submit] + input[type=submit], &[name=logout] + input[type=submit], &[name="database_delete"] + input[type="submit"] + a + input[type=submit], &[value=Confirm] + a:hover + input[type=submit] {
      margin-left: -1px;
    }
  }
}

#headerlinks + fieldset + fieldset + fieldset .input-group-btn > .btn + input[type=submit], #loginBox form #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type="submit"] + input[type=submit] {
  margin-left: -1px;
}

#headerlinks + fieldset + fieldset + fieldset {
  #loginBox form .input-group-btn > input[type="submit"] + input[type=submit] {
    margin-left: -1px;
  }
  .input-group-btn > input {
    &[type=submit] + input[type=submit], &[name=logout] + input[type=submit], &[name="database_delete"] + input[type="submit"] + a + input[type=submit], &[value=Confirm] + a:hover + input[type=submit] {
      margin-left: -1px;
    }
  }
}

.input-group-btn > .btn + input[name=logout], #loginBox form .input-group-btn > input[type="submit"] + input[name=logout], div.confirm + fieldset form .input-group-btn > input[type=submit] + input[name=logout], #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit] + input[name=logout] {
  margin-left: -1px;
}

.input-group-btn > input {
  &[name=logout] + input[name=logout], &[name="database_delete"] + input[type="submit"] + a + input[name=logout], &[value=Confirm] + a:hover + input[name=logout], &[name="database_delete"] + input[type="submit"].btn + a {
    margin-left: -1px;
  }
}

#loginBox form .input-group-btn > input[name="database_delete"] + input[type="submit"] + a, div.confirm + fieldset form .input-group-btn > input[name="database_delete"] + input[type="submit"][type=submit] + a, #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[name="database_delete"] + input[type="submit"][type=submit] + a {
  margin-left: -1px;
}

.input-group-btn > input {
  &[name="database_delete"] + input[type="submit"][name=logout] + a, &[value=Confirm].btn + a:hover {
    margin-left: -1px;
  }
}

#loginBox form .input-group-btn > input[value=Confirm][type="submit"] + a:hover, div.confirm + fieldset form .input-group-btn > input[value=Confirm][type=submit] + a:hover, #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[value=Confirm][type=submit] + a:hover {
  margin-left: -1px;
}

.input-group-btn > {
  input[value=Confirm][name=logout] + a:hover {
    margin-left: -1px;
  }
  .btn:hover {
    z-index: 2;
  }
}

#loginBox form .input-group-btn > input[type="submit"]:hover, div.confirm + fieldset form .input-group-btn > input[type=submit]:hover, #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit]:hover {
  z-index: 2;
}

.input-group-btn > {
  input {
    &[name=logout]:hover, &[name="database_delete"] + input[type="submit"] + a:hover, &[value=Confirm] + a:hover {
      z-index: 2;
    }
  }
  .btn:focus {
    z-index: 2;
  }
}

#loginBox form .input-group-btn > input[type="submit"]:focus, div.confirm + fieldset form .input-group-btn > input[type=submit]:focus, #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit]:focus {
  z-index: 2;
}

.input-group-btn > {
  input {
    &[name=logout]:focus, &[name="database_delete"] + input[type="submit"] + a:focus, &[value=Confirm] + a:focus:hover {
      z-index: 2;
    }
  }
  .btn:active {
    z-index: 2;
  }
}

#loginBox form .input-group-btn > input[type="submit"]:active, div.confirm + fieldset form .input-group-btn > input[type=submit]:active, #headerlinks + fieldset + fieldset + fieldset .input-group-btn > input[type=submit]:active {
  z-index: 2;
}

.input-group-btn {
  > input {
    &[name=logout]:active, &[name="database_delete"] + input[type="submit"] + a:active, &[value=Confirm] + a:active:hover {
      z-index: 2;
    }
  }
  &:first-child > .btn {
    margin-right: -1px;
  }
}

#loginBox form .input-group-btn:first-child > input[type="submit"], div.confirm + fieldset form .input-group-btn:first-child > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:first-child > input[type=submit] {
  margin-right: -1px;
}

.input-group-btn {
  &:first-child > {
    input {
      &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
        margin-right: -1px;
      }
    }
    .btn-group {
      margin-right: -1px;
    }
  }
  &:last-child > .btn {
    z-index: 2;
    margin-left: -1px;
  }
}

#loginBox form .input-group-btn:last-child > input[type="submit"], div.confirm + fieldset form .input-group-btn:last-child > input[type=submit], #headerlinks + fieldset + fieldset + fieldset .input-group-btn:last-child > input[type=submit] {
  z-index: 2;
  margin-left: -1px;
}

.input-group-btn:last-child > {
  input {
    &[name=logout], &[name="database_delete"] + input[type="submit"] + a, &[value=Confirm] + a:hover {
      z-index: 2;
      margin-left: -1px;
    }
  }
  .btn-group {
    z-index: 2;
    margin-left: -1px;
  }
}

.alert, #loginBox div span.warning, div.confirm {
  padding: 15px;
  margin-bottom: 20px;
  border: 1px solid transparent;
  border-radius: 4px;
}

.alert h4, #loginBox div span.warning h4, div.confirm h4 {
  margin-top: 0;
  color: inherit;
}

.alert .alert-link, #loginBox div span.warning .alert-link, div.confirm .alert-link {
  font-weight: bold;
}

.alert > p, #loginBox div span.warning > p, div.confirm > p, .alert > ul, #loginBox div span.warning > ul, div.confirm > ul {
  margin-bottom: 0;
}

.alert > p + p, #loginBox div span.warning > p + p, div.confirm > p + p {
  margin-top: 5px;
}

.alert-dismissable, .alert-dismissible {
  padding-right: 35px;
}

.alert-dismissable .close, .alert-dismissible .close {
  position: relative;
  top: -2px;
  right: -21px;
  color: inherit;
}

.alert-success {
  background-color: #dff0d8;
  border-color: #d6e9c6;
  color: #3c763d;
  hr {
    border-top-color: #c9e2b3;
  }
  .alert-link {
    color: #2b542c;
  }
}

.alert-info, div.confirm {
  background-color: #d9edf7;
  border-color: #bce8f1;
  color: #31708f;
}

.alert-info hr, div.confirm hr {
  border-top-color: #a6e1ec;
}

.alert-info .alert-link, div.confirm .alert-link {
  color: #245269;
}

.alert-warning {
  background-color: #fcf8e3;
  border-color: #faebcc;
  color: #8a6d3b;
  hr {
    border-top-color: #f7e1b5;
  }
  .alert-link {
    color: #66512c;
  }
}

.alert-danger, #loginBox div span.warning {
  background-color: #f2dede;
  border-color: #ebccd1;
  color: #a94442;
}

.alert-danger hr, #loginBox div span.warning hr {
  border-top-color: #e4b9c0;
}

.alert-danger .alert-link, #loginBox div span.warning .alert-link {
  color: #843534;
}

.list-group, #headerlinks + fieldset {
  margin-bottom: 20px;
  padding-left: 0;
}

.list-group-item {
  position: relative;
  display: block;
  padding: 10px 15px;
  margin-bottom: -1px;
  background-color: #fff;
  border: 1px solid #ddd;
}

#headerlinks + fieldset {
  legend {
    position: relative;
    display: block;
    padding: 10px 15px;
    margin-bottom: -1px;
    background-color: #fff;
    border: 1px solid #ddd;
  }
  + fieldset {
    legend, + fieldset legend {
      position: relative;
      display: block;
      padding: 10px 15px;
      margin-bottom: -1px;
      background-color: #fff;
      border: 1px solid #ddd;
    }
  }
}

.list-group-item:first-child {
  border-top-right-radius: 4px;
  border-top-left-radius: 4px;
}

#headerlinks + fieldset {
  legend:first-child {
    border-top-right-radius: 4px;
    border-top-left-radius: 4px;
  }
  + fieldset {
    legend:first-child, + fieldset legend:first-child {
      border-top-right-radius: 4px;
      border-top-left-radius: 4px;
    }
  }
}

.list-group-item:last-child {
  margin-bottom: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}

#headerlinks + fieldset {
  legend:last-child {
    margin-bottom: 0;
    border-bottom-right-radius: 4px;
    border-bottom-left-radius: 4px;
  }
  + fieldset {
    legend:last-child, + fieldset legend:last-child {
      margin-bottom: 0;
      border-bottom-right-radius: 4px;
      border-bottom-left-radius: 4px;
    }
  }
}

a.list-group-item, button.list-group-item {
  color: #555;
}

a.list-group-item .list-group-item-heading, button.list-group-item .list-group-item-heading {
  color: #333;
}

a.list-group-item {
  &:hover, &:focus {
    text-decoration: none;
    color: #555;
    background-color: #f5f5f5;
  }
}

button.list-group-item {
  &:hover, &:focus {
    text-decoration: none;
    color: #555;
    background-color: #f5f5f5;
  }
  width: 100%;
  text-align: left;
}

.list-group-item.disabled {
  background-color: #eee;
  color: #777;
  cursor: not-allowed;
}

#headerlinks + fieldset {
  legend.disabled {
    background-color: #eee;
    color: #777;
    cursor: not-allowed;
  }
  + fieldset {
    legend.disabled, + fieldset legend.disabled {
      background-color: #eee;
      color: #777;
      cursor: not-allowed;
    }
  }
}

.list-group-item.disabled:hover {
  background-color: #eee;
  color: #777;
  cursor: not-allowed;
}

#headerlinks + fieldset {
  legend.disabled:hover {
    background-color: #eee;
    color: #777;
    cursor: not-allowed;
  }
  + fieldset {
    legend.disabled:hover, + fieldset legend.disabled:hover {
      background-color: #eee;
      color: #777;
      cursor: not-allowed;
    }
  }
}

.list-group-item.disabled:focus {
  background-color: #eee;
  color: #777;
  cursor: not-allowed;
}

#headerlinks + fieldset {
  legend.disabled:focus {
    background-color: #eee;
    color: #777;
    cursor: not-allowed;
  }
  + fieldset {
    legend.disabled:focus, + fieldset legend.disabled:focus {
      background-color: #eee;
      color: #777;
      cursor: not-allowed;
    }
  }
}

.list-group-item.disabled .list-group-item-heading {
  color: inherit;
}

#headerlinks + fieldset {
  legend.disabled .list-group-item-heading {
    color: inherit;
  }
  + fieldset {
    legend.disabled .list-group-item-heading, + fieldset legend.disabled .list-group-item-heading {
      color: inherit;
    }
  }
}

.list-group-item.disabled:hover .list-group-item-heading {
  color: inherit;
}

#headerlinks + fieldset {
  legend.disabled:hover .list-group-item-heading {
    color: inherit;
  }
  + fieldset {
    legend.disabled:hover .list-group-item-heading, + fieldset legend.disabled:hover .list-group-item-heading {
      color: inherit;
    }
  }
}

.list-group-item.disabled:focus .list-group-item-heading {
  color: inherit;
}

#headerlinks + fieldset {
  legend.disabled:focus .list-group-item-heading {
    color: inherit;
  }
  + fieldset {
    legend.disabled:focus .list-group-item-heading, + fieldset legend.disabled:focus .list-group-item-heading {
      color: inherit;
    }
  }
}

.list-group-item.disabled .list-group-item-text {
  color: #777;
}

#headerlinks + fieldset {
  legend.disabled .list-group-item-text {
    color: #777;
  }
  + fieldset {
    legend.disabled .list-group-item-text, + fieldset legend.disabled .list-group-item-text {
      color: #777;
    }
  }
}

.list-group-item.disabled:hover .list-group-item-text {
  color: #777;
}

#headerlinks + fieldset {
  legend.disabled:hover .list-group-item-text {
    color: #777;
  }
  + fieldset {
    legend.disabled:hover .list-group-item-text, + fieldset legend.disabled:hover .list-group-item-text {
      color: #777;
    }
  }
}

.list-group-item.disabled:focus .list-group-item-text {
  color: #777;
}

#headerlinks + fieldset {
  legend.disabled:focus .list-group-item-text {
    color: #777;
  }
  + fieldset {
    legend.disabled:focus .list-group-item-text, + fieldset legend.disabled:focus .list-group-item-text {
      color: #777;
    }
  }
}

.list-group-item.active {
  z-index: 2;
  color: #fff;
  background-color: #337ab7;
  border-color: #337ab7;
}

#headerlinks + fieldset {
  legend.active {
    z-index: 2;
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7;
  }
  + fieldset {
    legend.active, + fieldset legend.active {
      z-index: 2;
      color: #fff;
      background-color: #337ab7;
      border-color: #337ab7;
    }
  }
}

.list-group-item.active:hover {
  z-index: 2;
  color: #fff;
  background-color: #337ab7;
  border-color: #337ab7;
}

#headerlinks + fieldset {
  legend.active:hover {
    z-index: 2;
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7;
  }
  + fieldset {
    legend.active:hover, + fieldset legend.active:hover {
      z-index: 2;
      color: #fff;
      background-color: #337ab7;
      border-color: #337ab7;
    }
  }
}

.list-group-item.active:focus {
  z-index: 2;
  color: #fff;
  background-color: #337ab7;
  border-color: #337ab7;
}

#headerlinks + fieldset {
  legend.active:focus {
    z-index: 2;
    color: #fff;
    background-color: #337ab7;
    border-color: #337ab7;
  }
  + fieldset {
    legend.active:focus, + fieldset legend.active:focus {
      z-index: 2;
      color: #fff;
      background-color: #337ab7;
      border-color: #337ab7;
    }
  }
}

.list-group-item.active .list-group-item-heading {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active .list-group-item-heading {
    color: inherit;
  }
  + fieldset {
    legend.active .list-group-item-heading, + fieldset legend.active .list-group-item-heading {
      color: inherit;
    }
  }
}

.list-group-item.active .list-group-item-heading > small {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active .list-group-item-heading > small {
    color: inherit;
  }
  + fieldset {
    legend.active .list-group-item-heading > small, + fieldset legend.active .list-group-item-heading > small {
      color: inherit;
    }
  }
}

.list-group-item.active .list-group-item-heading > .small {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active .list-group-item-heading > .small {
    color: inherit;
  }
  + fieldset {
    legend.active .list-group-item-heading > .small, + fieldset legend.active .list-group-item-heading > .small {
      color: inherit;
    }
  }
}

.list-group-item.active:hover .list-group-item-heading {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active:hover .list-group-item-heading {
    color: inherit;
  }
  + fieldset {
    legend.active:hover .list-group-item-heading, + fieldset legend.active:hover .list-group-item-heading {
      color: inherit;
    }
  }
}

.list-group-item.active:hover .list-group-item-heading > small {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active:hover .list-group-item-heading > small {
    color: inherit;
  }
  + fieldset {
    legend.active:hover .list-group-item-heading > small, + fieldset legend.active:hover .list-group-item-heading > small {
      color: inherit;
    }
  }
}

.list-group-item.active:hover .list-group-item-heading > .small {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active:hover .list-group-item-heading > .small {
    color: inherit;
  }
  + fieldset {
    legend.active:hover .list-group-item-heading > .small, + fieldset legend.active:hover .list-group-item-heading > .small {
      color: inherit;
    }
  }
}

.list-group-item.active:focus .list-group-item-heading {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active:focus .list-group-item-heading {
    color: inherit;
  }
  + fieldset {
    legend.active:focus .list-group-item-heading, + fieldset legend.active:focus .list-group-item-heading {
      color: inherit;
    }
  }
}

.list-group-item.active:focus .list-group-item-heading > small {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active:focus .list-group-item-heading > small {
    color: inherit;
  }
  + fieldset {
    legend.active:focus .list-group-item-heading > small, + fieldset legend.active:focus .list-group-item-heading > small {
      color: inherit;
    }
  }
}

.list-group-item.active:focus .list-group-item-heading > .small {
  color: inherit;
}

#headerlinks + fieldset {
  legend.active:focus .list-group-item-heading > .small {
    color: inherit;
  }
  + fieldset {
    legend.active:focus .list-group-item-heading > .small, + fieldset legend.active:focus .list-group-item-heading > .small {
      color: inherit;
    }
  }
}

.list-group-item.active .list-group-item-text {
  color: #c7ddef;
}

#headerlinks + fieldset {
  legend.active .list-group-item-text {
    color: #c7ddef;
  }
  + fieldset {
    legend.active .list-group-item-text, + fieldset legend.active .list-group-item-text {
      color: #c7ddef;
    }
  }
}

.list-group-item.active:hover .list-group-item-text {
  color: #c7ddef;
}

#headerlinks + fieldset {
  legend.active:hover .list-group-item-text {
    color: #c7ddef;
  }
  + fieldset {
    legend.active:hover .list-group-item-text, + fieldset legend.active:hover .list-group-item-text {
      color: #c7ddef;
    }
  }
}

.list-group-item.active:focus .list-group-item-text {
  color: #c7ddef;
}

#headerlinks + fieldset {
  legend.active:focus .list-group-item-text {
    color: #c7ddef;
  }
  + fieldset {
    legend.active:focus .list-group-item-text, + fieldset legend.active:focus .list-group-item-text {
      color: #c7ddef;
    }
  }
}

.list-group-item-success {
  color: #3c763d;
  background-color: #dff0d8;
}

a.list-group-item-success, button.list-group-item-success {
  color: #3c763d;
}

a.list-group-item-success .list-group-item-heading, button.list-group-item-success .list-group-item-heading {
  color: inherit;
}

a.list-group-item-success {
  &:hover, &:focus {
    color: #3c763d;
    background-color: #d0e9c6;
  }
}

button.list-group-item-success {
  &:hover, &:focus {
    color: #3c763d;
    background-color: #d0e9c6;
  }
}

a.list-group-item-success.active {
  color: #fff;
  background-color: #3c763d;
  border-color: #3c763d;
  &:hover, &:focus {
    color: #fff;
    background-color: #3c763d;
    border-color: #3c763d;
  }
}

button.list-group-item-success.active {
  color: #fff;
  background-color: #3c763d;
  border-color: #3c763d;
  &:hover, &:focus {
    color: #fff;
    background-color: #3c763d;
    border-color: #3c763d;
  }
}

.list-group-item-info {
  color: #31708f;
  background-color: #d9edf7;
}

a.list-group-item-info, button.list-group-item-info {
  color: #31708f;
}

a.list-group-item-info .list-group-item-heading, button.list-group-item-info .list-group-item-heading {
  color: inherit;
}

a.list-group-item-info {
  &:hover, &:focus {
    color: #31708f;
    background-color: #c4e3f3;
  }
}

button.list-group-item-info {
  &:hover, &:focus {
    color: #31708f;
    background-color: #c4e3f3;
  }
}

a.list-group-item-info.active {
  color: #fff;
  background-color: #31708f;
  border-color: #31708f;
  &:hover, &:focus {
    color: #fff;
    background-color: #31708f;
    border-color: #31708f;
  }
}

button.list-group-item-info.active {
  color: #fff;
  background-color: #31708f;
  border-color: #31708f;
  &:hover, &:focus {
    color: #fff;
    background-color: #31708f;
    border-color: #31708f;
  }
}

.list-group-item-warning {
  color: #8a6d3b;
  background-color: #fcf8e3;
}

a.list-group-item-warning, button.list-group-item-warning {
  color: #8a6d3b;
}

a.list-group-item-warning .list-group-item-heading, button.list-group-item-warning .list-group-item-heading {
  color: inherit;
}

a.list-group-item-warning {
  &:hover, &:focus {
    color: #8a6d3b;
    background-color: #faf2cc;
  }
}

button.list-group-item-warning {
  &:hover, &:focus {
    color: #8a6d3b;
    background-color: #faf2cc;
  }
}

a.list-group-item-warning.active {
  color: #fff;
  background-color: #8a6d3b;
  border-color: #8a6d3b;
  &:hover, &:focus {
    color: #fff;
    background-color: #8a6d3b;
    border-color: #8a6d3b;
  }
}

button.list-group-item-warning.active {
  color: #fff;
  background-color: #8a6d3b;
  border-color: #8a6d3b;
  &:hover, &:focus {
    color: #fff;
    background-color: #8a6d3b;
    border-color: #8a6d3b;
  }
}

.list-group-item-danger {
  color: #a94442;
  background-color: #f2dede;
}

a.list-group-item-danger, button.list-group-item-danger {
  color: #a94442;
}

a.list-group-item-danger .list-group-item-heading, button.list-group-item-danger .list-group-item-heading {
  color: inherit;
}

a.list-group-item-danger {
  &:hover, &:focus {
    color: #a94442;
    background-color: #ebcccc;
  }
}

button.list-group-item-danger {
  &:hover, &:focus {
    color: #a94442;
    background-color: #ebcccc;
  }
}

a.list-group-item-danger.active {
  color: #fff;
  background-color: #a94442;
  border-color: #a94442;
  &:hover, &:focus {
    color: #fff;
    background-color: #a94442;
    border-color: #a94442;
  }
}

button.list-group-item-danger.active {
  color: #fff;
  background-color: #a94442;
  border-color: #a94442;
  &:hover, &:focus {
    color: #fff;
    background-color: #a94442;
    border-color: #a94442;
  }
}

.list-group-item-heading {
  margin-top: 0;
  margin-bottom: 5px;
}

.list-group-item-text {
  margin-bottom: 0;
  line-height: 1.3;
}

.panel, #loginBox {
  margin-bottom: 20px;
  background-color: #fff;
  border: 1px solid transparent;
  border-radius: 4px;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
}

.panel-body {
  padding: 15px;
  &:before {
    content: " ";
    display: table;
  }
  &:after {
    content: " ";
    display: table;
    clear: both;
  }
}

.panel-heading {
  padding: 10px 15px;
  border-bottom: 1px solid transparent;
  border-top-right-radius: 3px;
  border-top-left-radius: 3px;
  > .dropdown .dropdown-toggle {
    color: inherit;
  }
}

.panel-title {
  margin-top: 0;
  margin-bottom: 0;
  font-size: 16px;
  color: inherit;
  > {
    a, small, .small, small > a, .small > a {
      color: inherit;
    }
  }
}

.panel-footer {
  padding: 10px 15px;
  background-color: #f5f5f5;
  border-top: 1px solid #ddd;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}

.panel > .list-group, #loginBox > .list-group, .panel > #headerlinks + fieldset, #loginBox > #headerlinks + fieldset, .panel > .panel-collapse > .list-group, #loginBox > .panel-collapse > .list-group, .panel > .panel-collapse > #headerlinks + fieldset, #loginBox > .panel-collapse > #headerlinks + fieldset {
  margin-bottom: 0;
}

.panel > .list-group .list-group-item, #loginBox > .list-group .list-group-item, .panel > #headerlinks + fieldset .list-group-item, #loginBox > #headerlinks + fieldset .list-group-item {
  border-width: 1px 0;
  border-radius: 0;
}

#headerlinks + fieldset {
  .panel > .list-group legend, #loginBox > .list-group legend {
    border-width: 1px 0;
    border-radius: 0;
  }
}

.panel > #headerlinks + fieldset legend, #loginBox > #headerlinks + fieldset legend, .panel > .list-group #headerlinks + fieldset + fieldset legend, #headerlinks + fieldset + fieldset .panel > .list-group legend, #loginBox > .list-group #headerlinks + fieldset + fieldset legend, #headerlinks + fieldset + fieldset #loginBox > .list-group legend, .panel > .list-group #headerlinks + fieldset + fieldset + fieldset legend, #headerlinks + fieldset + fieldset + fieldset .panel > .list-group legend, #loginBox > .list-group #headerlinks + fieldset + fieldset + fieldset legend, #headerlinks + fieldset + fieldset + fieldset #loginBox > .list-group legend, .panel > .panel-collapse > .list-group .list-group-item, #loginBox > .panel-collapse > .list-group .list-group-item, .panel > .panel-collapse > #headerlinks + fieldset .list-group-item, #loginBox > .panel-collapse > #headerlinks + fieldset .list-group-item {
  border-width: 1px 0;
  border-radius: 0;
}

#headerlinks + fieldset {
  .panel > .panel-collapse > .list-group legend, #loginBox > .panel-collapse > .list-group legend {
    border-width: 1px 0;
    border-radius: 0;
  }
}

.panel > .panel-collapse > #headerlinks + fieldset legend, #loginBox > .panel-collapse > #headerlinks + fieldset legend, .panel > .panel-collapse > .list-group #headerlinks + fieldset + fieldset legend, #headerlinks + fieldset + fieldset .panel > .panel-collapse > .list-group legend, #loginBox > .panel-collapse > .list-group #headerlinks + fieldset + fieldset legend, #headerlinks + fieldset + fieldset #loginBox > .panel-collapse > .list-group legend, .panel > .panel-collapse > .list-group #headerlinks + fieldset + fieldset + fieldset legend, #headerlinks + fieldset + fieldset + fieldset .panel > .panel-collapse > .list-group legend, #loginBox > .panel-collapse > .list-group #headerlinks + fieldset + fieldset + fieldset legend, #headerlinks + fieldset + fieldset + fieldset #loginBox > .panel-collapse > .list-group legend {
  border-width: 1px 0;
  border-radius: 0;
}

.panel > .list-group:first-child .list-group-item:first-child, #loginBox > .list-group:first-child .list-group-item:first-child, .panel > #headerlinks + fieldset:first-child .list-group-item:first-child, #loginBox > #headerlinks + fieldset:first-child .list-group-item:first-child, .panel > .list-group:first-child #headerlinks + fieldset legend:first-child, #headerlinks + fieldset .panel > .list-group:first-child legend:first-child, #loginBox > .list-group:first-child #headerlinks + fieldset legend:first-child, #headerlinks + fieldset #loginBox > .list-group:first-child legend:first-child, .panel > #headerlinks + fieldset:first-child legend:first-child, #loginBox > #headerlinks + fieldset:first-child legend:first-child, .panel > .list-group:first-child #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset .panel > .list-group:first-child legend:first-child, #loginBox > .list-group:first-child #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset #loginBox > .list-group:first-child legend:first-child, .panel > .list-group:first-child #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset .panel > .list-group:first-child legend:first-child, #loginBox > .list-group:first-child #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset #loginBox > .list-group:first-child legend:first-child, .panel > .panel-collapse > .list-group:first-child .list-group-item:first-child, #loginBox > .panel-collapse > .list-group:first-child .list-group-item:first-child, .panel > .panel-collapse > #headerlinks + fieldset:first-child .list-group-item:first-child, #loginBox > .panel-collapse > #headerlinks + fieldset:first-child .list-group-item:first-child, .panel > .panel-collapse > .list-group:first-child #headerlinks + fieldset legend:first-child, #headerlinks + fieldset .panel > .panel-collapse > .list-group:first-child legend:first-child, #loginBox > .panel-collapse > .list-group:first-child #headerlinks + fieldset legend:first-child, #headerlinks + fieldset #loginBox > .panel-collapse > .list-group:first-child legend:first-child, .panel > .panel-collapse > #headerlinks + fieldset:first-child legend:first-child, #loginBox > .panel-collapse > #headerlinks + fieldset:first-child legend:first-child, .panel > .panel-collapse > .list-group:first-child #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset .panel > .panel-collapse > .list-group:first-child legend:first-child, #loginBox > .panel-collapse > .list-group:first-child #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset #loginBox > .panel-collapse > .list-group:first-child legend:first-child, .panel > .panel-collapse > .list-group:first-child #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset .panel > .panel-collapse > .list-group:first-child legend:first-child, #loginBox > .panel-collapse > .list-group:first-child #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset #loginBox > .panel-collapse > .list-group:first-child legend:first-child {
  border-top: 0;
  border-top-right-radius: 3px;
  border-top-left-radius: 3px;
}

.panel > .list-group:last-child .list-group-item:last-child, #loginBox > .list-group:last-child .list-group-item:last-child, .panel > #headerlinks + fieldset:last-child .list-group-item:last-child, #loginBox > #headerlinks + fieldset:last-child .list-group-item:last-child, .panel > .list-group:last-child #headerlinks + fieldset legend:last-child, #headerlinks + fieldset .panel > .list-group:last-child legend:last-child, #loginBox > .list-group:last-child #headerlinks + fieldset legend:last-child, #headerlinks + fieldset #loginBox > .list-group:last-child legend:last-child, .panel > #headerlinks + fieldset:last-child legend:last-child, #loginBox > #headerlinks + fieldset:last-child legend:last-child, .panel > .list-group:last-child #headerlinks + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset .panel > .list-group:last-child legend:last-child, #loginBox > .list-group:last-child #headerlinks + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset #loginBox > .list-group:last-child legend:last-child, .panel > .list-group:last-child #headerlinks + fieldset + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset + fieldset .panel > .list-group:last-child legend:last-child, #loginBox > .list-group:last-child #headerlinks + fieldset + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset + fieldset #loginBox > .list-group:last-child legend:last-child, .panel > .panel-collapse > .list-group:last-child .list-group-item:last-child, #loginBox > .panel-collapse > .list-group:last-child .list-group-item:last-child, .panel > .panel-collapse > #headerlinks + fieldset:last-child .list-group-item:last-child, #loginBox > .panel-collapse > #headerlinks + fieldset:last-child .list-group-item:last-child, .panel > .panel-collapse > .list-group:last-child #headerlinks + fieldset legend:last-child, #headerlinks + fieldset .panel > .panel-collapse > .list-group:last-child legend:last-child, #loginBox > .panel-collapse > .list-group:last-child #headerlinks + fieldset legend:last-child, #headerlinks + fieldset #loginBox > .panel-collapse > .list-group:last-child legend:last-child, .panel > .panel-collapse > #headerlinks + fieldset:last-child legend:last-child, #loginBox > .panel-collapse > #headerlinks + fieldset:last-child legend:last-child, .panel > .panel-collapse > .list-group:last-child #headerlinks + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset .panel > .panel-collapse > .list-group:last-child legend:last-child, #loginBox > .panel-collapse > .list-group:last-child #headerlinks + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset #loginBox > .panel-collapse > .list-group:last-child legend:last-child, .panel > .panel-collapse > .list-group:last-child #headerlinks + fieldset + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset + fieldset .panel > .panel-collapse > .list-group:last-child legend:last-child, #loginBox > .panel-collapse > .list-group:last-child #headerlinks + fieldset + fieldset + fieldset legend:last-child, #headerlinks + fieldset + fieldset + fieldset #loginBox > .panel-collapse > .list-group:last-child legend:last-child {
  border-bottom: 0;
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}

.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child, #loginBox > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child, .panel > .panel-heading + .panel-collapse > #headerlinks + fieldset .list-group-item:first-child, #loginBox > .panel-heading + .panel-collapse > #headerlinks + fieldset .list-group-item:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

#headerlinks + fieldset {
  .panel > .panel-heading + .panel-collapse > .list-group legend:first-child, #loginBox > .panel-heading + .panel-collapse > .list-group legend:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
  }
}

.panel > .panel-heading + .panel-collapse > #headerlinks + fieldset legend:first-child, #loginBox > .panel-heading + .panel-collapse > #headerlinks + fieldset legend:first-child, .panel > .panel-heading + .panel-collapse > .list-group #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset .panel > .panel-heading + .panel-collapse > .list-group legend:first-child, #loginBox > .panel-heading + .panel-collapse > .list-group #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset #loginBox > .panel-heading + .panel-collapse > .list-group legend:first-child, .panel > .panel-heading + .panel-collapse > .list-group #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset .panel > .panel-heading + .panel-collapse > .list-group legend:first-child, #loginBox > .panel-heading + .panel-collapse > .list-group #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset #loginBox > .panel-heading + .panel-collapse > .list-group legend:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

.panel-heading + .list-group .list-group-item:first-child, #headerlinks.panel-heading + fieldset .list-group-item:first-child, .panel-heading + .list-group #headerlinks + fieldset legend:first-child {
  border-top-width: 0;
}

#headerlinks {
  + fieldset .panel-heading + .list-group legend:first-child, &.panel-heading + fieldset legend:first-child {
    border-top-width: 0;
  }
}

.panel-heading + .list-group #headerlinks + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset .panel-heading + .list-group legend:first-child, .panel-heading + .list-group #headerlinks + fieldset + fieldset + fieldset legend:first-child, #headerlinks + fieldset + fieldset + fieldset .panel-heading + .list-group legend:first-child, .list-group + .panel-footer, #headerlinks + fieldset + .panel-footer {
  border-top-width: 0;
}

.panel > .table, #loginBox > .table, .panel > table.viewTable, #loginBox > table.viewTable, .panel > .table-responsive > .table, #loginBox > .table-responsive > .table, .panel > .table-responsive > table.viewTable, #loginBox > .table-responsive > table.viewTable, .panel > .panel-collapse > .table, #loginBox > .panel-collapse > .table, .panel > .panel-collapse > table.viewTable, #loginBox > .panel-collapse > table.viewTable {
  margin-bottom: 0;
}

.panel > .table caption, #loginBox > .table caption, .panel > table.viewTable caption, #loginBox > table.viewTable caption, .panel > .table-responsive > .table caption, #loginBox > .table-responsive > .table caption, .panel > .table-responsive > table.viewTable caption, #loginBox > .table-responsive > table.viewTable caption, .panel > .panel-collapse > .table caption, #loginBox > .panel-collapse > .table caption, .panel > .panel-collapse > table.viewTable caption, #loginBox > .panel-collapse > table.viewTable caption {
  padding-left: 15px;
  padding-right: 15px;
}

.panel > .table:first-child, #loginBox > .table:first-child, .panel > table.viewTable:first-child, #loginBox > table.viewTable:first-child, .panel > .table-responsive:first-child > .table:first-child, #loginBox > .table-responsive:first-child > .table:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child {
  border-top-right-radius: 3px;
  border-top-left-radius: 3px;
}

.panel > .table:first-child > thead:first-child > tr:first-child, #loginBox > .table:first-child > thead:first-child > tr:first-child, .panel > table.viewTable:first-child > thead:first-child > tr:first-child, #loginBox > table.viewTable:first-child > thead:first-child > tr:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child, #loginBox > .table:first-child > tbody:first-child > tr:first-child, .panel > table.viewTable:first-child > tbody:first-child > tr:first-child, #loginBox > table.viewTable:first-child > tbody:first-child > tr:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child, #loginBox > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child, #loginBox > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child {
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
}

.panel > .table:first-child > thead:first-child > tr:first-child td:first-child, #loginBox > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel > table.viewTable:first-child > thead:first-child > tr:first-child td:first-child, #loginBox > table.viewTable:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table:first-child > thead:first-child > tr:first-child th:first-child, #loginBox > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel > table.viewTable:first-child > thead:first-child > tr:first-child th:first-child, #loginBox > table.viewTable:first-child > thead:first-child > tr:first-child th:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child td:first-child, #loginBox > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel > table.viewTable:first-child > tbody:first-child > tr:first-child td:first-child, #loginBox > table.viewTable:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table:first-child > tbody:first-child > tr:first-child th:first-child, #loginBox > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel > table.viewTable:first-child > tbody:first-child > tr:first-child th:first-child, #loginBox > table.viewTable:first-child > tbody:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child, #loginBox > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child td:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child, #loginBox > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child th:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child, #loginBox > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child td:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child td:first-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child, #loginBox > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child, .panel > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child th:first-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child th:first-child {
  border-top-left-radius: 3px;
}

.panel > .table:first-child > thead:first-child > tr:first-child td:last-child, #loginBox > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel > table.viewTable:first-child > thead:first-child > tr:first-child td:last-child, #loginBox > table.viewTable:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table:first-child > thead:first-child > tr:first-child th:last-child, #loginBox > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel > table.viewTable:first-child > thead:first-child > tr:first-child th:last-child, #loginBox > table.viewTable:first-child > thead:first-child > tr:first-child th:last-child, .panel > .table:first-child > tbody:first-child > tr:first-child td:last-child, #loginBox > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel > table.viewTable:first-child > tbody:first-child > tr:first-child td:last-child, #loginBox > table.viewTable:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table:first-child > tbody:first-child > tr:first-child th:last-child, #loginBox > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel > table.viewTable:first-child > tbody:first-child > tr:first-child th:last-child, #loginBox > table.viewTable:first-child > tbody:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child, #loginBox > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child td:last-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child, #loginBox > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child th:last-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > thead:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child, #loginBox > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child td:last-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child td:last-child, .panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child, #loginBox > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child, .panel > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child th:last-child, #loginBox > .table-responsive:first-child > table.viewTable:first-child > tbody:first-child > tr:first-child th:last-child {
  border-top-right-radius: 3px;
}

.panel > .table:last-child, #loginBox > .table:last-child, .panel > table.viewTable:last-child, #loginBox > table.viewTable:last-child, .panel > .table-responsive:last-child > .table:last-child, #loginBox > .table-responsive:last-child > .table:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child {
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}

.panel > .table:last-child > tbody:last-child > tr:last-child, #loginBox > .table:last-child > tbody:last-child > tr:last-child, .panel > table.viewTable:last-child > tbody:last-child > tr:last-child, #loginBox > table.viewTable:last-child > tbody:last-child > tr:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child, #loginBox > .table:last-child > tfoot:last-child > tr:last-child, .panel > table.viewTable:last-child > tfoot:last-child > tr:last-child, #loginBox > table.viewTable:last-child > tfoot:last-child > tr:last-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child, #loginBox > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child, #loginBox > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child {
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
}

.panel > .table:last-child > tbody:last-child > tr:last-child td:first-child, #loginBox > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel > table.viewTable:last-child > tbody:last-child > tr:last-child td:first-child, #loginBox > table.viewTable:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table:last-child > tbody:last-child > tr:last-child th:first-child, #loginBox > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel > table.viewTable:last-child > tbody:last-child > tr:last-child th:first-child, #loginBox > table.viewTable:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child, #loginBox > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > table.viewTable:last-child > tfoot:last-child > tr:last-child td:first-child, #loginBox > table.viewTable:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child, #loginBox > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .panel > table.viewTable:last-child > tfoot:last-child > tr:last-child th:first-child, #loginBox > table.viewTable:last-child > tfoot:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child, #loginBox > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child td:first-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child, #loginBox > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child th:first-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child, #loginBox > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child td:first-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child td:first-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child, #loginBox > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child th:first-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child th:first-child {
  border-bottom-left-radius: 3px;
}

.panel > .table:last-child > tbody:last-child > tr:last-child td:last-child, #loginBox > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel > table.viewTable:last-child > tbody:last-child > tr:last-child td:last-child, #loginBox > table.viewTable:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table:last-child > tbody:last-child > tr:last-child th:last-child, #loginBox > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel > table.viewTable:last-child > tbody:last-child > tr:last-child th:last-child, #loginBox > table.viewTable:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child, #loginBox > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > table.viewTable:last-child > tfoot:last-child > tr:last-child td:last-child, #loginBox > table.viewTable:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child, #loginBox > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .panel > table.viewTable:last-child > tfoot:last-child > tr:last-child th:last-child, #loginBox > table.viewTable:last-child > tfoot:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child, #loginBox > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child td:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child, #loginBox > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child th:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tbody:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child, #loginBox > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child td:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child td:last-child, .panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child, #loginBox > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child, .panel > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child th:last-child, #loginBox > .table-responsive:last-child > table.viewTable:last-child > tfoot:last-child > tr:last-child th:last-child {
  border-bottom-right-radius: 3px;
}

.panel > .panel-body + .table, #loginBox > .panel-body + .table, .panel > .panel-body + table.viewTable, #loginBox > .panel-body + table.viewTable, .panel > .panel-body + .table-responsive, #loginBox > .panel-body + .table-responsive, .panel > .table + .panel-body, #loginBox > .table + .panel-body, .panel > table.viewTable + .panel-body, #loginBox > table.viewTable + .panel-body, .panel > .table-responsive + .panel-body, #loginBox > .table-responsive + .panel-body {
  border-top: 1px solid #ddd;
}

.panel > .table > tbody:first-child > tr:first-child th, #loginBox > .table > tbody:first-child > tr:first-child th, .panel > table.viewTable > tbody:first-child > tr:first-child th, #loginBox > table.viewTable > tbody:first-child > tr:first-child th, .panel > .table > tbody:first-child > tr:first-child td, #loginBox > .table > tbody:first-child > tr:first-child td, .panel > table.viewTable > tbody:first-child > tr:first-child td, #loginBox > table.viewTable > tbody:first-child > tr:first-child td {
  border-top: 0;
}

.panel > .table-bordered, #loginBox > .table-bordered, .panel > table.viewTable, #loginBox > table.viewTable, .panel > .table-responsive > .table-bordered, #loginBox > .table-responsive > .table-bordered, .panel > .table-responsive > table.viewTable, #loginBox > .table-responsive > table.viewTable {
  border: 0;
}

.panel > .table-bordered > thead > tr > th:first-child, #loginBox > .table-bordered > thead > tr > th:first-child, .panel > table.viewTable > thead > tr > th:first-child, #loginBox > table.viewTable > thead > tr > th:first-child, .panel > .table-bordered > thead > tr > td:first-child, #loginBox > .table-bordered > thead > tr > td:first-child, .panel > table.viewTable > thead > tr > td:first-child, #loginBox > table.viewTable > thead > tr > td:first-child, .panel > .table-bordered > tbody > tr > th:first-child, #loginBox > .table-bordered > tbody > tr > th:first-child, .panel > table.viewTable > tbody > tr > th:first-child, #loginBox > table.viewTable > tbody > tr > th:first-child, .panel > .table-bordered > tbody > tr > td:first-child, #loginBox > .table-bordered > tbody > tr > td:first-child, .panel > table.viewTable > tbody > tr > td:first-child, #loginBox > table.viewTable > tbody > tr > td:first-child, .panel > .table-bordered > tfoot > tr > th:first-child, #loginBox > .table-bordered > tfoot > tr > th:first-child, .panel > table.viewTable > tfoot > tr > th:first-child, #loginBox > table.viewTable > tfoot > tr > th:first-child, .panel > .table-bordered > tfoot > tr > td:first-child, #loginBox > .table-bordered > tfoot > tr > td:first-child, .panel > table.viewTable > tfoot > tr > td:first-child, #loginBox > table.viewTable > tfoot > tr > td:first-child, .panel > .table-responsive > .table-bordered > thead > tr > th:first-child, #loginBox > .table-responsive > .table-bordered > thead > tr > th:first-child, .panel > .table-responsive > table.viewTable > thead > tr > th:first-child, #loginBox > .table-responsive > table.viewTable > thead > tr > th:first-child, .panel > .table-responsive > .table-bordered > thead > tr > td:first-child, #loginBox > .table-responsive > .table-bordered > thead > tr > td:first-child, .panel > .table-responsive > table.viewTable > thead > tr > td:first-child, #loginBox > .table-responsive > table.viewTable > thead > tr > td:first-child, .panel > .table-responsive > .table-bordered > tbody > tr > th:first-child, #loginBox > .table-responsive > .table-bordered > tbody > tr > th:first-child, .panel > .table-responsive > table.viewTable > tbody > tr > th:first-child, #loginBox > .table-responsive > table.viewTable > tbody > tr > th:first-child, .panel > .table-responsive > .table-bordered > tbody > tr > td:first-child, #loginBox > .table-responsive > .table-bordered > tbody > tr > td:first-child, .panel > .table-responsive > table.viewTable > tbody > tr > td:first-child, #loginBox > .table-responsive > table.viewTable > tbody > tr > td:first-child, .panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child, #loginBox > .table-responsive > .table-bordered > tfoot > tr > th:first-child, .panel > .table-responsive > table.viewTable > tfoot > tr > th:first-child, #loginBox > .table-responsive > table.viewTable > tfoot > tr > th:first-child, .panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child, #loginBox > .table-responsive > .table-bordered > tfoot > tr > td:first-child, .panel > .table-responsive > table.viewTable > tfoot > tr > td:first-child, #loginBox > .table-responsive > table.viewTable > tfoot > tr > td:first-child {
  border-left: 0;
}

.panel > .table-bordered > thead > tr > th:last-child, #loginBox > .table-bordered > thead > tr > th:last-child, .panel > table.viewTable > thead > tr > th:last-child, #loginBox > table.viewTable > thead > tr > th:last-child, .panel > .table-bordered > thead > tr > td:last-child, #loginBox > .table-bordered > thead > tr > td:last-child, .panel > table.viewTable > thead > tr > td:last-child, #loginBox > table.viewTable > thead > tr > td:last-child, .panel > .table-bordered > tbody > tr > th:last-child, #loginBox > .table-bordered > tbody > tr > th:last-child, .panel > table.viewTable > tbody > tr > th:last-child, #loginBox > table.viewTable > tbody > tr > th:last-child, .panel > .table-bordered > tbody > tr > td:last-child, #loginBox > .table-bordered > tbody > tr > td:last-child, .panel > table.viewTable > tbody > tr > td:last-child, #loginBox > table.viewTable > tbody > tr > td:last-child, .panel > .table-bordered > tfoot > tr > th:last-child, #loginBox > .table-bordered > tfoot > tr > th:last-child, .panel > table.viewTable > tfoot > tr > th:last-child, #loginBox > table.viewTable > tfoot > tr > th:last-child, .panel > .table-bordered > tfoot > tr > td:last-child, #loginBox > .table-bordered > tfoot > tr > td:last-child, .panel > table.viewTable > tfoot > tr > td:last-child, #loginBox > table.viewTable > tfoot > tr > td:last-child, .panel > .table-responsive > .table-bordered > thead > tr > th:last-child, #loginBox > .table-responsive > .table-bordered > thead > tr > th:last-child, .panel > .table-responsive > table.viewTable > thead > tr > th:last-child, #loginBox > .table-responsive > table.viewTable > thead > tr > th:last-child, .panel > .table-responsive > .table-bordered > thead > tr > td:last-child, #loginBox > .table-responsive > .table-bordered > thead > tr > td:last-child, .panel > .table-responsive > table.viewTable > thead > tr > td:last-child, #loginBox > .table-responsive > table.viewTable > thead > tr > td:last-child, .panel > .table-responsive > .table-bordered > tbody > tr > th:last-child, #loginBox > .table-responsive > .table-bordered > tbody > tr > th:last-child, .panel > .table-responsive > table.viewTable > tbody > tr > th:last-child, #loginBox > .table-responsive > table.viewTable > tbody > tr > th:last-child, .panel > .table-responsive > .table-bordered > tbody > tr > td:last-child, #loginBox > .table-responsive > .table-bordered > tbody > tr > td:last-child, .panel > .table-responsive > table.viewTable > tbody > tr > td:last-child, #loginBox > .table-responsive > table.viewTable > tbody > tr > td:last-child, .panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child, #loginBox > .table-responsive > .table-bordered > tfoot > tr > th:last-child, .panel > .table-responsive > table.viewTable > tfoot > tr > th:last-child, #loginBox > .table-responsive > table.viewTable > tfoot > tr > th:last-child, .panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child, #loginBox > .table-responsive > .table-bordered > tfoot > tr > td:last-child, .panel > .table-responsive > table.viewTable > tfoot > tr > td:last-child, #loginBox > .table-responsive > table.viewTable > tfoot > tr > td:last-child {
  border-right: 0;
}

.panel > .table-bordered > thead > tr:first-child > td, #loginBox > .table-bordered > thead > tr:first-child > td, .panel > table.viewTable > thead > tr:first-child > td, #loginBox > table.viewTable > thead > tr:first-child > td, .panel > .table-bordered > thead > tr:first-child > th, #loginBox > .table-bordered > thead > tr:first-child > th, .panel > table.viewTable > thead > tr:first-child > th, #loginBox > table.viewTable > thead > tr:first-child > th, .panel > .table-bordered > tbody > tr:first-child > td, #loginBox > .table-bordered > tbody > tr:first-child > td, .panel > table.viewTable > tbody > tr:first-child > td, #loginBox > table.viewTable > tbody > tr:first-child > td, .panel > .table-bordered > tbody > tr:first-child > th, #loginBox > .table-bordered > tbody > tr:first-child > th, .panel > table.viewTable > tbody > tr:first-child > th, #loginBox > table.viewTable > tbody > tr:first-child > th, .panel > .table-responsive > .table-bordered > thead > tr:first-child > td, #loginBox > .table-responsive > .table-bordered > thead > tr:first-child > td, .panel > .table-responsive > table.viewTable > thead > tr:first-child > td, #loginBox > .table-responsive > table.viewTable > thead > tr:first-child > td, .panel > .table-responsive > .table-bordered > thead > tr:first-child > th, #loginBox > .table-responsive > .table-bordered > thead > tr:first-child > th, .panel > .table-responsive > table.viewTable > thead > tr:first-child > th, #loginBox > .table-responsive > table.viewTable > thead > tr:first-child > th, .panel > .table-responsive > .table-bordered > tbody > tr:first-child > td, #loginBox > .table-responsive > .table-bordered > tbody > tr:first-child > td, .panel > .table-responsive > table.viewTable > tbody > tr:first-child > td, #loginBox > .table-responsive > table.viewTable > tbody > tr:first-child > td, .panel > .table-responsive > .table-bordered > tbody > tr:first-child > th, #loginBox > .table-responsive > .table-bordered > tbody > tr:first-child > th, .panel > .table-responsive > table.viewTable > tbody > tr:first-child > th, #loginBox > .table-responsive > table.viewTable > tbody > tr:first-child > th, .panel > .table-bordered > tbody > tr:last-child > td, #loginBox > .table-bordered > tbody > tr:last-child > td, .panel > table.viewTable > tbody > tr:last-child > td, #loginBox > table.viewTable > tbody > tr:last-child > td, .panel > .table-bordered > tbody > tr:last-child > th, #loginBox > .table-bordered > tbody > tr:last-child > th, .panel > table.viewTable > tbody > tr:last-child > th, #loginBox > table.viewTable > tbody > tr:last-child > th, .panel > .table-bordered > tfoot > tr:last-child > td, #loginBox > .table-bordered > tfoot > tr:last-child > td, .panel > table.viewTable > tfoot > tr:last-child > td, #loginBox > table.viewTable > tfoot > tr:last-child > td, .panel > .table-bordered > tfoot > tr:last-child > th, #loginBox > .table-bordered > tfoot > tr:last-child > th, .panel > table.viewTable > tfoot > tr:last-child > th, #loginBox > table.viewTable > tfoot > tr:last-child > th, .panel > .table-responsive > .table-bordered > tbody > tr:last-child > td, #loginBox > .table-responsive > .table-bordered > tbody > tr:last-child > td, .panel > .table-responsive > table.viewTable > tbody > tr:last-child > td, #loginBox > .table-responsive > table.viewTable > tbody > tr:last-child > td, .panel > .table-responsive > .table-bordered > tbody > tr:last-child > th, #loginBox > .table-responsive > .table-bordered > tbody > tr:last-child > th, .panel > .table-responsive > table.viewTable > tbody > tr:last-child > th, #loginBox > .table-responsive > table.viewTable > tbody > tr:last-child > th, .panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td, #loginBox > .table-responsive > .table-bordered > tfoot > tr:last-child > td, .panel > .table-responsive > table.viewTable > tfoot > tr:last-child > td, #loginBox > .table-responsive > table.viewTable > tfoot > tr:last-child > td, .panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th, #loginBox > .table-responsive > .table-bordered > tfoot > tr:last-child > th, .panel > .table-responsive > table.viewTable > tfoot > tr:last-child > th, #loginBox > .table-responsive > table.viewTable > tfoot > tr:last-child > th {
  border-bottom: 0;
}

.panel > .table-responsive, #loginBox > .table-responsive {
  border: 0;
  margin-bottom: 0;
}

.panel-group {
  margin-bottom: 20px;
  .panel, #loginBox {
    margin-bottom: 0;
    border-radius: 4px;
  }
  .panel + .panel, #loginBox + .panel, .panel + #loginBox, #loginBox + #loginBox {
    margin-top: 5px;
  }
  .panel-heading {
    border-bottom: 0;
    + .panel-collapse > {
      .panel-body, .list-group, #headerlinks + fieldset {
        border-top: 1px solid #ddd;
      }
    }
  }
  .panel-footer {
    border-top: 0;
    + .panel-collapse .panel-body {
      border-bottom: 1px solid #ddd;
    }
  }
}

.panel-default, #loginBox {
  border-color: #ddd;
}

.panel-default > .panel-heading, #loginBox > .panel-heading {
  color: #333;
  background-color: #f5f5f5;
  border-color: #ddd;
}

.panel-default > .panel-heading + .panel-collapse > .panel-body, #loginBox > .panel-heading + .panel-collapse > .panel-body {
  border-top-color: #ddd;
}

.panel-default > .panel-heading .badge, #loginBox > .panel-heading .badge {
  color: #f5f5f5;
  background-color: #333;
}

.panel-default > .panel-footer + .panel-collapse > .panel-body, #loginBox > .panel-footer + .panel-collapse > .panel-body {
  border-bottom-color: #ddd;
}

.panel-primary {
  border-color: #337ab7;
  > {
    .panel-heading {
      color: #fff;
      background-color: #337ab7;
      border-color: #337ab7;
      + .panel-collapse > .panel-body {
        border-top-color: #337ab7;
      }
      .badge {
        color: #337ab7;
        background-color: #fff;
      }
    }
    .panel-footer + .panel-collapse > .panel-body {
      border-bottom-color: #337ab7;
    }
  }
}

.panel-success {
  border-color: #d6e9c6;
  > {
    .panel-heading {
      color: #3c763d;
      background-color: #dff0d8;
      border-color: #d6e9c6;
      + .panel-collapse > .panel-body {
        border-top-color: #d6e9c6;
      }
      .badge {
        color: #dff0d8;
        background-color: #3c763d;
      }
    }
    .panel-footer + .panel-collapse > .panel-body {
      border-bottom-color: #d6e9c6;
    }
  }
}

.panel-info {
  border-color: #bce8f1;
  > {
    .panel-heading {
      color: #31708f;
      background-color: #d9edf7;
      border-color: #bce8f1;
      + .panel-collapse > .panel-body {
        border-top-color: #bce8f1;
      }
      .badge {
        color: #d9edf7;
        background-color: #31708f;
      }
    }
    .panel-footer + .panel-collapse > .panel-body {
      border-bottom-color: #bce8f1;
    }
  }
}

.panel-warning {
  border-color: #faebcc;
  > {
    .panel-heading {
      color: #8a6d3b;
      background-color: #fcf8e3;
      border-color: #faebcc;
      + .panel-collapse > .panel-body {
        border-top-color: #faebcc;
      }
      .badge {
        color: #fcf8e3;
        background-color: #8a6d3b;
      }
    }
    .panel-footer + .panel-collapse > .panel-body {
      border-bottom-color: #faebcc;
    }
  }
}

.panel-danger {
  border-color: #ebccd1;
  > {
    .panel-heading {
      color: #a94442;
      background-color: #f2dede;
      border-color: #ebccd1;
      + .panel-collapse > .panel-body {
        border-top-color: #ebccd1;
      }
      .badge {
        color: #f2dede;
        background-color: #a94442;
      }
    }
    .panel-footer + .panel-collapse > .panel-body {
      border-bottom-color: #ebccd1;
    }
  }
}

a:hover {
  text-decoration: none !important;
}

#loginBox {
  width: 500px;
  margin: 7em auto;
  padding-bottom: 12px;
  h1 {
    background: #eeeeee;
    text-align: center;
    padding: 5px;
    margin: 0 0 12px;
    #version {
      font-size: 16px;
    }
  }
  div {
    position: relative;
    span.warning {
      display: block;
      position: absolute;
      top: -8px;
      width: 95%;
    }
  }
  form {
    text-align: left;
    font-weight: bold;
    input[type="password"] {
      margin-top: 8px;
    }
  }
}

div.confirm + fieldset form {
  width: 55.55%;
  input[type=submit] {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    z-index: 2;
    padding-bottom: 7px;
  }
}

.left_td[style] {
  padding: 0 !important;
}

#leftNav h1 {
  font-size: 20px;
  background: #ffffff;
  margin-bottom: 0 !important;
  margin-left: 0 !important;
  padding-top: 5px;
  #version {
    font-size: 16px;
  }
}

.left_td {
  background: #e3e3e3;
  height: 100vh;
  max-width: 187px;
}

#headerlinks {
  font-size: 9.8px;
  background: #ffffff !important;
  margin-top: 0 !important;
  border-bottom: 1px solid #00b3ee;
  text-align: center;
  padding-bottom: 12px;
  + fieldset {
    padding-left: 7px;
    background: #ffffff;
    margin-left: -12px;
    z-index: -2;
    padding-top: 45px;
    margin-top: 27px !important;
    padding-bottom: 4px;
    legend {
      font-size: 12px;
      width: 194px;
      left: 0;
      top: 100px;
      cursor: pointer;
      z-index: 2;
      position: absolute !important;
      border-radius: 0 !important;
      b {
        margin-left: 25px;
      }
      &:before {
        content: '';
        width: 0;
        height: 0;
        border-style: solid;
        position: absolute;
        z-index: 12;
        border-width: 10px 0 0 10px;
        border-color: transparent transparent transparent #ccc;
        top: -10px;
        left: 184px;
      }
    }
    br {
      content: "";
      margin: 1em 0;
      display: block;
      font-size: 24%;
      border-bottom: 2px solid transparent;
    }
  }
}

.sidebar_table {
  display: none;
  + a {
    border-left: 2px solid;
    margin: 0 !important;
    br {
      content: "";
      margin: 0;
      display: block;
      font-size: 2px;
      border: none;
    }
    &:before {
      content: '─';
      font-weight: bolder;
      margin-right: 6px;
    }
  }
}

.right_td[style] {
  padding-left: 25px !important;
}

#headerlinks + fieldset + fieldset {
  background: #fff;
  padding-left: 5px !important;
  + fieldset {
    background: #fff;
    padding-left: 5px !important;
  }
  legend {
    background: #ffffff;
    font-size: 12px;
    width: 198px;
    left: 0;
    top: 18px;
    cursor: pointer;
    margin-left: -22px;
    z-index: 12;
    border-radius: 0 !important;
    border: 1px solid #cccccc;
    color: #000000;
    a {
      color: #000;
      font-weight: bold;
      font-size: 14px;
    }
    &:before {
      content: '';
      width: 0;
      height: 0;
      border-style: solid;
      position: absolute;
      z-index: 12;
      border-width: 10px 0 0 10px;
      border-color: transparent transparent transparent #ccc;
      top: -10px;
      left: 188px;
    }
    a {
      overflow-x: hidden;
    }
  }
  + fieldset legend {
    background: #ffffff;
    font-size: 12px;
    width: 198px;
    left: 0;
    top: 18px;
    cursor: pointer;
    margin-left: -22px;
    z-index: 12;
    border-radius: 0 !important;
    border: 1px solid #cccccc;
    color: #000000;
  }
  + fieldset legend a {
    color: #000;
    font-weight: bold;
    font-size: 14px;
  }
  + fieldset legend:before {
    content: '';
    width: 0;
    height: 0;
    border-style: solid;
    position: absolute;
    z-index: 12;
    border-width: 10px 0 0 10px;
    border-color: transparent transparent transparent #ccc;
    top: -10px;
    left: 188px;
  }
  + fieldset {
    legend {
      a {
        overflow-x: hidden;
      }
      top: -12px;
    }
    padding-bottom: 5px;
    input {
      &[type=text] {
        margin-bottom: 5px;
        width: 95% !important;
      }
      &[type=submit] {
        width: 95%;
      }
    }
  }
  margin-bottom: 9px;
}

a {
  &.tab, &.tab_pressed {
    margin-right: -1px;
    line-height: 1.42857143;
    border-radius: 4px 4px 0 0;
    position: relative;
    display: inline-block;
    padding: 10px 15px;
    border-bottom: 1px solid #ddd;
  }
  &.tab:hover {
    border-color: #eee #eee #ddd;
    text-decoration: none;
    background-color: #eee;
  }
  &.tab_pressed {
    &:hover {
      border-color: #eee #eee #ddd;
      text-decoration: none;
      background-color: #eee;
    }
    color: #555;
    cursor: default;
    background-color: #fff;
    border: 1px solid #ddd;
    border-bottom-color: transparent;
  }
  &.warning {
    color: red;
  }
}

div#main {
  padding-top: 5px;
}

input {
  &[name=newname] {
    display: inline;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
  }
  &[name=rename] {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin-top: -3px;
    margin-left: -5px;
    padding-bottom: 7px;
  }
}

table.viewTable {
  width: auto !important;
}

td a {
  &.edit {
    color: blue;
  }
  &.delete {
    color: red;
  }
}

input {
  &[name=tablefields], &[name=select] {
    display: inline-block;
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
  }
  &[name=createtable] {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    margin-top: -3px;
    margin-left: -5px;
    padding-bottom: 7px;
  }
  &[name=tablename], &[name=viewname], &[name=numRows], &[name=startRow] {
    display: inline-block;
  }
}

select {
  &[name=viewtype], &[name=type] {
    width: auto !important;
    display: inline-block;
  }
}

input[name=tablefields][style] {
  width: 45px;
  color: #000000;
  padding-right: 0 !important;
}